@@ -28,6 +28,7 @@
 #include <cstdlib>
 #include <cassert>
 
+#include "strings.hpp"
 #include "lifeograph.hpp"
 #include "app_window.hpp"
 #include "dialog_preferences.hpp"
@@ -35,13 +36,12 @@
 
 using namespace LIFEO;
 
-AppWindow *AppWindow::p = NULL;
+AppWindow* AppWindow::p = NULL;
 
 // CONSTRUCTOR
-AppWindow::AppWindow( void )
+AppWindow::AppWindow()
 :   m_view_login( NULL ), m_diary_view( NULL ), m_entry_view( NULL ), m_tag_view( NULL ),
-    m_ctg_tags_view( NULL ), m_chapter_view( NULL ), m_theme_view( NULL ),
-    m_about_dialog( NULL ), m_hpaned_main( NULL )
+    m_ctg_tags_view( NULL ), m_chapter_view( NULL ), m_about_dialog( NULL ), m_paned_main( NULL )
 {
     p = this;
 
@@ -69,7 +69,7 @@ AppWindow::AppWindow( void )
         draw_loginscreen();
 }
 
-AppWindow::~AppWindow( void )
+AppWindow::~AppWindow()
 {
     remove();
     delete UndoManager::m;
@@ -97,7 +97,7 @@ AppWindow::on_delete_event( GdkEventAny* )
 }
 
 bool
-AppWindow::write_backup( void )
+AppWindow::write_backup()
 {
     m_entry_view->sync();
 
@@ -107,14 +107,13 @@ AppWindow::write_backup( void )
 }
 
 void
-AppWindow::show_about( void )
+AppWindow::show_about()
 {
     if( m_about_dialog == NULL )
     {
         Lifeograph::builder->get_widget( "aboutdialog", m_about_dialog );
         m_about_dialog->set_name( PROGRAM_NAME );
         m_about_dialog->set_version( Lifeograph::PROGRAM_VERSION_STRING );
-        // XXX if needed: m_about_dialog->signal_activate_link().connect( open_url );
         m_about_dialog->set_transient_for( *this );
     }
 
@@ -123,13 +122,13 @@ AppWindow::show_about( void )
 }
 
 void
-AppWindow::handle_undo( void )
+AppWindow::handle_undo()
 {
     UndoManager::m->undo();
 }
 
 void
-AppWindow::handle_redo( void )
+AppWindow::handle_redo()
 {
     UndoManager::m->redo();
 }
@@ -138,8 +137,8 @@ bool
 AppWindow::finish_editing( bool opt_save )
 {
     // SAVING
-    Lifeograph::settings.position_pane = m_hpaned_main->get_position();
-    Lifeograph::settings.position_pane_tags = m_hpaned_entry->get_position();
+    Lifeograph::settings.position_pane = m_paned_main->get_position();
+    Lifeograph::settings.position_pane_tags = m_paned_entry->get_position();
 
     // files added to recent list here if not already there
     if( ! Diary::d->get_path().empty() )
@@ -224,7 +223,7 @@ AppWindow::logout( bool opt_save )
 }
 
 bool
-AppWindow::confirm_dismiss_element( const DiaryElement *elem, Gtk::Widget *extra_widget )
+AppWindow::confirm_dismiss_element( const DiaryElement* elem, Gtk::Widget* extra_widget )
 {
     Gtk::MessageDialog message( *this, "", false,
                                 Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE, true );
@@ -248,17 +247,19 @@ AppWindow::confirm_dismiss_element( const DiaryElement *elem, Gtk::Widget *extra
 }
 
 Gtk::TreeRow
-AppWindow::get_element_row( const DiaryElement *element )
+AppWindow::get_element_row( const DiaryElement* element )
 {
     switch( element->get_type() )
     {
         case DiaryElement::ET_ENTRY:
         case DiaryElement::ET_CHAPTER:
+        case DiaryElement::ET_TOPIC:
+        case DiaryElement::ET_TODO_GRP:
             return( panel_diary->get_row( element->m_list_data->treepath ) );
 
         case DiaryElement::ET_TAG:
+        case DiaryElement::ET_UNTAGGED:
         case DiaryElement::ET_TAG_CTG:
-        case DiaryElement::ET_THEME:
             return( panel_extra->get_row( element->m_list_data->treepath ) );
         default:
             return( Gtk::TreeRow() );
@@ -266,7 +267,7 @@ AppWindow::get_element_row( const DiaryElement *element )
 }
 
 void
-AppWindow::update_title( void )
+AppWindow::update_title()
 {
     Glib::ustring title( PROGRAM_NAME );
 
@@ -288,15 +289,15 @@ AppWindow::update_title( void )
 
 // MODE DRAWING FUNCTIONS
 void
-AppWindow::draw_welcomescreen( void )
+AppWindow::draw_welcomescreen()
 {
-    Gtk::Alignment *alignment = Gtk::manage( new Gtk::Alignment( 0.5, 0.5, 0.1, 0 ) );
-    Gtk::Label *label_salutation =
+    Gtk::Alignment* alignment = Gtk::manage( new Gtk::Alignment( 0.5, 0.5, 0.1, 0 ) );
+    Gtk::Label* label_salutation =
             Gtk::manage( new Gtk::Label( _( STRING::SALUTATION ), 0.5, 0.5 ) );
-    Gtk::Button *button_start = Gtk::manage( new Gtk::Button( _("_Continue"), true ) );
-    Gtk::Image *icon_forward =
+    Gtk::Button* button_start = Gtk::manage( new Gtk::Button( _("_Continue"), true ) );
+    Gtk::Image* icon_forward =
             Gtk::manage( new Gtk::Image( Gtk::Stock::GO_FORWARD, Gtk::ICON_SIZE_MENU ) );
-    Gtk::Box *vbox = Gtk::manage( new Gtk::Box( Gtk::ORIENTATION_VERTICAL, 50 ) );
+    Gtk::Box* vbox = Gtk::manage( new Gtk::Box( Gtk::ORIENTATION_VERTICAL, 50 ) );
 
     alignment->set_padding( 120, 120, 150, 150 );
 
@@ -317,7 +318,7 @@ AppWindow::draw_welcomescreen( void )
 }
 
 void
-AppWindow::draw_loginscreen( void )
+AppWindow::draw_loginscreen()
 {
     // only to be called on start up
     assert( m_view_login == NULL );
@@ -334,15 +335,15 @@ AppWindow::draw_loginscreen( void )
 }
 
 void
-AppWindow::login( void )
+AppWindow::login()
 {
     remove();
 
-    if( m_hpaned_main == NULL )
+    if( m_paned_main == NULL )
     {
 #ifdef LIFEO_NO_APP_MENU
-        Gtk::MenuItem               *menuitem_preferences;
-        Gtk::MenuItem               *menuitem_about;
+        Gtk::MenuItem*              menuitem_preferences;
+        Gtk::MenuItem*              menuitem_about;
 #endif
 
         try
@@ -354,44 +355,79 @@ AppWindow::login( void )
 #endif
 
             // PANES
-            Lifeograph::builder->get_widget( "hpaned_main", m_hpaned_main );
-            Lifeograph::builder->get_widget( "hpaned_second", m_hpaned_entry );
+            Lifeograph::builder->get_widget( "P_main", m_paned_main );
+            Lifeograph::builder->get_widget( "P_second", m_paned_entry );
 
             // TAG PANEL
             Lifeograph::builder->get_widget_derived( "treeview_all_tags", panel_extra );
 
             // ICONS
-            Glib::RefPtr< Gtk::IconTheme > theme = Gtk::IconTheme::get_default();
-            Lifeograph::icons->diary_16 = Gdk::Pixbuf::create_from_file( ICONDIR "/diary-16.png" );
-            Lifeograph::icons->diary_32 = Gdk::Pixbuf::create_from_file( ICONDIR "/diary-32.png" );
-            Lifeograph::icons->entry_16 = Gdk::Pixbuf::create_from_file( ICONDIR "/entry-16.png" );
-            Lifeograph::icons->entry_32 = Gdk::Pixbuf::create_from_file( ICONDIR "/entry-32.png" );
-            Lifeograph::icons->entry_favorite_16 = Gdk::Pixbuf::create_from_file( ICONDIR "/favorite-16.png" );
-            Lifeograph::icons->entry_favorite_32 = Gdk::Pixbuf::create_from_file( ICONDIR "/favorite-32.png" );
-            Lifeograph::icons->tag_16 = Gdk::Pixbuf::create_from_file( ICONDIR "/tag-16.png" );
-            Lifeograph::icons->tag_32 = Gdk::Pixbuf::create_from_file( ICONDIR "/tag-32.png" );
-            Lifeograph::icons->tag_category_16 = Gdk::Pixbuf::create_from_file( ICONDIR "/category_tags-16.png" );
-            Lifeograph::icons->tag_category_32 = Gdk::Pixbuf::create_from_file( ICONDIR "/category_tags-32.png" );
-            Lifeograph::icons->chapter_16 = Gdk::Pixbuf::create_from_file( ICONDIR "/chapter-16.png" );
-            Lifeograph::icons->chapter_32 = Gdk::Pixbuf::create_from_file( ICONDIR "/chapter-32.png" );
-            // TODO: update icons on theme change
-            Lifeograph::icons->theme_16 = theme->load_icon( "gtk-select-color", 16 );
-            Lifeograph::icons->theme_default_16 = theme->load_icon( "gtk-apply", 16 );
-            Lifeograph::icons->theme_32 = theme->load_icon( "gtk-select-color", 32 );
-            Lifeograph::icons->month_16 = Gdk::Pixbuf::create_from_file( ICONDIR "/month-16.png" );
-            Lifeograph::icons->month_32 = Gdk::Pixbuf::create_from_file( ICONDIR "/month-32.png" );
-            Lifeograph::icons->filter_16 = Gdk::Pixbuf::create_from_file( ICONDIR "/filter-16.png" );
+            Lifeograph::icons->diary_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/diary-16.png" );
+            Lifeograph::icons->diary_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/diary-32.png" );
+            Lifeograph::icons->entry_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/entry-16.png" );
+            Lifeograph::icons->entry_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/entry-32.png" );
+            Lifeograph::icons->entry_favorite_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/favorite-16.png" );
+
+            Lifeograph::icons->tag_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag-16.png" );
+            Lifeograph::icons->tag_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag-32.png" );
+            Lifeograph::icons->tag_theme_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag_theme-16.png" );
+            Lifeograph::icons->tag_theme_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag_theme-32.png" );
+            Lifeograph::icons->untagged_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/untagged-16.png" );
+            Lifeograph::icons->untagged_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/untagged-32.png" );
+            Lifeograph::icons->tag_category_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag_category-16.png" );
+            Lifeograph::icons->tag_category_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/tag_category-32.png" );
+
+            Lifeograph::icons->chapter_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/chapter-16.png" );
+            Lifeograph::icons->chapter_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/chapter-32.png" );
+
+            Lifeograph::icons->month_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/month-16.png" );
+            Lifeograph::icons->month_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/month-32.png" );
+
+            Lifeograph::icons->filter_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/filter-16.png" );
+            Lifeograph::icons->filter_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/filter-32.png" );
+
+            Lifeograph::icons->todo_open_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_open-16.png" );
+            Lifeograph::icons->todo_open_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_open-32.png" );
+            Lifeograph::icons->todo_done_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_done-16.png" );
+            Lifeograph::icons->todo_done_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_done-32.png" );
+            Lifeograph::icons->todo_canceled_16 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_canceled-16.png" );
+            Lifeograph::icons->todo_canceled_32 =
+                    Gdk::Pixbuf::create_from_file( ICONDIR "/todo_canceled-32.png" );
 
             // PANELS & VIEWS
             panel_main = new PanelMain;
             panel_diary = new PanelDiary;
             //panel_extra = new PanelExtra;
             m_diary_view = new DiaryView;
-            m_theme_view = new ThemeView;
             m_ctg_tags_view = new CategoryTagsView;
             m_chapter_view = new ChapterView;
             m_entry_view = new EntryView;
             m_tag_view = new TagView;
+            m_filter_view = new FilterView;
         }
         catch( std::exception &ex )
         {
@@ -414,8 +450,8 @@ AppWindow::login( void )
             Lifeograph::settings.position_pane = width - PanelDiary::MIN_WIDTH;
         }
 
-        m_hpaned_main->set_position( Lifeograph::settings.position_pane );
-        m_hpaned_entry->set_position( Lifeograph::settings.position_pane_tags );
+        m_paned_main->set_position( Lifeograph::settings.position_pane );
+        m_paned_entry->set_position( Lifeograph::settings.position_pane_tags );
 
         // ACTIONS
         Lifeograph::create_action( true, m_action_undo,"Undo", Gtk::Stock::UNDO,
@@ -446,12 +482,13 @@ AppWindow::login( void )
     Lifeograph::m_actions_edit->set_visible( Diary::d->is_read_only() == false );
     Lifeograph::m_actions_edit->set_sensitive( Diary::d->is_read_only() == false );
 
-    add( *m_hpaned_main );
+    add( *m_paned_main );
 
     // LOGIN
     Lifeograph::m_internaloperation++;
 
     m_tag_view->handle_login();
+    m_filter_view->handle_login();
     m_entry_view->handle_login();
     m_diary_view->handle_login();
     m_chapter_view->handle_login();
