@@ -56,16 +56,16 @@ class DialogSaveDiary : public DialogSaveGeneric
         static int                  launch( std::string&, std::string& );
 
 	protected:
-        void                        handle_encryption_toggled( void );
-        void                        handle_password_changed( void );
+        void                        handle_encryption_toggled();
+        void                        handle_password_changed();
 
-        static DialogSaveDiary      *ptr;
+        static DialogSaveDiary*     ptr;
 
-        Gtk::Frame                  *m_frame_encrypt;
-        Gtk::Grid                   *m_grid_password;
-        Gtk::CheckButton            *m_check_encrypt;
-        Gtk::Entry                  *m_entry_password;
-        Gtk::Entry                  *m_entry_confirm;
+        Gtk::Frame*                 m_frame_encrypt;
+        Gtk::Grid*                  m_grid_password;
+        Gtk::CheckButton*           m_check_encrypt;
+        Gtk::Entry*                 m_entry_password;
+        Gtk::Entry*                 m_entry_confirm;
 };
 
 // FILE OPEN DIALOG ================================================================================
@@ -79,7 +79,7 @@ class DialogOpenDiary : public Gtk::FileChooserDialog
                                     DialogOpenDiary();
 
         // FILTERING
-        static void                 init_filters( void );
+        static void                 init_filters();
 
         static Glib::RefPtr< Gtk::FileFilter >
                                     filter_any;
@@ -87,7 +87,7 @@ class DialogOpenDiary : public Gtk::FileChooserDialog
                                     filter_diary;
 
     protected:
-        void                        handle_selection_changed( void );
+        void                        handle_selection_changed();
 
         static bool                 flag_filters_created;
 };
@@ -99,37 +99,37 @@ class DialogImport : public DialogEvent
         DialogImport( BaseObjectType*,
                       const Glib::RefPtr< Gtk::Builder >& );
 
-        void                        on_show( void );
+        void                        on_show();
         void                        on_response( int );
 
-        void                        handle_diary_changed( void );
-        void                        handle_parts_changed( void );
+        void                        handle_diary_changed();
+        void                        handle_parts_changed();
 
-        void                        set_ready( void );
+        void                        set_ready();
         void                        set_not_ready( const Glib::ustring& );
 
-        bool                        is_options_ready( void );
+        bool                        is_options_ready();
 
     private:
-        Gtk::FileChooserButton      *m_file_chooser_button;
-        Gtk::Label                  *m_label_info;
-        Gtk::Label                  *m_label_entries;
-        Gtk::Label                  *m_label_tags;
-        Gtk::Label                  *m_label_themes;
-        TagWidget                   *m_tag_widget;
-        Gtk::Entry                  *m_entry_password;
+        Gtk::FileChooserButton*     m_file_chooser_button;
+        Gtk::Label*                 m_label_info;
+        Gtk::Label*                 m_label_entries;
+        Gtk::Label*                 m_label_tags;
+        Gtk::Label*                 m_label_chapters;
+        TagWidget*                  m_tag_widget;
+        Gtk::Entry*                 m_entry_password;
 
-        Gtk::CheckButton            *m_checkbutton_import_entries;
-        Gtk::CheckButton            *m_checkbutton_import_tags;
-        Gtk::CheckButton            *m_checkbutton_import_themes;
+        Gtk::CheckButton*           m_checkbutton_import_entries;
+        Gtk::CheckButton*           m_checkbutton_import_tags;
+        Gtk::CheckButton*           m_checkbutton_import_chapters;
 
-        DialogPassword              *m_dialog_password;
+        DialogPassword*             m_dialog_password;
 
-        Diary                       *m_diary;
+        Diary*                      m_diary;
 
         bool                        m_option_import_entries;
         bool                        m_option_import_tags;
-        bool                        m_option_import_themes;
+        bool                        m_option_import_chapters;
         bool                        m_flag_diary_is_ready;
 
 };
@@ -141,14 +141,14 @@ class Diarysaver
     typedef sigc::signal< void, bool >
                                     Signal_void_bool;
 
-        virtual Gtk::Widget*        draw_options( void ) = 0;
-        virtual bool                is_ready( void ) = 0;
+        virtual Gtk::Widget*        draw_options() = 0;
+        virtual bool                is_ready() = 0;
         virtual Result              save( bool ) = 0;
 
-        Glib::ustring               get_name( void )
+        Glib::ustring               get_name()
         { return m_name; }
 
-        Signal_void_bool            signal_updated( void )
+        Signal_void_bool            signal_updated()
         { return m_signal_updated; }
 
     protected:
@@ -156,7 +156,7 @@ class Diarysaver
         virtual                     ~Diarysaver() {}
 
         Glib::ustring               m_name;
-        Diary                       *m_ptr2diary;
+        Diary*                      m_ptr2diary;
 
         Signal_void_bool            m_signal_updated;
 };
@@ -165,12 +165,12 @@ class ExporterLifeograph : public Diarysaver
 {
     public:
         explicit                    ExporterLifeograph( Diary* );
-        Gtk::Widget*                draw_options( void );
-        bool                        is_ready( void );
+        Gtk::Widget*                draw_options();
+        bool                        is_ready();
         Result                      save( bool );
 
-//        void                        handle_passphrase_changed( void );
-//        void                        handle_encryption_changed( void );
+//        void                        handle_passphrase_changed();
+//        void                        handle_encryption_changed();
 
     private:
 //        Gtk::CheckButton            *m_check_encrypt;
@@ -185,10 +185,10 @@ class ExporterText : public Diarysaver
 {
     public:
         explicit                    ExporterText( Diary* );
-        Gtk::Widget*                draw_options( void )
+        Gtk::Widget*                draw_options()
         { return NULL; }
 
-        bool                        is_ready( void )
+        bool                        is_ready()
         { return true; }
 
         Result                      save( bool );
@@ -206,21 +206,20 @@ class DialogExport : public DialogEvent
     protected:
         virtual void                on_response( int );
 
-        void                        handle_savetype_changed( void );
+        void                        handle_savetype_changed();
         void                        handle_saver_updated( bool );
 
-        Gtk::ComboBoxText           *m_combo_type;
-        Gtk::ComboBoxText           *m_combo_extent;
-        Gtk::Button                 *m_button_export;
-        Gtk::Alignment              *m_align_options;
-        Gtk::Frame                  *m_frame_options;
-        Gtk::Widget                 *m_ptr2widget_options;
+        Gtk::ComboBoxText*          m_combo_type;
+        Gtk::ComboBoxText*          m_combo_extent;
+        Gtk::Button*                m_button_export;
+        Gtk::Alignment*             m_align_options;
+        Gtk::Frame*                 m_frame_options;
+        Gtk::Widget*                m_ptr2widget_options;
 
-        std::vector< Diarysaver* >
-                                    m_savers;
-        Diarysaver                  *m_saver_cur;
+        std::vector< Diarysaver* >  m_savers;
+        Diarysaver*                 m_saver_cur;
 
-        Diary                       *m_ptr2diary;
+        Diary*                      m_ptr2diary;
         bool                        m_flag_saverready;
 
     private:
