@@ -32,7 +32,7 @@
 namespace LIFEO
 {
 const char                      DB_FILE_HEADER[] = "LIFEOGRAPHDB";
-const int                       DB_FILE_VERSION_INT( 110 );
+const int                       DB_FILE_VERSION_INT( 1010 );
 const int                       DB_FILE_VERSION_INT_MIN( 56 );
 const std::string::size_type    PASSPHRASE_MIN_SIZE( 4 );
 const char                      LOCK_SUFFIX[] = ".~LOCK~";
@@ -49,7 +49,8 @@ enum Result
     WRONG_PASSWORD,
     //APPARENTLY_ENCRYTED_FILE,
     //APPARENTLY_PLAIN_FILE,
-    INCOMPATIBLE_FILE,
+    INCOMPATIBLE_FILE_OLD,
+    INCOMPATIBLE_FILE_NEW,
     CORRUPT_FILE,
     // EMPTY_DATABASE, // not used anymore
     // VARIABLES USED BY set_path():
@@ -64,175 +65,160 @@ typedef PoolEntries::reverse_iterator       EntryIterReverse;
 typedef PoolEntries::const_iterator         EntryIterConst;
 typedef PoolEntries::const_reverse_iterator EntryIterConstRev;
 
-typedef std::vector< Entry* >               EntryVector;
-typedef std::vector< Entry* >::iterator     EntryVectorIter;
-
 
 class Diary : public DiaryBase, public DiaryElement
 {
     public:
-        typedef unsigned int FilteringStatus;
-        static const FilteringStatus FS_CLEAR               = 0;
-        static const FilteringStatus FS_FILTER_TEXT         = 2;
-        static const FilteringStatus FS_FILTER_FAVORITES    = 4;
-        static const FilteringStatus FS_FILTER_TAG          = 8;
-        static const FilteringStatus FS_FILTER_DATE         = 16;
-        static const FilteringStatus FS_FILTER_TRASH        = 32;
-        static const FilteringStatus FS_NEW                 = 1024;
 
         static ElementShower< Diary > *shower;
 
-                                Diary( void );
-                                ~Diary( void );
+                                Diary();
+                                ~Diary();
 
         static Diary            *d;
 
-        bool	                is_old( void )
+        bool	                is_old()
         { return( m_read_version < DB_FILE_VERSION_INT ); }
 
         void                    init_new( const std::string& );
 
         // DISK I/O
-        LIFEO::Result           read_body( void );
-        LIFEO::Result           read_header( void );
+        LIFEO::Result           read_body();
+        LIFEO::Result           read_header();
 
-        LIFEO::Result           write( void );
+        LIFEO::Result           write();
         LIFEO::Result           write( const std::string& );
         LIFEO::Result           write_copy( const std::string&, const std::string&, bool );
         LIFEO::Result           write_txt( const std::string&, bool );
 
-        virtual void            clear( void );
+        virtual void            clear();
 
         int	                    get_size() const
         { return m_entries.size(); }
-        Type                    get_type( void ) const
+        Type                    get_type() const
         { return ET_DIARY; }
         const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon( void ) const;
+                                get_icon() const;
         const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32( void ) const;
+                                get_icon32() const;
 
-        Glib::ustring           get_list_str( void ) const
+        Glib::ustring           get_list_str() const
         { return Glib::ustring::compose( "<b>%1</b>", Glib::Markup::escape_text( m_name ) ); }
 
         LIFEO::Result           set_path( const std::string&, bool, bool = false );
-        const std::string&	    get_path( void ) const;
-        bool                    is_path_set( void ) const;
+        const std::string&	    get_path() const;
+        bool                    is_path_set() const;
 
         bool                    set_passphrase( const std::string& );
-        void                    clear_passphrase( void );
-        std::string	            get_passphrase( void ) const;
+        void                    clear_passphrase();
+        std::string	            get_passphrase() const;
         bool                    compare_passphrase( const std::string& ) const;
-        bool                    is_passphrase_set( void ) const;
+        bool                    is_passphrase_set() const;
 
-        bool                    is_read_only( void ) const
+        bool                    is_read_only() const
         { return m_flag_read_only; }
 
         DiaryElement*           get_element( DEID ) const;
-        DiaryElement*           get_startup_elem( void ) const;
+        DiaryElement*           get_startup_elem() const;
         void                    set_startup_elem( const DEID );
-        DiaryElement*           get_most_current_elem( void ) const;
-        DiaryElement*           get_prev_session_elem( void ) const;
+        DiaryElement*           get_most_current_elem() const;
+        DiaryElement*           get_prev_session_elem() const;
         void                    set_last_elem( const DiaryElement* );
 
         Entry*                  get_entry( const Date::date_t );
         EntryVector*            get_entries( Date::date_t );
-        PoolEntries&	        get_entries( void )
+        PoolEntries&	        get_entries()
         { return m_entries; }
         bool                    get_day_has_multiple_entries( const Date& );
-        Entry*                  get_entry_today( void );
+        Entry*                  get_entry_today();
         Entry*                  get_entry_next_in_day( const Date& );
-        Entry*                  get_entry_first( void );
+        Entry*                  get_entry_first();
         void                    set_entry_date( Entry*, const Date& );
 
         bool                    is_first( const Entry * const ) const;
         bool                    is_last( const Entry * const ) const;
-        SortingCriteria	        get_sorting_criteria( void ) const
+        SortingCriteria	        get_sorting_criteria() const
         { return m_option_sorting_criteria; }
         void	                set_sorting_criteria( SortingCriteria sc )
         { m_option_sorting_criteria = sc; }
 
-        void                    set_filter_text( const Glib::ustring& );
-        Glib::ustring	        get_filter_text( void ) const
-        { return m_filter_text; }
-        void                    set_filter_tag( const Tag* );
-        const Tag*	            get_filter_tag( void ) const
-        { return m_filter_tag; }
-        void                    toggle_filter_favorites( void );
-        void                    toggle_filter_trash( void );
-        Date::date_t            get_filter_date_begin( void )
-        { return m_filter_date_begin; }
-        Date::date_t            get_filter_date_end( void )
-        { return m_filter_date_end; }
-        void                    set_filter_date_begin( Date::date_t d );
-        void                    set_filter_date_end( Date::date_t d );
-        void                    activate_individual_filter( void );
-        void                    clear_filter_date( void );
-
-        FilteringStatus         get_filtering_status( void ) const { return m_filtering_status; }
-        void	                set_filtering_status_applied( void )
-        { if( m_filtering_status & FS_NEW ) m_filtering_status -= FS_NEW; }
-        void                    set_filtering_status_new( void ) { m_filtering_status |= FS_NEW; }
-
+        // FILTERING
+        void                    set_search_text( const Glib::ustring& );
+        Glib::ustring	        get_search_text() const
+        { return m_search_text; }
+        bool                    is_search_active()
+        { return( m_search_text.empty() == false ); }
         int                     replace_text( const Glib::ustring& );
 
+        Filter*                 get_filter()
+        { return m_filter_active; }
+        Filter*                 get_filter_default()
+        { return m_filter_default; }
+        void                    set_filter_tag( const Tag *tag )
+        { m_filter_active->set_tag( tag ); }
+        const Tag*              get_filter_tag() const
+        { return m_filter_active->get_tag(); }
+        Date::date_t            get_filter_date_begin()
+        { return m_filter_active->get_date_begin(); }
+        Date::date_t            get_filter_date_end()
+        { return m_filter_active->get_date_end(); }
+        void                    set_filter_date_begin( Date::date_t d )
+        { m_filter_active->set_date_begin( d ); }
+        void                    set_filter_date_end( Date::date_t d )
+        { m_filter_active->set_date_end( d ); }
+
+        ElemStatus              get_filter_status() const
+        { return m_filter_active->get_status(); }
+
         Entry*                  create_entry( Date::date_t, const Glib::ustring& = "",
                                               bool = false );
         // adds a new entry to today even if there is already one or more:
-        Entry*                  add_today( void );
+        Entry*                  add_today();
         virtual bool            dismiss_entry( Entry* );
-        int                     list_entries( void );
+        int                     list_entries();
 
-        PoolTags*               get_tags( void )
+        PoolTags*               get_tags()
         { return &m_tags; }
-        CategoryTags*           create_tag_ctg( void );
+        CategoryTags*           create_tag_ctg();
         CategoryTags*           create_tag_ctg( const Glib::ustring& );
         void                    dismiss_tag_ctg( CategoryTags*, bool = false );
         Tag*                    create_tag( const Glib::ustring&, CategoryTags* = NULL );
         void                    dismiss_tag( Tag*, bool = false );
 
     const PoolCategoriesChapters*
-                                get_chapter_ctgs( void ) const
+                                get_chapter_ctgs() const
         { return &m_chapter_categories; }
-        CategoryChapters*	    get_current_chapter_ctg( void )
+        CategoryChapters*	    get_current_chapter_ctg()
         { return m_ptr2chapter_ctg_cur; }
-        CategoryChapters*       create_chapter_ctg( void );
+        CategoryChapters*       create_chapter_ctg();
         CategoryChapters*       create_chapter_ctg( const Glib::ustring& );
         void                    dismiss_chapter_ctg( CategoryChapters* );
         bool                    rename_chapter_ctg( CategoryChapters*, const Glib::ustring& );
         void                    dismiss_chapter( Chapter*, bool = false );
-        const CategoryChapters* get_topics( void )
+        const CategoryChapters* get_topics()
         { return &m_topics; }
+        const CategoryChapters* get_todo_groups()
+        { return &m_todo_groups; }
         Chapter*                add_topic( const Glib::ustring& );
+        Chapter*                add_todo_group( const Glib::ustring& );
         void                    set_topic_order( Chapter*, Date::date_t );
 
-        Date                    get_free_chapter_order_temporal( void );
-        Date                    get_free_chapter_order_ordinal( void );
+        Date                    get_free_chapter_order_temporal();
+        Date                    get_free_chapter_order_ordinal();
 
         bool                    make_free_entry_order( Date& );
 
-        bool                    is_encrypted( void ) const
+        bool                    is_encrypted() const
         { return( ! m_passphrase.empty() ); }
 
-        Theme*                  create_theme( const Glib::ustring& );
-        Theme*                  duplicate_theme( const Theme *theme );
-        bool	                has_theme( void ) const
-        { return( m_default_theme != NULL ); }
-        const PoolThemes&	    get_themes( void ) const
-        { return m_themes; }
-        PoolThemes&	            get_themes( void )
-        { return m_themes; }
-        void	                set_default_theme( Theme *theme )
-        { m_default_theme = theme; }
-        Theme*	                get_default_theme( void ) const
-        { return m_default_theme; }
-        void                    dismiss_theme( Theme *theme );
-
-        void                    show( void );
+        void                    show();
 
         bool                    import_tag( Tag* );
         bool                    import_entries( const Diary&, bool, const Glib::ustring& );
-        bool                    import_themes( const PoolThemes& );
+        bool                    import_chapters( const Diary& );
+
+        Untagged*               get_untagged()
+        { return &m_untagged; }
 
         static bool             s_flag_ignore_locks;
 
@@ -244,10 +230,9 @@ class Diary : public DiaryBase, public DiaryElement
         PoolTags                m_tags;
         PoolCategoriesTags      m_tag_categories;
         PoolCategoriesChapters	m_chapter_categories;
-        CategoryChapters        *m_ptr2chapter_ctg_cur;
-        CategoryChapters        m_topics;	// ordinal chapters
-        PoolThemes              m_themes;
-        Theme                   *m_default_theme;
+        CategoryChapters*       m_ptr2chapter_ctg_cur;
+        CategoryChapters        m_topics;   // ordinal chapters
+        CategoryChapters        m_todo_groups;
 
         DEID                    m_startup_elem_id;
         DEID                    m_last_elem_id;
@@ -257,18 +242,23 @@ class Diary : public DiaryBase, public DiaryElement
         bool                    m_flag_only_save_filtered;
         bool                    m_flag_read_only;
         // filtering
-        Glib::ustring           m_filter_text;
-        const Tag               *m_filter_tag;
-        Date::date_t            m_filter_date_begin;
-        Date::date_t            m_filter_date_end;
-        FilteringStatus         m_filtering_status;
+        Glib::ustring           m_search_text;
+        Filter*                 m_filter_active;
+        Filter*                 m_filter_default;
+        // TODO FilterVector            m_filters;  // user defined filters
 
+        // pseudo tag "untagged":
+        Untagged                m_untagged;
+
+        void                    create_db_tag_text( const Tag*, std::stringstream& );
         LIFEO::Result           parse_db_body_text( std::stringstream& );
+        LIFEO::Result           parse_db_body_text_1010( std::stringstream& );
+        LIFEO::Result           parse_db_body_text_110( std::stringstream& );
         LIFEO::Result           parse_db_body_text_56( std::stringstream& );
         bool                    create_db_body_text( std::stringstream& );
         bool                    create_db_header_text( std::stringstream&, bool );
-        LIFEO::Result           read_plain( void );
-        LIFEO::Result           read_encrypted( void );
+        LIFEO::Result           read_plain();
+        LIFEO::Result           read_encrypted();
         LIFEO::Result           write_plain( const std::string&, bool = false );
         LIFEO::Result           write_encrypted( const std::string& );
 
