@@ -30,32 +30,34 @@ using namespace LIFEO;
 
 
 bool
-LIFEO::compare_listitems( DiaryElement *item_l, DiaryElement *item_r )
+LIFEO::compare_listitems( DiaryElement* item_l, DiaryElement* item_r )
 {
     return( item_l->get_date() > item_r->get_date() );
 }
 
 bool
-LIFEO::compare_listitems_by_name( DiaryElement *item_l, DiaryElement *item_r )
+LIFEO::compare_listitems_by_name( DiaryElement* item_l, DiaryElement* item_r )
 {
     return( item_l->get_name() < item_r->get_name() );
 }
 
 bool
-LIFEO::compare_names( const Glib::ustring &name_l, const Glib::ustring &name_r )
+LIFEO::compare_names( const Glib::ustring& name_l, const Glib::ustring& name_r )
 {
     return( name_l < name_r );
 }
 
 // DIARYELEMENT ====================================================================================
 // STATIC MEMBERS
-ListData::Colrec                    *ListData::colrec;
+ListData::Colrec*                   ListData::colrec;
 bool                                DiaryElement::FLAG_ALLOCATE_GUI_FOR_DIARY = true;
 const Glib::RefPtr< Gdk::Pixbuf >   DiaryElement::s_pixbuf_null;
 
-DiaryElement::DiaryElement( DiaryBase * const ptr2diary, const Glib::ustring &name )
+DiaryElement::DiaryElement( DiaryBase* const ptr2diary,
+                            ElemStatus status,
+                            const Glib::ustring &name )
 :   NamedElement( name ), m_ptr2diary( ptr2diary ),
-    m_id( ptr2diary ? ptr2diary->create_new_id( this ) : DEID_UNSET )
+    m_id( ptr2diary ? ptr2diary->create_new_id( this ) : DEID_UNSET ), m_status( status )
 {
     if( FLAG_ALLOCATE_GUI_FOR_DIARY )
         m_list_data = new ListData;
@@ -64,33 +66,33 @@ DiaryElement::DiaryElement( DiaryBase * const ptr2diary, const Glib::ustring &na
 
 // TAG =============================================================================================
 // STATIC MEMBERS
-ElementShower< Tag >    *Tag::shower( NULL );
+ElementShower< Tag >* Tag::shower( NULL );
 
-Tag::Tag( DiaryBase * const d, const Glib::ustring &name, CategoryTags *category )
-:   DiaryElementContainer( d, name ), m_ptr2category( category )
+Tag::Tag( DiaryBase* const d, const Glib::ustring& name, CategoryTags* category )
+:   DiaryElementContainer( d, name ), m_ptr2category( category ), m_theme( NULL )
 {
     if( category != NULL )
         category->insert( this );
 }
 
-Tag::~Tag( void )
+Tag::~Tag()
 {
 }
 
 const Glib::RefPtr< Gdk::Pixbuf >&
-Tag::get_icon( void ) const
+Tag::get_icon() const
 {
-    return( this == Diary::d->get_filter_tag() ?
-            Lifeograph::icons->filter_16 : Lifeograph::icons->tag_16 );
+    return( get_has_own_theme() ? Lifeograph::icons->tag_theme_16 : Lifeograph::icons->tag_16 );
 }
+
 const Glib::RefPtr< Gdk::Pixbuf >&
-Tag::get_icon32( void ) const
+Tag::get_icon32() const
 {
-    return( Lifeograph::icons->tag_32 );
+    return( get_has_own_theme() ? Lifeograph::icons->tag_theme_32 : Lifeograph::icons->tag_32 );
 }
 
 void
-Tag::show( void )
+Tag::show()
 {
     if( shower != NULL )
         shower->show( *this );
@@ -99,13 +101,13 @@ Tag::show( void )
 }
 
 void
-Tag::set_name( const Glib::ustring &name )
+Tag::set_name( const Glib::ustring& name )
 {
     m_name = name;
 }
 
 void
-Tag::set_category( CategoryTags *category_new )
+Tag::set_category( CategoryTags* category_new )
 {
     if( m_ptr2category )
         m_ptr2category->erase( this );
@@ -114,6 +116,91 @@ Tag::set_category( CategoryTags *category_new )
     m_ptr2category = category_new;
 }
 
+Theme*
+Tag::get_theme() const
+{
+    return( m_theme ? m_theme : ThemeSystem::get() );
+}
+Theme*
+Tag::get_own_theme()
+{
+    if( m_theme == NULL )
+    {
+        m_theme = new Theme( ThemeSystem::get() );
+
+        for( SetDiaryElements::const_iterator iter = m_items.begin();
+             iter != m_items.end();
+             ++iter )
+        {
+            Entry* entry = dynamic_cast< Entry* >( * iter );
+            entry->update_theme();
+        }
+    }
+
+    return m_theme;
+}
+
+Theme*
+Tag::create_own_theme_duplicating( const Theme* theme )
+{
+    if( m_theme != NULL )
+        delete m_theme;
+
+    m_theme = new Theme( theme );
+
+    for( SetDiaryElements::const_iterator iter = m_items.begin();
+         iter != m_items.end();
+         ++iter )
+    {
+        Entry* entry = dynamic_cast< Entry* >( * iter );
+        entry->update_theme();
+    }
+
+    return m_theme;
+}
+
+void
+Tag::reset_theme()
+{
+    if( m_theme )
+    {
+        delete m_theme;
+        m_theme = NULL;
+
+        for( SetDiaryElements::const_iterator iter = m_items.begin();
+             iter != m_items.end();
+             ++iter )
+        {
+            Entry* entry = dynamic_cast< Entry* >( * iter );
+            entry->update_theme();
+        }
+    }
+}
+
+Untagged::Untagged()
+:   Tag( NULL, _( "Untagged" ), NULL )
+{
+
+}
+
+Glib::ustring
+Untagged::get_list_str() const
+{
+    return( "<i>" + Glib::Markup::escape_text( m_name ) + "</i>" );
+}
+
+const Glib::RefPtr< Gdk::Pixbuf >&
+Untagged::get_icon() const
+{
+    return Lifeograph::icons->untagged_16;
+}
+
+const Glib::RefPtr< Gdk::Pixbuf >&
+Untagged::get_icon32() const
+{
+    return Lifeograph::icons->untagged_32;
+}
+
 // TAGPOOL =========================================================================================
 PoolTags::~PoolTags()
 {
@@ -133,7 +220,7 @@ PoolTags::get_tag( unsigned int tagorder )
 }
 
 Tag*
-PoolTags::get_tag( const Glib::ustring &name )
+PoolTags::get_tag( const Glib::ustring& name )
 {
     iterator iter = find( name );
     if( iter != end() )
@@ -143,7 +230,7 @@ PoolTags::get_tag( const Glib::ustring &name )
 }
 
 bool
-PoolTags::rename( Tag *tag, const Glib::ustring &new_name )
+PoolTags::rename( Tag* tag, const Glib::ustring& new_name )
 {
     erase( tag->m_name );
     tag->m_name = new_name;
@@ -151,7 +238,7 @@ PoolTags::rename( Tag *tag, const Glib::ustring &new_name )
 }
 
 void
-PoolTags::clear( void )
+PoolTags::clear()
 {
     for( iterator iter = begin(); iter != end(); ++iter )
         delete iter->second;
@@ -161,27 +248,27 @@ PoolTags::clear( void )
 
 // CATEGORYTAGS ====================================================================================
 // STATIC MEMBERS
-ElementShower< CategoryTags >   *CategoryTags::shower( NULL );
+ElementShower< CategoryTags >* CategoryTags::shower( NULL );
 
-CategoryTags::CategoryTags( DiaryBase * const d, const Glib::ustring &name )
-:   DiaryElement( d, name ), std::set< Tag*, FuncCompareDiaryElemNamed >( compare_listitems_by_name ),
-    m_flag_expanded( true )
+CategoryTags::CategoryTags( DiaryBase* const d, const Glib::ustring& name )
+:   DiaryElement( d, ES::EXPANDED, name ),
+    std::set< Tag*, FuncCompareDiaryElemNamed >( compare_listitems_by_name )
 {
 }
 
 const Glib::RefPtr< Gdk::Pixbuf >&
-CategoryTags::get_icon( void ) const
+CategoryTags::get_icon() const
 {
     return Lifeograph::icons->tag_category_16;
 }
 const Glib::RefPtr< Gdk::Pixbuf >&
-CategoryTags::get_icon32( void ) const
+CategoryTags::get_icon32() const
 {
     return Lifeograph::icons->tag_category_32;
 }
 
 void
-CategoryTags::show( void )
+CategoryTags::show()
 {
     if( shower != NULL )
         shower->show( *this );
@@ -190,7 +277,7 @@ CategoryTags::show( void )
 }
 
 // POOL OF DEFINED TAG CATEGORIES
-PoolCategoriesTags::PoolCategoriesTags( void )
+PoolCategoriesTags::PoolCategoriesTags()
 :   std::map< Glib::ustring, CategoryTags*, FuncCompareStrings >( compare_names )
 {
 }
@@ -204,7 +291,7 @@ PoolCategoriesTags::~PoolCategoriesTags()
 }
 
 void
-PoolCategoriesTags::clear( void )
+PoolCategoriesTags::clear()
 {
     for( iterator iter = begin(); iter != end(); ++iter )
     {
@@ -215,7 +302,7 @@ PoolCategoriesTags::clear( void )
 }
 
 bool
-PoolCategoriesTags::rename_category( CategoryTags *category, const Glib::ustring &new_name )
+PoolCategoriesTags::rename_category( CategoryTags* category, const Glib::ustring& new_name )
 {
     erase( category->m_name );
     category->m_name = new_name;
@@ -223,12 +310,12 @@ PoolCategoriesTags::rename_category( CategoryTags *category, const Glib::ustring
 }
 
 // TAGSET
-Tagset::~Tagset( void )
+Tagset::~Tagset()
 {
 }
 
 bool
-Tagset::add( Tag *tag )
+Tagset::add( Tag* tag )
 {
     if( insert( tag ).second ) // if did not exist previously
         return true;
@@ -241,7 +328,7 @@ Tagset::add( Tag *tag )
 }
 
 bool
-Tagset::checkfor_member( const Tag *tag ) const
+Tagset::checkfor_member( const Tag* tag ) const
 {
     return( count( const_cast< Tag* >( tag ) ) > 0 );
 }
@@ -264,35 +351,57 @@ Tagset::get_tag( unsigned int tagorder ) const
 
 // CHAPTER =========================================================================================
 // STATIC MEMBERS
-ElementShower< Chapter >    *Chapter::shower( NULL );
+ElementShower< Chapter >* Chapter::shower( NULL );
 
-Chapter::Chapter( DiaryBase * const d, const Glib::ustring &name )
-:   DiaryElement( d, name ), m_date_begin( Date::NOTSET ), m_time_span( 0 ), m_size( 0 ),
-    m_flag_expanded( false )
+Chapter::Chapter( DiaryBase* const d, const Glib::ustring& name )
+:   DiaryElement( d, ES::TODO, name ), m_date_begin( Date::NOTSET ), m_time_span( 0 ), m_size( 0 ),
+    m_type( ET_CHAPTER )
 {
 }
 
-Chapter::Chapter( DiaryBase * const d, const Glib::ustring &name, Date date )
-    :   DiaryElement( d, name ), m_date_begin( date ), m_size( 0 ),
-    m_flag_expanded( false )
+Chapter::Chapter( DiaryBase* const d, const Glib::ustring& name, Date date )
+:   DiaryElement( d, ES::TODO, name ), m_date_begin( date ), m_size( 0 )
 {
+    update_type();
 }
 
 const Glib::RefPtr< Gdk::Pixbuf >&
-Chapter::get_icon( void ) const
+Chapter::get_icon() const
 {
-    return m_date_begin.is_ordinal() ?
-                Lifeograph::icons->chapter_16 : Lifeograph::icons->month_16;
+    if( m_date_begin.is_todo() )
+        switch( m_status & ES::FILTER_TODO )
+        {
+            case ES::TODO:
+                return Lifeograph::icons->todo_open_16;
+            case ES::DONE:
+                return Lifeograph::icons->todo_done_16;
+            case ES::CANCELED:
+                return Lifeograph::icons->todo_canceled_16;
+        }
+
+    return( m_date_begin.is_ordinal() ?
+            Lifeograph::icons->chapter_16 : Lifeograph::icons->month_16 );
 }
 const Glib::RefPtr< Gdk::Pixbuf >&
-Chapter::get_icon32( void ) const
+Chapter::get_icon32() const
 {
-    return m_date_begin.is_ordinal() ?
-                Lifeograph::icons->chapter_32 : Lifeograph::icons->month_32;
+    if( m_date_begin.is_todo() )
+            switch( m_status & ES::FILTER_TODO )
+            {
+                case ES::TODO:
+                    return Lifeograph::icons->todo_open_32;
+                case ES::DONE:
+                    return Lifeograph::icons->todo_done_32;
+                case ES::CANCELED:
+                    return Lifeograph::icons->todo_canceled_32;
+            }
+
+    return( m_date_begin.is_ordinal() ?
+                Lifeograph::icons->chapter_32 : Lifeograph::icons->month_32 );
 }
 
 void
-Chapter::show( void )
+Chapter::show()
 {
     if( shower != NULL )
         shower->show( *this );
@@ -302,13 +411,13 @@ Chapter::show( void )
 }
 
 void
-Chapter::set_name( const Glib::ustring &name )
+Chapter::set_name( const Glib::ustring& name )
 {
     m_name = name;
 }
 
 Glib::ustring
-Chapter::get_date_str( void ) const
+Chapter::get_date_str() const
 {
     if( is_initialized() )
         return m_date_begin.format_string();
@@ -317,19 +426,24 @@ Chapter::get_date_str( void ) const
 }
 
 Date
-Chapter::get_date( void ) const
+Chapter::get_date() const
 {
     return m_date_begin;
 }
 
 void
-Chapter::set_date( Date::date_t date )
+Chapter::update_type()
 {
-    m_date_begin.m_date = date;
+    if( m_date_begin.is_todo() )
+        m_type = ET_TODO_GRP;
+    else if( m_date_begin.is_ordinal() )
+        m_type = ET_TOPIC;
+    else
+        m_type = ET_CHAPTER;
 }
 
 Date
-Chapter::get_free_order( void ) const
+Chapter::get_free_order() const
 {
     Date date( m_date_begin );
     m_ptr2diary->make_free_entry_order( date );
@@ -337,7 +451,7 @@ Chapter::get_free_order( void ) const
 }
 
 void
-Chapter::recalculate_span( const Chapter *next )
+Chapter::recalculate_span( const Chapter* next )
 {
     if( next == NULL )
         m_time_span = 0;    // unlimited
@@ -348,8 +462,8 @@ Chapter::recalculate_span( const Chapter *next )
 }
 
 // CHAPTER CATEGORY ================================================================================
-CategoryChapters::CategoryChapters( DiaryBase * const d, const Glib::ustring &name )
-:   DiaryElement( d, name ),
+CategoryChapters::CategoryChapters( DiaryBase* const d, const Glib::ustring& name )
+:   DiaryElement( d, ES::VOID, name ),
     std::map< Date::date_t, Chapter*, FuncCompareDates >( compare_dates )
 {
 }
@@ -368,9 +482,9 @@ CategoryChapters::get_chapter( const Date::date_t date ) const
 }
 
 Chapter*
-CategoryChapters::create_chapter( const Glib::ustring &name, const Date &date )
+CategoryChapters::create_chapter( const Glib::ustring& name, const Date& date )
 {
-    Chapter *chapter = new Chapter( m_ptr2diary, name, date );
+    Chapter* chapter = new Chapter( m_ptr2diary, name, date );
 
     add( chapter );
 
@@ -378,7 +492,7 @@ CategoryChapters::create_chapter( const Glib::ustring &name, const Date &date )
 }
 
 void
-CategoryChapters::dismiss_chapter( Chapter *chapter )
+CategoryChapters::dismiss_chapter( Chapter* chapter )
 {
     iterator iter( find( chapter->m_date_begin.m_date ) );
     if( iter == end() )
@@ -399,7 +513,7 @@ CategoryChapters::dismiss_chapter( Chapter *chapter )
 }
 
 bool
-CategoryChapters::rename_chapter( Chapter *chapter, const Glib::ustring &name )
+CategoryChapters::rename_chapter( Chapter* chapter, const Glib::ustring& name )
 {
     // Chapters must have unique begin dates not names
     chapter->set_name( name );
@@ -407,7 +521,7 @@ CategoryChapters::rename_chapter( Chapter *chapter, const Glib::ustring &name )
 }
 
 bool
-CategoryChapters::set_chapter_date( Chapter *chapter, Date::date_t date )
+CategoryChapters::set_chapter_date( Chapter* chapter, Date::date_t date )
 {
     assert( chapter->is_ordinal() == false );
 
@@ -419,7 +533,7 @@ CategoryChapters::set_chapter_date( Chapter *chapter, Date::date_t date )
 
         if( ( ++iter ) != end() ) // fix time span
         {
-            Chapter *chapter_earlier( iter->second );
+            Chapter* chapter_earlier( iter->second );
             if( chapter->m_time_span > 0 )
                 chapter_earlier->m_time_span += chapter->m_time_span;
             else
@@ -431,8 +545,7 @@ CategoryChapters::set_chapter_date( Chapter *chapter, Date::date_t date )
         if( find( date ) != end() ) // if target is taken move chapters
         {
             Date::date_t d( chapter->m_date_begin.is_ordinal() ?
-                            chapter->m_date_begin.m_date :
-                            get_free_order_ordinal().m_date );
+                            chapter->m_date_begin.m_date : get_free_order().m_date );
                             // if a temporal chapter is being converted..
                             // ..assume that it was the last
             Date::date_t step( chapter->m_date_begin.m_date > date ?
@@ -464,7 +577,7 @@ CategoryChapters::set_chapter_date( Chapter *chapter, Date::date_t date )
 }
 
 bool
-CategoryChapters::add( Chapter *chapter )
+CategoryChapters::add( Chapter* chapter )
 {
     iterator iter = insert( CategoryChapters::value_type(
             chapter->m_date_begin.m_date, chapter ) ).first;
@@ -485,7 +598,7 @@ CategoryChapters::add( Chapter *chapter )
 }
 
 void
-CategoryChapters::clear( void )
+CategoryChapters::clear()
 {
     for( CategoryChapters::iterator iter = begin(); iter != end(); ++iter )
         delete iter->second;
@@ -494,7 +607,7 @@ CategoryChapters::clear( void )
 }
 
 Date
-CategoryChapters::get_free_order_ordinal( void ) const
+CategoryChapters::get_free_order() const
 {
     if( size() > 0 )
     {
@@ -516,7 +629,7 @@ PoolCategoriesChapters::~PoolCategoriesChapters()
 }
 
 void
-PoolCategoriesChapters::clear( void )
+PoolCategoriesChapters::clear()
 {
     for( PoolCategoriesChapters::iterator iter = begin(); iter != end(); ++iter )
         delete( iter->second );
@@ -526,7 +639,6 @@ PoolCategoriesChapters::clear( void )
 
 // THEMES ==========================================================================================
 // STATIC MEMBERS
-ElementShower< Theme > *Theme::shower( NULL );
 const Gdk::RGBA Theme::s_color_match( "#33FF33" );
 const Gdk::RGBA Theme::s_color_match2( "#009900" );
 const Gdk::RGBA Theme::s_color_link( "#3333FF" );
@@ -534,9 +646,8 @@ const Gdk::RGBA Theme::s_color_link2( "#000099" );
 const Gdk::RGBA Theme::s_color_broken( "#FF3333" );
 const Gdk::RGBA Theme::s_color_broken2( "#990000" );
 
-Theme::Theme( DiaryBase * const d, const Glib::ustring &name )
-:   DiaryElement( d, name ),
-    font( ThemeSystem::get()->font ),
+Theme::Theme()
+:   font( ThemeSystem::get()->font ),
     color_base( ThemeSystem::get()->color_base ),
     color_text( ThemeSystem::get()->color_text ),
     color_heading( ThemeSystem::get()->color_heading ),
@@ -545,23 +656,20 @@ Theme::Theme( DiaryBase * const d, const Glib::ustring &name )
 {
 }
 
-Theme::Theme( DiaryBase * const d,
-              const Glib::ustring &name,
-              const Glib::ustring &str_font,
-              const std::string &str_base,
-              const std::string &str_text,
-              const std::string &str_heading,
-              const std::string &str_subheading,
-              const std::string &str_highlight )
-:   DiaryElement( d, name ), font( str_font ), color_base( str_base ), color_text( str_text ),
+Theme::Theme( const Glib::ustring& str_font,
+              const std::string& str_base,
+              const std::string& str_text,
+              const std::string& str_heading,
+              const std::string& str_subheading,
+              const std::string& str_highlight )
+:   font( str_font ), color_base( str_base ), color_text( str_text ),
     color_heading( str_heading ), color_subheading( str_subheading ),
     color_highlight( str_highlight )
 {
 }
 
-Theme::Theme( DiaryBase * const d, const Theme *theme, const Glib::ustring &name )
-:   DiaryElement( d, name ),
-    font( theme->font ),
+Theme::Theme( const Theme* theme )
+:   font( theme->font ),
     color_base( theme->color_base ),
     color_text( theme->color_text ),
     color_heading( theme->color_heading ),
@@ -570,39 +678,18 @@ Theme::Theme( DiaryBase * const d, const Theme *theme, const Glib::ustring &name
 {
 }
 
-const Glib::RefPtr< Gdk::Pixbuf >&
-Theme::get_icon( void ) const
-{
-    return( this == Diary::d->get_default_theme() ?
-            Lifeograph::icons->theme_default_16 : Lifeograph::icons->theme_16 );
-}
-const Glib::RefPtr< Gdk::Pixbuf >&
-Theme::get_icon32( void ) const
-{
-    return( Lifeograph::icons->theme_32 );
-}
-
-void
-Theme::show( void )
-{
-    if( shower != NULL )
-        shower->show( *this );
-    else
-        PRINT_DEBUG( "Theme has no graphical data!" );
-}
-
-ThemeSystem::ThemeSystem( const Glib::ustring &f,
-                          const std::string &cb,
-                          const std::string &ct,
-                          const std::string &ch,
-                          const std::string &csh,
-                          const std::string &chl )
-:   Theme( NULL, STRING::SYSTEM_THEME, f, cb, ct, ch, csh, chl )
+ThemeSystem::ThemeSystem( const Glib::ustring& f,
+                          const std::string& cb,
+                          const std::string& ct,
+                          const std::string& ch,
+                          const std::string& csh,
+                          const std::string& chl )
+:   Theme( f, cb, ct, ch, csh, chl )
 {
 }
 
 ThemeSystem*
-ThemeSystem::get( void )
+ThemeSystem::get()
 {
     static bool s_flag_initialized( false );
     static ThemeSystem *s_theme;
@@ -626,30 +713,172 @@ ThemeSystem::get( void )
     }
 }
 
-// POOLTHEMES ==================================================================
-PoolThemes::~PoolThemes()
+// FILTERS =========================================================================================
+ElementShower< Filter >* Filter::shower( NULL );
+
+Filter::Filter( DiaryBase* const d, const Glib::ustring& name )
+:   DiaryElement( d, ES::FILTER_DEFAULT, name ), m_tag( NULL ),
+    m_date_begin( 0 ), m_date_end( Date::DATE_MAX )
 {
-    for( iterator iter = begin(); iter != end(); ++iter )
-        if( ! iter->second->is_system() )
-            delete iter->second;
+}
+
+const Glib::RefPtr< Gdk::Pixbuf >&
+Filter::get_icon() const
+{
+    return Lifeograph::icons->filter_16;
+}
+
+const Glib::RefPtr< Gdk::Pixbuf >&
+Filter::get_icon32() const
+{
+    return Lifeograph::icons->filter_32;
 }
 
 void
-PoolThemes::clear( void )
+Filter::show()
 {
-    for( iterator iter = begin(); iter != end(); ++iter )
-        if( iter->second->is_system() == false )
-            delete iter->second;
+    if( shower != NULL )
+        shower->show( *this );
+    else
+        PRINT_DEBUG( "Filter has no graphical data!" );
+}
 
-    std::map< Glib::ustring, Theme*, FuncCompareStrings >::clear();
-    // add back the system theme:
-    insert( PoolThemes::value_type( STRING::SYSTEM_THEME, ThemeSystem::get() ) );
+void
+Filter::reset()
+{
+    m_status = ES::FILTER_DEFAULT;
+    m_tag = NULL;
+    m_date_begin = 0;
+    m_date_end = Date::DATE_MAX;
+    m_entries.clear();
+}
+
+void
+Filter::set( const Filter* source )
+{
+    m_status = source->m_status;
+    m_tag = source->m_tag;
+    m_date_begin = source->m_date_begin;
+    m_date_end = source->m_date_end;
+    m_entries = source->m_entries;
+}
+
+void
+Filter::set_tag( const Tag* tag )
+{
+    m_tag = tag;
+
+    if( tag == NULL )
+        m_status &= ( ~ES::FILTER_TAG );
+    else
+        m_status |= ES::FILTER_TAG;
+
+    m_status |= ES::FILTER_OUTSTANDING;
+}
+
+void
+Filter::set_favorites( bool flag_show_fav, bool flag_show_not_fav )
+{
+    // clear previous values
+    m_status &= ( ES::FILTER_FAVORED ^ ES::FILTER_MAX ); // or ( ~ES::FILTER_FAVORED )
+
+    if( flag_show_fav )
+        m_status |= ES::SHOW_FAVORED;
+    if( flag_show_not_fav )
+        m_status |= ES::SHOW_NOT_FAVORED;
+
+    m_status |= ES::FILTER_OUTSTANDING;
+}
+
+void
+Filter::set_trash( bool flag_show_trashed, bool flag_show_not_trashed )
+{
+    // clear previous values
+    m_status &= ( ES::FILTER_TRASHED ^ ES::FILTER_MAX );
+
+    if( flag_show_trashed )
+        m_status |= ES::SHOW_TRASHED;
+    if( flag_show_not_trashed )
+        m_status |= ES::SHOW_NOT_TRASHED;
+
+    m_status |= ES::FILTER_OUTSTANDING;
+}
+
+void
+Filter::set_todo( bool flag_show_todo, bool flag_show_done, bool flag_show_canceled )
+{
+    // clear previous values
+    m_status &= ( ES::FILTER_TODO ^ ES::FILTER_MAX );
+
+    if( flag_show_todo )
+        m_status |= ES::SHOW_TODO;
+    if( flag_show_done )
+        m_status |= ES::SHOW_DONE;
+    if( flag_show_canceled )
+        m_status |= ES::SHOW_CANCELED;
+
+    m_status |= ES::FILTER_OUTSTANDING;
+}
+
+void
+Filter::clear_dates()
+{
+    m_date_begin = 0;
+    m_date_end = Date::DATE_MAX;
+    if( m_status & ES::FILTER_DATE_BEGIN )
+        m_status -= ES::FILTER_DATE_BEGIN;
+    if( m_status & ES::FILTER_DATE_END )
+        m_status -= ES::FILTER_DATE_END;
+
+    m_status |= ES::FILTER_OUTSTANDING;
+}
+
+void
+Filter::set_date_begin( Date::date_t d )
+{
+    m_status |= ES::FILTER_DATE_BEGIN;
+    m_status |= ES::FILTER_OUTSTANDING;
+    m_date_begin = d;
+}
+
+void
+Filter::set_date_end( Date::date_t d )
+{
+    m_status |= ES::FILTER_DATE_END;
+    m_status |= ES::FILTER_OUTSTANDING;
+    m_date_end = d;
+}
+
+void
+Filter::add_entry( Entry* entry )
+{
+    m_status |= ES::FILTER_INDIVIDUAL;
+    m_status |= ES::FILTER_OUTSTANDING;
+    m_entries.insert( entry );
+}
+
+void
+Filter::remove_entry( Entry* entry )
+{
+    if( m_entries.find( entry ) != m_entries.end() )
+    {
+        m_status |= ES::FILTER_OUTSTANDING;
+        m_entries.erase( entry );
+    }
+}
+
+void
+Filter::clear_entries()
+{
+    if( ! m_entries.empty() )
+    {
+        m_status |= ES::FILTER_OUTSTANDING;
+        m_entries.clear();
+    }
 }
 
 bool
-PoolThemes::rename_theme( Theme *theme, const Glib::ustring &new_name )
+Filter::is_entry_filtered( Entry* entry ) const
 {
-    erase( theme->get_name() );
-    theme->set_name( new_name );
-    return( insert( value_type( new_name, theme ) ).second );
+    return( m_entries.find( entry ) != m_entries.end() );
 }
