@@ -38,7 +38,7 @@ class Entry : virtual public DiaryElement
     public:
         static ElementShower< Entry > *shower;
 
-    typedef sigc::signal< void, Entry* >
+        typedef sigc::signal< void, Entry* >
                                 Signal_void_Entry;
 
                                 Entry( DiaryBase * const, const Date::date_t,
@@ -47,72 +47,103 @@ class Entry : virtual public DiaryElement
                                        bool = false );
         virtual                 ~Entry() {}
 
-        void                    show( void );
-        void                    prepare_for_hiding( void );
+        void                    show();
+        void                    prepare_for_hiding();
 
         const Glib::ustring*    get_text() const { return &m_text; }
         Glib::ustring&          get_text() { return m_text; }
         void                    set_text( const Glib::ustring &text )
         { m_text = text; calculate_title( text ); }
 
-        Date                    get_date( void ) const { return m_date; }
-        time_t                  get_date_created( void ) const { return m_date_created; }
-        time_t                  get_date_changed( void ) const { return m_date_changed; }
-        Glib::ustring           get_date_created_str( void ) const;
-        Glib::ustring           get_date_changed_str( void ) const;
+        Date                    get_date() const { return m_date; }
+        time_t                  get_date_created() const { return m_date_created; }
+        time_t                  get_date_changed() const { return m_date_changed; }
+        Glib::ustring           get_date_created_str() const;
+        Glib::ustring           get_date_changed_str() const;
         void                    set_date( Date::date_t date )
         { m_date.m_date = date; }
 
-        int                     get_size( void ) const
+        int                     get_size() const
         { return m_text.size(); }
-        Type                    get_type( void ) const
+        Type                    get_type() const
         { return ET_ENTRY; }
         const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon( void ) const;
+                                get_icon() const;
         const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32( void ) const;
+                                get_icon32() const;
 
         void                    calculate_title( const Glib::ustring& );
 
-        Glib::ustring           get_list_str( void ) const
-        { return Glib::ustring::compose( "%1 -  %2", m_date.format_string(),
-                Glib::Markup::escape_text( m_name ) ); }
+        Glib::ustring           get_list_str() const;
 
-        bool                    get_filtered_out( void );
+        bool                    get_filtered_out();
         void                    set_filtered_out( bool filteredout = true )
-        { m_flag_filteredout = filteredout; }
+        {
+            if( filteredout )
+                m_status |= ES::FILTERED_OUT;
+            else if( m_status & ES::FILTERED_OUT )
+                m_status -= ES::FILTERED_OUT;
+        }
 
-        bool                    is_favored( void ) const { return m_option_favored; }
-        void                    set_favored( bool favored ) { m_option_favored = favored; }
+        bool                    is_favored() const { return( m_status & ES::FAVORED ); }
+        void                    set_favored( bool favored )
+        {
+            if( favored )
+            {
+                m_status |= ES::FAVORED;
+                m_status &= ( ~ES::NOT_FAVORED );
+            }
+            else
+            {
+                m_status |= ES::NOT_FAVORED;
+                m_status &= ( ~ES::FAVORED );
+            }
+        }
+        void                    toggle_favored()
+        { m_status ^= ES::FILTER_FAVORED; }
 
-        std::string             get_lang( void ) const { return m_option_lang; }
-        std::string             get_lang_final( void ) const {
+        std::string             get_lang() const { return m_option_lang; }
+        std::string             get_lang_final() const {
             return m_option_lang == LANG_INHERIT_DIARY ?
                     m_ptr2diary->get_lang() : m_option_lang; }
         void                    set_lang( const std::string &lang ) { m_option_lang = lang; }
 
-        bool                    is_trashed( void ) const { return m_option_trashed; }
-        void                    set_trashed( bool trashed ) { m_option_trashed = trashed; }
+        bool                    is_trashed() const { return( m_status & ES::TRASHED ); }
+        void                    set_trashed( bool trashed )
+        {
+            if( trashed )
+            {
+                m_status |= ES::TRASHED;
+                m_status &= ( ~ES::NOT_TRASHED );
+            }
+            else
+            {
+                m_status |= ES::NOT_TRASHED;
+                m_status &= ( ~ES::TRASHED );
+            }
+        }
 
         void                    set_tags( const Tagset& );
-        const Tagset&           get_tags( void ) const;
-        Tagset&                 get_tags( void );
+        const Tagset&           get_tags() const;
+        Tagset&                 get_tags();
         bool                    add_tag( Tag* );
         bool                    remove_tag( Tag* );
+        bool                    clear_tags();
 
-        // NULL means theme is not set
-        const Theme*            get_theme( void ) const
-        {
-            if( m_ptr2theme == NULL )   // FIXME: is this necessary?
-                throw LIFEO::Error( "Illegal theme request" );
-            return m_ptr2theme;
-        }
-        void                    set_theme( const Theme *theme )
-        { m_ptr2theme = theme; }
-        void                    unset_theme( void )
-        { m_ptr2theme = NULL; }
-        bool                    get_theme_is_set( void ) const
-        { return( m_ptr2theme != NULL ); }
+        // THEMES
+        const Theme*            get_theme() const;
+        const Tag*              get_theme_tag() const
+        { return m_ptr2theme_tag; }
+        void                    set_theme_tag( const Tag* );
+        bool                    get_theme_is_set() const
+        { return( m_ptr2theme_tag != NULL ); }
+        void                    update_theme(); // called when a tag gained or lost custom theme
+
+        bool                    is_todo() const
+        { return m_date.is_todo(); }
+        ElemStatus              get_todo_status() const
+        { return( m_status & ES::FILTER_TODO ); }
+        void                    set_todo_status( ElemStatus );
 
     protected:
         Date                    m_date;
@@ -120,12 +151,9 @@ class Entry : virtual public DiaryElement
         time_t                  m_date_changed;
         Glib::ustring           m_text;
         Tagset                  m_tags;
-        const Theme             *m_ptr2theme;
+        const Tag*              m_ptr2theme_tag; // NULL means theme is not set
 
-        bool                    m_option_favored;
         std::string             m_option_lang;  // empty means off
-        bool                    m_option_trashed;
-        bool                    m_flag_filteredout;
 
     friend class Diary; // TODO: remove this friendship too??
     friend class DiaryView; // TODO: remove this friendship too??
@@ -136,11 +164,11 @@ class Entry : virtual public DiaryElement
 class PoolEntries : public std::map< Date::date_t, Entry*, FuncCompareDates >
 {
     public:
-                                    PoolEntries( void )
+                                    PoolEntries()
         :   std::map< Date::date_t, Entry*, FuncCompareDates >( compare_dates ) {}
                                     ~PoolEntries();
 
-        void                        clear( void );
+        void                        clear();
 };
 
 } // end of namespace LIFEO
