@@ -338,7 +338,7 @@ EntryParser::set_search_str( const Glib::ustring &str )
 
 // TRIGGERERS ======================================================================================
 void
-EntryParser::trigger_subheading( void )
+EntryParser::trigger_subheading()
 {
     if( m_cc_last == CC_NEWLINE )
     {
@@ -350,14 +350,14 @@ EntryParser::trigger_subheading( void )
 }
 
 void
-EntryParser::apply_subheading_0( void )
+EntryParser::apply_subheading_0()
 {
     m_applier_nl = &EntryParser::apply_subheading_end;
     apply_subheading();
 }
 
 void
-EntryParser::trigger_bold( void )
+EntryParser::trigger_bold()
 {
     if( m_cc_last & CC_NOT_SEPARATOR )
         return;
@@ -370,7 +370,7 @@ EntryParser::trigger_bold( void )
 }
 
 void
-EntryParser::trigger_italic( void )
+EntryParser::trigger_italic()
 {
     if( m_cc_last & CC_NOT_SEPARATOR )
         return;
@@ -383,7 +383,7 @@ EntryParser::trigger_italic( void )
 }
 
 void
-EntryParser::trigger_strikethrough( void )
+EntryParser::trigger_strikethrough()
 {
     if( m_cc_last & CC_NOT_SEPARATOR )
         return;
@@ -396,7 +396,7 @@ EntryParser::trigger_strikethrough( void )
 }
 
 void
-EntryParser::trigger_highlight( void )
+EntryParser::trigger_highlight()
 {
     if( m_cc_last & CC_NOT_SEPARATOR )
         return;
@@ -409,7 +409,7 @@ EntryParser::trigger_highlight( void )
 }
 
 void
-EntryParser::trigger_comment( void )
+EntryParser::trigger_comment()
 {
     m_chars_looked_for.clear();
     m_chars_looked_for.push_back( AbsChar( CF_SBB|CF_IMMEDIATE, NULL ) );
@@ -420,7 +420,7 @@ EntryParser::trigger_comment( void )
 }
 
 void
-EntryParser::trigger_link( void )
+EntryParser::trigger_link()
 {
     PRINT_DEBUG( "word_last: " + word_last );
     m_flag_hidden_link = word_last[ 0 ] == '<';
@@ -484,7 +484,7 @@ EntryParser::trigger_link( void )
 }
 
 void
-EntryParser::trigger_link_at( void )
+EntryParser::trigger_link_at()
 {
     PRINT_DEBUG( "word_last [@]: " + word_last );
     if( m_cc_last & CC_SEPARATOR )
@@ -501,7 +501,7 @@ EntryParser::trigger_link_at( void )
 }
 
 void
-EntryParser::trigger_link_date( void )
+EntryParser::trigger_link_date()
 {
     m_cc_req = CC_ANY;
     m_chars_looked_for.clear();
@@ -532,7 +532,7 @@ EntryParser::trigger_link_date( void )
 }
 
 void
-EntryParser::trigger_list( void )
+EntryParser::trigger_list()
 {
     if( m_cc_last != CC_NEWLINE )
         return;
@@ -544,7 +544,7 @@ EntryParser::trigger_list( void )
 }
 
 void
-EntryParser::trigger_ignore( void )
+EntryParser::trigger_ignore()
 {
     if( m_cc_last == CC_NEWLINE )
     {
@@ -558,7 +558,7 @@ EntryParser::trigger_ignore( void )
 }
 
 void
-EntryParser::junction_link_date( void )
+EntryParser::junction_link_date()
 {
     date_last.set_day( int_last );
 
@@ -578,7 +578,7 @@ EntryParser::junction_link_date( void )
 }
 
 void
-EntryParser::junction_link_hidden_tab( void )
+EntryParser::junction_link_hidden_tab()
 {
     m_chars_looked_for.pop_front();
     pos_tab = pos_current + 1;
@@ -586,7 +586,7 @@ EntryParser::junction_link_hidden_tab( void )
 }
 
 void
-EntryParser::junction_list( void )
+EntryParser::junction_list()
 {
     m_chars_looked_for.front().flags = CF_SPACE|CF_IMMEDIATE;
     m_cc_req = CC_ANY;
@@ -607,7 +607,7 @@ EntryParser::junction_list( void )
 }
 
 void
-EntryParser::junction_date_dotym( void )
+EntryParser::junction_date_dotym()
 {
     if( int_last >= Date::YEAR_MIN && int_last <= Date::YEAR_MAX )
     {
@@ -622,7 +622,7 @@ EntryParser::junction_date_dotym( void )
 }
 
 void
-EntryParser::junction_date_dotmd( void )
+EntryParser::junction_date_dotmd()
 {
     if( int_last >= 1 && int_last <= 12 &&
     // two separators must be the same:
@@ -639,7 +639,7 @@ EntryParser::junction_date_dotmd( void )
 }
 
 void
-EntryParser::junction_ignore( void )
+EntryParser::junction_ignore()
 {
 //    m_applier_nl = &EntryParser::apply_ignore_end;
     m_chars_looked_for.front().flags = CF_IGNORE;
@@ -650,7 +650,7 @@ EntryParser::junction_ignore( void )
 // TODO: this is a temporary solution until begin and end appliers, and junction functions will
 // be bundled in a class also eliminating the need for separate deques for all of them:
 void
-EntryParser::apply_check_ccl_0( void )
+EntryParser::apply_check_ccl_0()
 {
     m_applier_nl = &EntryParser::apply_check_ccl_end;
     apply_check_ccl();
@@ -658,7 +658,7 @@ EntryParser::apply_check_ccl_0( void )
 
 // HELPERS =========================================================================================
 inline void
-EntryParser::handle_number( void )
+EntryParser::handle_number()
 {
     if( m_cc_last == CC_NUMBER )
     {
