@@ -36,14 +36,6 @@
 
 #include <gtkmm.h>
 
-#include <libintl.h>
-
-// DEFINITIONS FOR LIBGETTEXT
-#define _(String)               gettext(String)
-#define gettext_noop(String)    String
-#define N_(String)              gettext_noop(String)
-// END OF LIBGETTEXT DEFINITIONS
-
 
 namespace HELPERS
 {
@@ -68,13 +60,24 @@ static const int        RESPONSE_GO         = 1;
 class Date
 {
     public:
-        static const unsigned int   YEAR_MAX         = 2199;
-        static const unsigned int   YEAR_MIN         = 1900;
-        static const unsigned long  ORDINAL_FLAG     = 0x80000000;
         static const unsigned long  NOTSET           = 0xFFFFFFFF;
         static const unsigned long  DATE_MAX         = 0xFFFFFFFF;
-        static const unsigned long  ORDINAL_STEP     = 0x400;
         static const unsigned long  YEARMONTH_FILTER = 0x7FFF8000;
+        static const unsigned int   YEAR_MAX         = 2199;
+        static const unsigned int   YEAR_MIN         = 1900;
+
+        static const unsigned int   ORDER_FILTER     = 0x3FF;
+
+        static const unsigned long  ORDINAL_STEP     = 0x400;
+        static const unsigned long  ORDINAL_FLAG     = 0x80000000;
+        static const unsigned long  ORDINAL_FILTER   = 0x1FFFFC00;
+        static const unsigned long  TOPIC_MAX        = ORDINAL_FILTER;
+        static const unsigned long  TOPIC_NO_FLAGS_FILTER   = ORDINAL_FILTER|ORDER_FILTER;
+
+        static const unsigned long  TODO_FLAG        = 0x40000000;
+        static const unsigned long  TODO_FILTER      = TODO_FLAG;
+
+        static std::string          s_date_format_template;
 
         typedef unsigned long date_t;
 
@@ -109,35 +112,54 @@ class Date
                                     Date( unsigned int o1, unsigned int o2 )
             :   m_date( ORDINAL_FLAG | ( o1 << 10 ) | o2 ) {}
 
-        static date_t               get_today( int order = 0 ) {
+        static date_t               get_today( int order = 0 )
+        {
             time_t t = time( NULL );
             struct tm *ti = localtime( &t );
             return make_date( ti->tm_year + 1900, ti->tm_mon + 1, ti->tm_mday, order );
         }
 
-        date_t                      get_pure( void ) const
+        void                        set_now( int order = 0 )
+        { m_date = get_today( order ); }
+
+        date_t                      get_pure() const
         { return( m_date & 0xFFFFFC00 ); }
         static date_t               get_pure( const date_t d )
         { return( d & 0xFFFFFC00 ); }
 
-        date_t                      get_yearmonth( void ) const
+        date_t                      get_sort() const
+        {
+            // TODO: this is a temporary function. will be removed when default flags get adjusted
+            // as per sorting order in the new diary version
+            if( is_ordinal() )
+            {
+                if( is_todo() )
+                    return( ( m_date & TOPIC_NO_FLAGS_FILTER ) | ORDINAL_FLAG );
+                else
+                    return( m_date | TODO_FLAG );
+            }
+            else
+                return( m_date );
+        }
+
+        date_t                      get_yearmonth() const
         { return( m_date & YEARMONTH_FILTER ); }
         static date_t               get_yearmonth( const date_t d )
         { return( d & YEARMONTH_FILTER ); }
 
-        unsigned int                get_year( void ) const
+        unsigned int                get_year() const
         { return ( ( m_date & 0x7FF80000 ) >> 19 ); }
         static unsigned int         get_year( const date_t d )
         { return ( ( d & 0x7FF80000 ) >> 19 ); }
 
-        Glib::ustring               get_year_str( void ) const;
-        Glib::ustring               get_month_str( void ) const;
-        Glib::ustring               get_day_str( void ) const;
-        Glib::ustring               get_weekday_str( void ) const;
+        Glib::ustring               get_year_str() const;
+        Glib::ustring               get_month_str() const;
+        Glib::ustring               get_day_str() const;
+        Glib::ustring               get_weekday_str() const;
 
-        unsigned int                get_days_in_month( void ) const;
+        unsigned int                get_days_in_month() const;
 
-        bool                        is_leap_year( void ) const
+        bool                        is_leap_year() const
         {
             int year( get_year() );
             if( ( year % 400 ) == 0 )
@@ -150,35 +172,36 @@ class Date
             return false;
         }
 
-        unsigned int                get_month( void ) const
+        unsigned int                get_month() const
         { return( ( m_date & 0x78000 ) >> 15 ); }
         static unsigned int         get_month( const date_t d )
         { return( ( d & 0x78000 ) >> 15 ); }
 
-        Glib::Date::Month           get_month_glib( void ) const;
+        Glib::Date::Month           get_month_glib() const;
 
-        unsigned int                get_day( void ) const
+        unsigned int                get_day() const
         { return( ( m_date & 0x7C00 ) >> 10 ); }
         static unsigned int         get_day( const date_t d )
         { return( ( d & 0x7C00 ) >> 10 ); }
 
-        unsigned int                get_order( void ) const
-        { return( m_date & 0x3FF ); }
+        unsigned int                get_order() const
+        { return( m_date & ORDER_FILTER ); }
         static unsigned int         get_order( const date_t d )
-        { return( d & 0x3FF ); }
+        { return( d & ORDER_FILTER ); }
 
-        unsigned int                get_ordinal_order( void ) const
-        { return( ( m_date & 0x7FFFFC00) >> 10 ); }
+        unsigned int                get_ordinal_order() const
+        { return( ( m_date & ORDINAL_FILTER ) >> 10 ); }
         static unsigned int         get_ordinal_order( const date_t d )
-        { return( ( d & 0x7FFFFC00) >> 10 ); }
+        { return( ( d & ORDINAL_FILTER ) >> 10 ); }
 
-        static Date::date_t         get_order_begin( void ) {
+        static Date::date_t         get_order_begin() {
             return ORDINAL_FLAG;
         }
 
-        Glib::Date                  get_glib( void ) const
+        Glib::Date                  get_glib() const
         { return Glib::Date( get_day(), get_month_glib(), get_year() ); }
-        time_t                      get_ctime( void ) const;
+        time_t                      get_ctime() const
+        { return get_ctime( m_date ); }
         static time_t               get_ctime( const date_t );
 
         void                        set_year( unsigned int y )
@@ -198,42 +221,50 @@ class Date
             if( d < 32 )
                 m_date |= ( d << 10 );
         }
-        void                        reset_order_0( void )
+        void                        reset_order_0()
         { m_date &= 0xFFFFFC00; }
-        void                        reset_order_1( void )
+        void                        reset_order_1()
         { m_date |= 0x1; m_date &= 0xFFFFFC01; }
         static void                 reset_order_1( date_t &date )
         { date |= 0x1; date &= 0xFFFFFC01; }
 
-        Glib::ustring               format_string( void ) const;
-        static Glib::ustring        format_string( const date_t );
-        static Glib::ustring        format_string( const time_t );
-        static Glib::ustring        format_string_do( const time_t );
+        Glib::ustring               format_string() const
+        { return format_string( m_date, s_date_format_template ); }
+        static Glib::ustring        format_string( const date_t date )
+        { return format_string( date, s_date_format_template ); }
+        static Glib::ustring        format_string( const date_t, const std::string& );
+        static Glib::ustring        format_string_dt( const time_t );
+        static Glib::ustring        format_string_d( const time_t );
 
         static date_t               parse_string( const Glib::ustring& );
 
-        bool                        is_valid( void ) const
+        bool                        is_valid() const
         {
             return( get_day() > 0 && get_day() <= get_days_in_month() );
         }
 
-        bool                        is_ordinal( void ) const
+        bool                        is_todo() const
+        { return( m_date & TODO_FLAG ); }
+        static bool                 is_todo( const date_t d )
+        { return( d & TODO_FLAG ); }
+
+        bool                        is_ordinal() const
         { return( m_date & ORDINAL_FLAG ); }
         static bool                 is_ordinal( const date_t d )
         { return( d & ORDINAL_FLAG ); }
 
         void                        forward_months( int months );
-        void                        forward_month( void );
-        void                        forward_day( void );
+        void                        forward_month();
+        void                        forward_day();
 
-        void                        backward_ordinal_order( void )
+        void                        backward_ordinal_order()
         { if( get_ordinal_order() > 0 ) m_date -= ORDINAL_STEP; }
         static void                 backward_ordinal_order( Date::date_t &d )
         { if( get_ordinal_order( d ) > 0 ) d -= ORDINAL_STEP; }
-        void                        forward_ordinal_order( void )
-        { m_date += ORDINAL_STEP; }
+        void                        forward_ordinal_order()
+        { if( ( m_date & ORDINAL_FILTER ) != TOPIC_MAX ) m_date += ORDINAL_STEP; }
         static void                 forward_ordinal_order( Date::date_t &d )
-        { d += ORDINAL_STEP; }
+        { if( ( d & ORDINAL_FILTER ) != TOPIC_MAX ) d += ORDINAL_STEP; }
 
         static date_t               make_year( unsigned int y )
         { return( y << 19 ); }
@@ -313,10 +344,9 @@ convert_gdkrgba_to_string( const Gdk::RGBA &gdkcolor )
 }
 std::ios::pos_type  get_file_size( std::ifstream& );
 
-void                open_url( Gtk::AboutDialog&, const Glib::ustring& );
-void                mail_to( Gtk::AboutDialog&, const Glib::ustring& );
+bool                copy_file_suffix( const std::string&, const std::string&, int );
 
-std::string         get_env_lang( void );
+std::string         get_env_lang();
 
 Gtk::MenuItem*      create_menuitem_markup( const Glib::ustring&,
                                             const Glib::SignalProxy0< void >::SlotType& );
@@ -333,7 +363,7 @@ class Pool : public std::list< T* >
         virtual                 ~Pool()
         { clear(); }
 
-        void                    clear( void )
+        void                    clear()
         {
             for(    typename std::list< T* >::const_iterator iter = this->begin();
                     iter != this->end();
@@ -357,7 +387,7 @@ class Cipher
         static const int    cKEY_SIZE           = 32; // = 256 bits
         static const int    cHASH_ALGORITHM     = GCRY_MD_SHA256;
 
-        static bool         init( void );
+        static bool         init();
 
         static void         create_iv( unsigned char** );
         static void         expand_key( char const*,
@@ -389,11 +419,13 @@ class EntryClear : public Gtk::Entry
 
     protected:
         void                handle_clear_icon( Gtk::EntryIconPosition, const GdkEventButton* );
-        virtual void        on_changed( void );
+        virtual void        on_changed();
         virtual bool        on_key_release_event( GdkEventKey* );
 };
 
 // MENU 2 ==========================================================================================
+#if( GTKMM_MAJOR_VERSION < 3 )
+
 class Menu2 : public Gtk::Menu
 {
     public:
@@ -422,12 +454,12 @@ class Menubutton : public Gtk::ToggleButton
                                         Menu2* = NULL );
                             Menubutton( BaseObjectType*,
                                         const Glib::RefPtr< Gtk::Builder >& );
-        virtual             ~Menubutton( void );
+        virtual             ~Menubutton();
 
-        Menu2*              get_menu( void ) const;
+        Menu2*              get_menu() const;
         void                set_menu( Menu2* );
-        bool                clear_menu( void );
-        void                release( void );
+        bool                clear_menu();
+        void                release();
 
         void                set_label( const Glib::ustring& );
         void                get_menu_position( int&, int&, bool& );
@@ -445,6 +477,8 @@ class Menubutton : public Gtk::ToggleButton
     private:
 };
 
+#endif
+
 /*
  * TO BE REWRITTEN IF NEEDED IN THE FUTURE...
 class Menutoolbutton : public Gtk::ToolItem
@@ -453,15 +487,17 @@ class Menutoolbutton : public Gtk::ToolItem
         Menutoolbutton( const Gtk::StockID&, const std::string&,
                         Menu2* = NULL, bool = false );
 
-        Menu2*          get_menu( void );
+        Menu2*          get_menu();
 
     protected:
-        void            on_toolbar_reconfigured( void );
+        void            on_toolbar_reconfigured();
 
         bool            m_flag_important;
         Menubutton      m_button;
 };*/
 
+#if( GTKMM_MAJOR_VERSION < 3 )
+
 // FILE FILTERS
 //class FilefilterAny : public Gtk::FileFilter
 //{
@@ -491,7 +527,7 @@ class MenuitemRecent : public Gtk::MenuItem
 
                                     MenuitemRecent( const std::string& );
 
-        Signal_void_string          signal_removerecent( void )
+        Signal_void_string          signal_removerecent()
         { return m_signal_removerecent; }
 
     protected:
@@ -507,8 +543,6 @@ class MenuitemRecent : public Gtk::MenuItem
         Signal_void_string          m_signal_removerecent;
 };
 
-#if( GTKMM_MAJOR_VERSION < 3 )
-
 class FilebuttonRecent : public Menubutton
 {
     public:
@@ -522,29 +556,29 @@ class FilebuttonRecent : public Menubutton
 
         void                        set( ListPaths* );
 
-        ListPaths*                  get_recentlist( void )
+        ListPaths*                  get_recentlist()
         {
             return m_list_recent;
         }
-        std::string                 get_filename( void ) const;
+        std::string                 get_filename() const;
         std::string                 get_filename_recent( int ) const;
         void                        set_filename( const std::string& );
-        void                        update_filenames( void );
+        void                        update_filenames();
 
         bool                        add_recent( const std::string& );
         void                        remove_recent( const std::string& );
 
-        void                        show_filechooser( void );
+        void                        show_filechooser();
 
-        SignalVoid                  signal_selection_changed( void );
-        SignalVoid                  signal_create_file( void );
+        SignalVoid                  signal_selection_changed();
+        SignalVoid                  signal_create_file();
 
         bool                        handle_motion_notify( GdkEventMotion* );
 
         static Glib::ustring        fallback_label;
 
     protected:
-        virtual void                on_create_file( void );
+        virtual void                on_create_file();
         virtual void                on_size_allocate( Gtk::Allocation& );
         virtual void                on_drag_data_received(
                                             const Glib::RefPtr<Gdk::DragContext>&,
@@ -559,6 +593,7 @@ class FilebuttonRecent : public Menubutton
         SignalVoid                  m_signal_selectionchanged;
         SignalVoid                  m_signal_createfile;
 };
+
 #endif
 
 // DIALOGEVENT =====================================================================================
@@ -571,12 +606,13 @@ class DialogEvent : public Gtk::Dialog
 
     protected:
         bool                on_event( GdkEvent* );
-        void                handle_logout( void );
+        void                handle_logout();
 
 };
 
 // COMBOBOXTEXT WITH GTK BUILDER (FOR GTKMM 2) =====================================================
 #if( GTKMM_MAJOR_VERSION < 3 )
+
 class ComboboxEasy : public Gtk::ComboBoxText
 {
     public:
@@ -589,6 +625,11 @@ class ComboboxEasy : public Gtk::ComboBoxText
 // FRAME FOR PRINTING ==============================================================================
 Gtk::Frame* create_frame( const Glib::ustring&, Gtk::Widget& );
 
+// TREEVIEW ========================================================================================
+// scroll_to_row( Path& ) does not work for some reason. So, implemented our own
+bool treepath_is_less( const Gtk::TreePath&, const Gtk::TreePath& );
+bool treepath_is_more( const Gtk::TreePath&, const Gtk::TreePath& );
+
 } // end of namespace HELPERS
 
 #endif
