@@ -36,24 +36,14 @@
 
 namespace LIFEO
 {
+
     static const char   PROGRAM_NAME[]              = "Lifeograph";
 
     static const int    BACKUP_INTERVAL             = 30;    // seconds
     static const int    LOGOUT_COUNTDOWN            = 10;    // seconds
 
-    static const char   TARGET_ENTRY_DIARY[]        = "GTK_TREE_MODEL_ROW_DIARY";
     static const char   TARGET_ENTRY_TAG[]          = "GTK_TREE_MODEL_ROW_TAG";
-    static const char   TARGET_ENTRY_THEME[]        = "GTK_TREE_MODEL_ROW_THEME";
     static const char   TARGET_ENTRY_ENTRY[]        = "GTK_TREE_MODEL_ROW_ENTRY";
-    static const char   TARGET_ENTRY_CHAPTER[]      = "GTK_TREE_MODEL_ROW_CHAPTER";
-
-    // GENERIC STRINGS
-    namespace STRING
-    {
-        static const char OFF[] = N_( "Off" );
-        // TRANSLATORS: title of an empty diary entry
-        static const char EMPTY_ENTRY_TITLE[] = N_( "<empty entry>" );
-    }
 
 struct Icons
 {
@@ -65,16 +55,24 @@ struct Icons
     Glib::RefPtr< Gdk::Pixbuf >     entry_favorite_32;
     Glib::RefPtr< Gdk::Pixbuf >     tag_16;
     Glib::RefPtr< Gdk::Pixbuf >     tag_32;
+    Glib::RefPtr< Gdk::Pixbuf >     tag_theme_16;
+    Glib::RefPtr< Gdk::Pixbuf >     tag_theme_32;
     Glib::RefPtr< Gdk::Pixbuf >     tag_category_16;
     Glib::RefPtr< Gdk::Pixbuf >     tag_category_32;
+    Glib::RefPtr< Gdk::Pixbuf >     untagged_16;
+    Glib::RefPtr< Gdk::Pixbuf >     untagged_32;
     Glib::RefPtr< Gdk::Pixbuf >     chapter_16;
     Glib::RefPtr< Gdk::Pixbuf >     chapter_32;
-    Glib::RefPtr< Gdk::Pixbuf >     theme_16;
-    Glib::RefPtr< Gdk::Pixbuf >     theme_default_16;
-    Glib::RefPtr< Gdk::Pixbuf >     theme_32;
     Glib::RefPtr< Gdk::Pixbuf >     month_16;
     Glib::RefPtr< Gdk::Pixbuf >     month_32;
     Glib::RefPtr< Gdk::Pixbuf >     filter_16;
+    Glib::RefPtr< Gdk::Pixbuf >     filter_32;
+    Glib::RefPtr< Gdk::Pixbuf >     todo_open_16;
+    Glib::RefPtr< Gdk::Pixbuf >     todo_open_32;
+    Glib::RefPtr< Gdk::Pixbuf >     todo_done_16;
+    Glib::RefPtr< Gdk::Pixbuf >     todo_done_32;
+    Glib::RefPtr< Gdk::Pixbuf >     todo_canceled_16;
+    Glib::RefPtr< Gdk::Pixbuf >     todo_canceled_32;
 };
 
 typedef std::set< std::string > LanguageList;
@@ -95,20 +93,20 @@ class Lifeograph : public Gtk::Application
 
 
         static Glib::RefPtr< Lifeograph >
-                                    create( void );
+                                    create();
 
-        static bool                 quit( void );
+        static bool                 quit();
 
                                     Lifeograph();
         virtual                     ~Lifeograph();
-        static Lifeograph           *p; // static pointer
+        static Lifeograph*          p; // static pointer
 
-        void                        on_startup( void );
-        void                        on_activate( void );
+        void                        on_startup();
+        void                        on_activate();
         int             on_command_line( const Glib::RefPtr< Gio::ApplicationCommandLine >& );
 
         static Settings             settings;
-        static Icons                *icons;
+        static Icons*               icons;
 
         static Glib::RefPtr< Gtk::Builder >
                                     builder;
@@ -149,10 +147,10 @@ class Lifeograph : public Gtk::Application
         bool                        load_gui( const std::string& );
 
         // AUTO LOGOUT FUNCTIONALITY
-        bool                        handle_idle( void );
-        void                        handle_event( void );
-        void                        freeze_auto_logout( void );
-        void                        unfreeze_auto_logout( void );
+        bool                        handle_idle();
+        void                        handle_event();
+        void                        freeze_auto_logout();
+        void                        unfreeze_auto_logout();
 
         int                         m_seconds_remaining;
         sigc::connection            m_connection_timeout;
@@ -166,11 +164,14 @@ class Lifeograph : public Gtk::Application
                                     drag_targets_tag;
         std::vector< Gtk::TargetEntry >
                                     drag_targets_entry;
-        static DiaryElement         *s_elem_dragged;
+        static DiaryElement*        s_elem_dragged;
         static bool                 s_flag_dragging;
 
+        // COLORS
+        static std::string          s_color_insensitive;
+
         // ENCHANT
-        static EnchantBroker        *s_enchant_broker;
+        static EnchantBroker*       s_enchant_broker;
         static LanguageList         s_lang_list;
 
         static std::set< std::string > stock_diaries;
@@ -178,7 +179,7 @@ class Lifeograph : public Gtk::Application
         static Glib::RefPtr< Gdk::Pixbuf >
                                     get_thumbnail( const std::string&, int );
 
-        static SignalVoid           signal_logout( void )
+        static SignalVoid           signal_logout()
         { return s_signal_logout; }
 
         static Glib::RefPtr< Gtk::ActionGroup >
