@@ -36,7 +36,7 @@
 using namespace LIFEO;
 
 
-PanelDiary::PanelDiary( void )
+PanelDiary::PanelDiary()
 : m_entry_count( 0 )
 {
     Gtk::Button *button_today;
@@ -45,9 +45,8 @@ PanelDiary::PanelDiary( void )
         Lifeograph::builder->get_widget( "button_logout", m_button_logout );
         Lifeograph::builder->get_widget( "button_today", button_today );
 
-        Menubutton *mb_tools;
-        Menubutton::s_builder_name = "menubutton_tools";
-        Lifeograph::builder->get_widget_derived( Menubutton::s_builder_name, mb_tools );
+        Gtk::MenuButton *mb_tools;
+        Lifeograph::builder->get_widget( "menubutton_tools", mb_tools );
         Lifeograph::builder->get_widget( "menuitem_sort_by_date", m_menuitem_sort_by_date );
         Lifeograph::builder->get_widget( "menuitem_sort_by_size", m_menuitem_sort_by_size );
         Lifeograph::builder->get_widget( "menuitem_sort_by_change", m_menuitem_sort_by_change );
@@ -62,36 +61,20 @@ PanelDiary::PanelDiary( void )
             mb_tools->set_image( *img_tools );
         }
 
-        Lifeograph::builder->get_widget( "togglebtn_filter_favorites",
-                                        m_togglebtn_filter_favorites );
-        Lifeograph::builder->get_widget( "togglebtn_filter_trash", m_togglebtn_filter_trash );
-        Lifeograph::builder->get_widget( "button_remove_filters", m_button_remove_filters );
-
         Lifeograph::builder->get_widget( "calendar_main", m_calendar );
         Lifeograph::builder->get_widget_derived( "treeview_main", m_treeview_entries );
-        Lifeograph::builder->get_widget_derived( "entry_filter", m_entry_filter );
-        Lifeograph::builder->get_widget_derived( "entry_replace", m_entry_replace );
-        Lifeograph::builder->get_widget( "button_match_prev", m_button_match_prev );
-        Lifeograph::builder->get_widget( "button_match_next", m_button_match_next );
-        Lifeograph::builder->get_widget( "button_replace", m_button_replace );
-        Lifeograph::builder->get_widget( "button_replace_all", m_button_replace_all );
-        Lifeograph::builder->get_widget( "hbox_toolbar_replace", m_toolbar_replace );
 
-        Menubutton::s_builder_name = "menubutton_diary_add";
-        Lifeograph::builder->get_widget_derived( Menubutton::s_builder_name, m_button_add );
+        Lifeograph::builder->get_widget( "menubutton_diary_add", m_button_add );
         Lifeograph::builder->get_widget( "mnitem_add_entry", m_menuitem_add_entry );
-        Lifeograph::builder->get_widget( "mnitem_add_chapter", m_menuitem_add_chapter );
         Lifeograph::builder->get_widget( "mnitem_add_topic", m_menuitem_add_topic );
+        Lifeograph::builder->get_widget( "mnitem_add_todo_group", m_menuitem_add_todo_group );
+        Lifeograph::builder->get_widget( "mnitem_add_chapter", m_menuitem_add_chapter );
     }
     catch( ... )
     {
         throw LIFEO::Error( "Failed to create the diary panel" );
     }
 
-    // FILTER & REPLACE
-    m_entry_filter->set_placeholder_text( _( "Filter" ) );
-    m_entry_replace->set_placeholder_text( _( "Replace" ) );
-
     // SIGNALS
     m_button_logout->signal_clicked().connect(
             sigc::bind( sigc::mem_fun( AppWindow::p, &AppWindow::logout ), true ) );
@@ -112,15 +95,6 @@ PanelDiary::PanelDiary( void )
                                    &WidgetEntryList::handle_sorting_criteria_changed ),
                     SC_CHANGE ) );
 
-    m_togglebtn_filter_favorites->signal_toggled().connect(
-            sigc::mem_fun( this, &PanelDiary::handle_filter_favorites_toggled ) );
-
-    m_togglebtn_filter_trash->signal_toggled().connect(
-            sigc::mem_fun( this, &PanelDiary::handle_filter_trash_toggled ) );
-
-    m_button_remove_filters->signal_clicked().connect(
-            sigc::mem_fun( this, &PanelDiary::remove_filters ) );
-
     m_calendar->signal_day_selected_double_click().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_entry ) );
     m_calendar->signal_month_changed().connect(
@@ -128,19 +102,7 @@ PanelDiary::PanelDiary( void )
     m_calendar->signal_day_selected().connect(
             sigc::mem_fun( this, &PanelDiary::handle_calendar_dayselected ) );
 
-    m_entry_filter->signal_changed().connect(
-            sigc::mem_fun( this, &PanelDiary::handle_entry_filter_changed ) );
-    m_entry_filter->signal_activate().connect(
-            sigc::mem_fun( this, &PanelDiary::go_next_match ) );
-
-    m_entry_replace->signal_activate().connect(
-            sigc::mem_fun( this, &PanelDiary::replace_match ) );
-    m_button_replace->signal_clicked().connect(
-            sigc::mem_fun( this, &PanelDiary::replace_match ) );
-    m_button_replace_all->signal_clicked().connect(
-            sigc::mem_fun( this, &PanelDiary::replace_all_matches ) );
-
-    m_treeview_entries->signal_row_expanded().connect(
+     m_treeview_entries->signal_row_expanded().connect(
             sigc::mem_fun( this, &PanelDiary::handle_treeview_row_expanded ) );
     m_treeview_entries->signal_row_collapsed().connect(
             sigc::mem_fun( this, &PanelDiary::handle_treeview_row_expanded ) );
@@ -149,6 +111,8 @@ PanelDiary::PanelDiary( void )
             sigc::mem_fun( this, &PanelDiary::handle_add_entry ) );
     m_menuitem_add_topic->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_topic ) );
+    m_menuitem_add_todo_group->signal_activate().connect(
+            sigc::mem_fun( this, &PanelDiary::handle_add_todo_group ) );
     m_menuitem_add_chapter->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_chapter ) );
 
@@ -160,12 +124,6 @@ PanelDiary::PanelDiary( void )
             sigc::mem_fun( this, &PanelDiary::show_today ),
             button_today );
 
-    Lifeograph::create_action(
-            false, m_action_focusfilter, "FocusFilter",
-            Gtk::Stock::FIND, "", "",     // no grachical interface yet!
-            Gtk::AccelKey( GDK_KEY_f, Gdk::CONTROL_MASK ),
-            sigc::mem_fun( m_entry_filter, &Gtk::Widget::grab_focus ) );
-
     Lifeograph::create_action(
             false, m_action_previous_list, "ListPrevious", Gtk::Stock::GO_UP, _( "Previous" ),
             _( "Go to the previous entry in the list" ),
@@ -178,24 +136,6 @@ PanelDiary::PanelDiary( void )
             Gtk::AccelKey( GDK_KEY_Page_Down, Gdk::CONTROL_MASK ),
             sigc::bind( sigc::mem_fun( m_treeview_entries, &WidgetEntryList::go_down ), false ) );
 
-    Lifeograph::create_action(
-            false, m_action_previous_match, "MatchPrevious", Gtk::Stock::GO_BACK,
-// TRANSLATORS: label and tooltip of the go-to-previous-match-of-filtered-text action
-            _( "Previous Match" ),
-            _( "Go to previous match" ),
-            Gtk::AccelKey( GDK_KEY_F3, Gdk::SHIFT_MASK ),
-            sigc::mem_fun( this, &PanelDiary::go_prev_match ),
-            m_button_match_prev );
-
-    Lifeograph::create_action(
-            false, m_action_next_match, "MatchNext", Gtk::Stock::GO_FORWARD,
-// TRANSLATORS: label and tooltip of the go-to-next-match-of-filtered-text action
-            _( "Next Match" ),
-            _( "Go to next match" ),
-            Gtk::AccelKey( GDK_KEY_F3, Gdk::ModifierType( 0 ) ),
-            sigc::mem_fun( this, &PanelDiary::go_next_match ),
-            m_button_match_next );
-
     Lifeograph::create_action(
             false, m_action_jump2current, "Jump", Gtk::Stock::JUMP_TO,
             "", "",     // no grachical interface yet!
@@ -214,14 +154,10 @@ PanelDiary::PanelDiary( void )
             GDK_KEY_Escape,
             Gdk::CONTROL_MASK,
             Gtk::ACCEL_VISIBLE );
-
-    // becoming proxy widgets makes them visible:
-    m_button_match_prev->set_visible( false );
-    m_button_match_next->set_visible( false );
 }
 
 void
-PanelDiary::add_chapter_category_to_list( const CategoryChapters *chapters )
+PanelDiary::add_chapter_category_to_list( const CategoryChapters* chapters )
 {
     Gtk::TreeRow	row_container;
     Chapter			*chapter = NULL;
@@ -254,8 +190,8 @@ PanelDiary::add_chapter_category_to_list( const CategoryChapters *chapters )
                 l_row_entry = * m_treeview_entries->m_treestore->append(
                         row_container.children() );
                 l_row_entry[ ListData::colrec->ptr ] = l_entry;
-                l_row_entry[ ListData::colrec->info ] = l_entry->get_list_str();
                 l_row_entry[ ListData::colrec->icon ] = l_entry->get_icon();
+                l_row_entry[ ListData::colrec->info ] = l_entry->get_list_str();
             }
 
             ++l_itr_entry;
@@ -271,7 +207,7 @@ PanelDiary::add_chapter_category_to_list( const CategoryChapters *chapters )
 }
 
 void
-PanelDiary::fill_child_rows( const Gtk::TreeModel::Children &children )
+PanelDiary::fill_child_rows( const Gtk::TreeModel::Children& children )
 {
     for( Gtk::TreeModel::Children::const_iterator iter = children.begin();
             iter != children.end(); ++iter )
@@ -282,16 +218,24 @@ PanelDiary::fill_child_rows( const Gtk::TreeModel::Children &children )
         if( ptr )
             ptr->m_list_data->treepath = m_treeview_entries->m_treestore->get_path( row );
 
-        if( ptr->get_type() == DiaryElement::ET_CHAPTER )
-            if( dynamic_cast< Chapter* >( ptr )->get_expanded() )
-                m_treeview_entries->expand_to_path( ptr->m_list_data->treepath );
+        switch( ptr->get_type() )
+        {
+            case DiaryElement::ET_CHAPTER:
+            case DiaryElement::ET_TOPIC:
+            case DiaryElement::ET_TODO_GRP:
+                if( dynamic_cast< Chapter* >( ptr )->get_expanded() )
+                    m_treeview_entries->expand_to_path( ptr->m_list_data->treepath );
+                break;
+            default:
+                break;
+        }
 
         fill_child_rows( row.children() );
     }
 }
 
 void
-PanelDiary::update_entry_list( void )
+PanelDiary::update_entry_list()
 {
     PRINT_DEBUG( "update_entry_list()" );
     Lifeograph::m_internaloperation++;
@@ -316,9 +260,10 @@ PanelDiary::update_entry_list( void )
     l_row_diary[ ListData::colrec->icon ] = Lifeograph::icons->diary_16;
 
     // CHAPTERS
-    if( Diary::d->get_sorting_criteria() == SC_DATE &&
-        !( Diary::d->get_filtering_status() & Diary::FS_FILTER_TRASH ) )
+    if( Diary::d->get_sorting_criteria() == SC_DATE /* TODO: maybe later: &&
+        !( Diary::d->get_filtering_status() & Filter::FS_FILTER_TRASH )*/ )
     {
+        add_chapter_category_to_list( Diary::d->get_todo_groups() );
         add_chapter_category_to_list( Diary::d->get_topics() );
         add_chapter_category_to_list( Diary::d->get_current_chapter_ctg() );
     }
@@ -334,8 +279,8 @@ PanelDiary::update_entry_list( void )
             l_row_entry = *m_treeview_entries->m_treestore->append(
                     l_row_diary.children() );
             l_row_entry[ ListData::colrec->ptr ] = l_entry; // ptr must be first
-            l_row_entry[ ListData::colrec->info ] = l_entry->get_list_str();
             l_row_entry[ ListData::colrec->icon ] = l_entry->get_icon();
+            l_row_entry[ ListData::colrec->info ] = l_entry->get_list_str();
         }
     }
 
@@ -350,40 +295,37 @@ PanelDiary::update_entry_list( void )
     // always expand diary
     m_treeview_entries->expand_element( Diary::d );
 
-    // UPDATE DIARY ELEM IF LAST ONE IS NOT IN THE LIST ANYMORE
-    DiaryElement *elem = AppWindow::p->panel_main->get_cur_elem();
-    bool flag_show_elem = true;
-    if( m_entry_count <= 0 )
-        elem = Diary::d;
-    else
+    // UPDATE CURRENT ELEM IF LAST ONE IS NOT IN THE LIST ANYMORE
+    DiaryElement* elem = AppWindow::p->panel_main->get_cur_elem();
     if( elem != NULL )
     {
         if( elem->get_filtered_out() )
+        {
             elem = Diary::d->get_entry_first();
-        else
-            flag_show_elem = false;
+            if( elem == NULL ) // if there is no entry
+                elem = Diary::d;
+            elem->show();
+        }
+        else if( elem->get_type() >= DiaryElement::ET_DIARY )
+            m_treeview_entries->present_element( elem );
     }
     else // the case at the start-up
     {
         elem = Diary::d->get_startup_elem();
         if( elem->get_filtered_out() ) // if startup item is trashed
             elem = Diary::d->get_entry_first();
-        if( elem == NULL ) // if there is no entry
+        if( elem == NULL ) // if there is no unfiltered entry
             elem = Diary::d;
+        elem->show();
     }
 
-    if( flag_show_elem )
-        elem->show();
-    else
-        m_treeview_entries->present_element( elem );
-
-    Diary::d->set_filtering_status_applied();
+    Diary::d->get_filter()->set_status_applied();
 
     Lifeograph::m_internaloperation--;
 }
 
 void
-PanelDiary::update_entry_list_style( void ) // TODO: is this function really needed?
+PanelDiary::update_entry_list_style() // TODO: is this function really needed?
 {
     Lifeograph::m_internaloperation++;
 
@@ -398,7 +340,7 @@ PanelDiary::update_entry_list_style( void ) // TODO: is this function really nee
 }
 
 void
-PanelDiary::update_calendar( void )
+PanelDiary::update_calendar()
 {
     guint year, month, day;
 
@@ -432,15 +374,7 @@ PanelDiary::update_calendar( void )
 }
 
 void
-PanelDiary::update_button_remove_filters( void )
-{
-    m_button_remove_filters->set_visible(
-            Diary::d->get_filtering_status() &
-            ( Diary::FS_FILTER_DATE | Diary::FS_FILTER_TAG ) );
-}
-
-void
-PanelDiary::handle_login( void )
+PanelDiary::handle_login()
 {
     switch( Diary::d->get_sorting_criteria() )
     {
@@ -473,31 +407,21 @@ PanelDiary::handle_login( void )
 
     update_entry_list();
 
-    m_button_remove_filters->set_visible( false );
-
     m_button_add->set_visible( ! Diary::d->is_read_only() );
 }
 
 void
-PanelDiary::handle_logout( void )
+PanelDiary::handle_logout()
 {
     Lifeograph::m_internaloperation++;
 
-    m_entry_filter->set_text( "" );
-    m_entry_replace->set_text( "" );
-    m_togglebtn_filter_favorites->set_active( false );
-    m_togglebtn_filter_trash->set_active( false );
     m_treeview_entries->clear();
 
-    m_button_match_prev->hide();
-    m_button_match_next->hide();
-    m_toolbar_replace->hide();
-
     Lifeograph::m_internaloperation--;
 }
 
 void
-PanelDiary::show( const DiaryElement *element )
+PanelDiary::show( const DiaryElement* element )
 {
     if( element->get_type() >= DiaryElement::ET_DIARY ) // if a list element
         m_treeview_entries->present_element( element );
@@ -511,7 +435,9 @@ PanelDiary::show( const DiaryElement *element )
 
         if( element->get_date().is_ordinal() )
         {
-            Chapter *c = Diary::d->get_topics()->get_chapter( element->get_date().get_pure() );
+            Chapter *c = element->get_date().is_todo() ?
+                    Diary::d->get_todo_groups()->get_chapter( element->get_date().get_pure() ) :
+                    Diary::d->get_topics()->get_chapter( element->get_date().get_pure() );
             if( c == NULL )
                 m_menuitem_add_entry->set_sensitive( false );
             else
@@ -545,7 +471,7 @@ PanelDiary::show( const DiaryElement *element )
 }
 
 void
-PanelDiary::show_today( void )
+PanelDiary::show_today()
 {
     Entry *entry_today = Diary::d->get_entry_today();
     bool flag_add = false;
@@ -572,7 +498,7 @@ PanelDiary::show_today( void )
 }
 
 void
-PanelDiary::show_prev_session_elem( void )
+PanelDiary::show_prev_session_elem()
 {
     DiaryElement *elem( Diary::d->get_prev_session_elem() );
     if( elem != NULL )
@@ -582,7 +508,7 @@ PanelDiary::show_prev_session_elem( void )
 }
 
 void
-PanelDiary::present_current_row( void )
+PanelDiary::present_current_row()
 {
     Gtk::TreeIter iter = m_treeview_entries->get_selection()->get_selected();
     if( iter == m_treeview_entries->m_treestore->children().end() )
@@ -593,97 +519,7 @@ PanelDiary::present_current_row( void )
 }
 
 void
-PanelDiary::handle_entry_filter_changed( void )
-{
-    if( Lifeograph::m_internaloperation ) return;
-    // current entry must be closed here or else it loses...
-    // ...changes since it was selected:
-    //AppWindow::p->m_entry_view->sync(); update_entry_list() does the syncing
-
-    const std::string filterstring( m_entry_filter->get_text().lowercase() );
-
-    Diary::d->set_filter_text( filterstring );
-    update_entry_list();    // syncs current entry
-
-    if( filterstring.size() > 0 )
-    {
-        if( m_entry_count > 0 )
-        {
-            AppWindow::p->m_entry_view->get_buffer()->set_search_str( filterstring );
-            if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
-                AppWindow::p->m_entry_view->get_buffer()->select_searchstr_next();
-        }
-
-        m_entry_filter->set_tooltip_markup(
-                Glib::ustring::compose(
-                        _( "Found in <b>%1</b> of <b>%2</b> entrie(s)" ),
-                        m_entry_count, Diary::d->get_size() ) );
-    }
-    else
-    {
-        AppWindow::p->m_entry_view->get_buffer()->set_search_str( "" );
-        m_entry_filter->set_tooltip_text( _( "Enter text to be filtered" ) );
-    }
-
-    update_calendar();
-
-    if( m_entry_count < 1 || filterstring.size() < 1 )
-    {
-        m_button_match_prev->hide();
-        m_button_match_next->hide();
-        m_toolbar_replace->hide();
-    }
-    else
-    {
-        m_button_match_prev->show();
-        m_button_match_next->show();
-        if( ! Diary::d->is_read_only() )
-            m_toolbar_replace->show();
-    }
-}
-
-void
-PanelDiary::handle_filter_favorites_toggled( void )
-{
-    if( Lifeograph::m_internaloperation ) return;
-
-    Diary::d->toggle_filter_favorites();	// set filter
-    update_entry_list();					// apply the filter
-}
-
-void
-PanelDiary::handle_filter_trash_toggled( void )
-{
-    if( Lifeograph::m_internaloperation ) return;
-
-    Diary::d->toggle_filter_trash();    // set filter
-    update_entry_list();                // apply the filter
-}
-
-void
-PanelDiary::remove_filters( void )
-{
-    if( Diary::d->get_filtering_status() & ( Diary::FS_FILTER_DATE | Diary::FS_FILTER_TAG) )
-    {
-        const Tag *tag( Diary::d->get_filter_tag() );
-        if( tag != NULL )
-        {
-            Diary::d->set_filter_tag( NULL );
-            AppWindow::p->m_tag_view->update_button_filter_tag();
-            // UPDATE ICON
-            Gtk::TreeRow row = *AppWindow::p->get_element_row( tag );
-            row[ PanelExtra::colrec->icon ] = tag->get_icon();
-        }
-        m_button_remove_filters->set_visible( false );
-
-        Diary::d->clear_filter_date();
-
-        update_entry_list();
-    }
-}
-
-void
-PanelDiary::handle_calendar_dayselected( void )
+PanelDiary::handle_calendar_dayselected()
 {
     if( Lifeograph::m_internaloperation ) return;
 
@@ -719,7 +555,7 @@ PanelDiary::handle_calendar_dayselected( void )
 }
 
 void
-PanelDiary::handle_calendar_monthchanged( void )
+PanelDiary::handle_calendar_monthchanged()
 {
     if( Lifeograph::m_internaloperation ) return;
 
@@ -727,7 +563,7 @@ PanelDiary::handle_calendar_monthchanged( void )
 }
 
 void
-PanelDiary::handle_add_entry( void )
+PanelDiary::handle_add_entry()
 {
     if( Diary::d->is_read_only() )
         return;
@@ -758,7 +594,16 @@ PanelDiary::handle_add_entry( void )
 }
 
 void
-PanelDiary::handle_add_topic( void )
+PanelDiary::handle_add_todo_group()
+{
+    Chapter *c( Diary::d->add_todo_group( _( "New todo group" ) ) );
+    update_entry_list();
+    c->show();
+    AppWindow::p->panel_main->start_title_edit();
+}
+
+void
+PanelDiary::handle_add_topic()
 {
     Chapter *c( Diary::d->add_topic( _( "New topic" ) ) );
     update_entry_list();
@@ -767,7 +612,7 @@ PanelDiary::handle_add_topic( void )
 }
 
 void
-PanelDiary::handle_add_chapter( void )
+PanelDiary::handle_add_chapter()
 {
     guint year, month, day;
     m_calendar->get_date( year, month, day );
@@ -785,7 +630,7 @@ PanelDiary::handle_add_chapter( void )
 }
 
 void
-PanelDiary::select_date_in_calendar( const Date &date )
+PanelDiary::select_date_in_calendar( const Date& date )
 {
     ++Lifeograph::m_internaloperation;
 
@@ -794,17 +639,23 @@ PanelDiary::select_date_in_calendar( const Date &date )
     m_calendar->select_day( 0 );
     if( ! date.is_ordinal() )
     {
-        m_calendar->select_month( date.get_month() - 1, date.get_year() );
-        update_calendar();
-        if( date.get_day() )
-            m_calendar->select_day( date.get_day() );
+        guint year, month, day;
+        m_calendar->get_date( year, month, day );
+
+        if( year != date.get_year() || month != date.get_month() + 1 )
+        {
+            m_calendar->select_month( date.get_month() - 1, date.get_year() );
+            update_calendar();
+        }
+        //if( date.get_day() ) should not be necessary
+        m_calendar->select_day( date.get_day() );
     }
 
     --Lifeograph::m_internaloperation;
 }
 
 void
-PanelDiary::go_prev_match( void )
+PanelDiary::go_prev_match()
 {
     if( m_entry_count < 1 )
         return;
@@ -829,7 +680,7 @@ PanelDiary::go_prev_match( void )
 }
 
 void
-PanelDiary::go_next_match( void )
+PanelDiary::go_next_match()
 {
     if( m_entry_count < 1 )
         return;
@@ -849,34 +700,7 @@ PanelDiary::go_next_match( void )
 }
 
 void
-PanelDiary::replace_match( void )
-{
-    if( ! AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
-        go_next_match();
-    if( AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
-    {
-        AppWindow::p->m_entry_view->get_buffer()->erase_selection();
-        AppWindow::p->m_entry_view->get_buffer()->insert_at_cursor( m_entry_replace->get_text() );
-        go_next_match();
-    }
-}
-
-void
-PanelDiary::replace_all_matches( void )
-{
-    AppWindow::p->m_entry_view->sync();
-
-    Diary::d->replace_text( m_entry_replace->get_text() );
-    // update current entry:
-    if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
-    {
-        Entry *entry = dynamic_cast< Entry* >( AppWindow::p->panel_main->get_cur_elem() );
-        AppWindow::p->m_entry_view->get_buffer()->set_richtext( entry );
-    }
-}
-
-void
-PanelDiary::handle_entry_title_changed( DiaryElement *element )
+PanelDiary::handle_entry_title_changed( DiaryElement* element )
 {
     if( Lifeograph::m_internaloperation ) return;
 
@@ -885,23 +709,31 @@ PanelDiary::handle_entry_title_changed( DiaryElement *element )
 }
 
 Gtk::TreeRow
-PanelDiary::get_row( const Gtk::TreePath &path )
+PanelDiary::get_row( const Gtk::TreePath& path )
 {
     return( * m_treeview_entries->m_treestore->get_iter( path ) );
     // TODO: check validity
 }
 
 void
-PanelDiary::handle_treeview_row_expanded( const Gtk::TreeIter &iter,
-                                          const Gtk::TreePath &path )
+PanelDiary::handle_treeview_row_expanded( const Gtk::TreeIter& iter,
+                                          const Gtk::TreePath& path )
 {
     //if( Lifeograph::m_internaloperation )
         //return;
 
-    DiaryElement *element = ( * iter )[ ListData::colrec->ptr ];
-    if( element->get_type() == DiaryElement::ET_CHAPTER )
+    DiaryElement* element = ( * iter )[ ListData::colrec->ptr ];
+    switch( element->get_type() )
     {
-        Chapter *chapter = dynamic_cast< Chapter* >( element );
-        chapter->set_expanded( m_treeview_entries->row_expanded( path ) );
+        case DiaryElement::ET_CHAPTER:
+        case DiaryElement::ET_TOPIC:
+        case DiaryElement::ET_TODO_GRP:
+        {
+            Chapter* chapter = dynamic_cast< Chapter* >( element );
+            chapter->set_expanded( m_treeview_entries->row_expanded( path ) );
+        }
+        break;
+    default:
+        break;
     }
 }
