@@ -36,35 +36,27 @@ class PanelDiary
     public:
         static const int        MIN_WIDTH = 300; // pixels
 
-                                PanelDiary( void );
+                                PanelDiary();
 
-        //void                    update_toolbar( void );
-        void                    update_entry_list( void );
-        void                    update_entry_list_style( void );
-        void                    update_calendar( void );
-        void                    update_button_remove_filters( void );
+        //void                    update_toolbar();
+        void                    update_entry_list();
+        void                    update_entry_list_style();
+        void                    update_calendar();
 
         void                    show( const DiaryElement* );
-        void                    show_today( void );
-        void                    present_current_row( void );
-        void                    show_prev_session_elem( void );
+        void                    show_today();
+        void                    present_current_row();
+        void                    show_prev_session_elem();
 
-        void                    handle_calendar_monthchanged( void );
-        void                    handle_calendar_dayselected( void );
+        void                    handle_calendar_monthchanged();
+        void                    handle_calendar_dayselected();
         void                    select_date_in_calendar( const Date& );
 
-        void                    handle_filter_favorites_toggled( void );
-        void                    handle_filter_trash_toggled( void );
-        void                    remove_filters( void );
+        void                    go_prev_match();
+        void                    go_next_match();
 
-        void                    handle_login( void );
-        void                    handle_logout( void );
-
-        void                    handle_entry_filter_changed( void );
-        void                    go_prev_match( void );
-        void                    go_next_match( void );
-        void                    replace_match( void );
-        void                    replace_all_matches( void );
+        void                    handle_login();
+        void                    handle_logout();
 
         void                    handle_entry_title_changed( DiaryElement* );
 
@@ -73,10 +65,14 @@ class PanelDiary
         void                    handle_treeview_row_expanded( const Gtk::TreeIter&,
                                                               const Gtk::TreePath& );
 
+        int                     get_entry_count() const
+        { return m_entry_count; }
+
     protected:
-        void                    handle_add_entry( void );
-        void                    handle_add_topic( void );
-        void                    handle_add_chapter( void );
+        void                    handle_add_entry();
+        void                    handle_add_todo_group();
+        void                    handle_add_topic();
+        void                    handle_add_chapter();
 
         void                    fill_child_rows( const Gtk::TreeModel::Children& );
 
@@ -84,34 +80,21 @@ class PanelDiary
 
         Gtk::Button             *m_button_logout;
         Gtk::Calendar           *m_calendar;
-        EntryClear              *m_entry_filter;
-        EntryClear              *m_entry_replace;
-        Gtk::Button             *m_button_match_prev;
-        Gtk::Button             *m_button_match_next;
-        Gtk::Box                *m_toolbar_replace;
-        Gtk::Button             *m_button_replace;
-        Gtk::Button             *m_button_replace_all;
 
         Gtk::RadioMenuItem      *m_menuitem_sort_by_date;
         Gtk::RadioMenuItem      *m_menuitem_sort_by_size;
         Gtk::RadioMenuItem      *m_menuitem_sort_by_change;
 
-        Gtk::ToggleButton       *m_togglebtn_filter_favorites;
-        Gtk::ToggleButton       *m_togglebtn_filter_trash;
-        Gtk::Button             *m_button_remove_filters;
-
-        Menubutton              *m_button_add;
+        Gtk::MenuButton         *m_button_add;
         Gtk::ImageMenuItem      *m_menuitem_add_entry;
         Gtk::ImageMenuItem      *m_menuitem_add_topic;
+        Gtk::ImageMenuItem      *m_menuitem_add_todo_group;
         Gtk::ImageMenuItem      *m_menuitem_add_chapter;
         Gtk::Separator          *m_sprt_tb1;
 
         Glib::RefPtr< Gtk::Action > m_action_today;
         Glib::RefPtr< Gtk::Action > m_action_previous_list;
         Glib::RefPtr< Gtk::Action > m_action_next_list;
-        Glib::RefPtr< Gtk::Action > m_action_focusfilter;
-        Glib::RefPtr< Gtk::Action > m_action_previous_match;
-        Glib::RefPtr< Gtk::Action > m_action_next_match;
         Glib::RefPtr< Gtk::Action > m_action_jump2current;
         Glib::RefPtr< Gtk::Action > m_action_show_prev_session_elem;
 
