@@ -39,31 +39,34 @@ class PanelExtra : public Gtk::TreeView
                     add( icon );
                     add( name );
                     add( ptr );
+                    add( filter );
                 }
                 Gtk::TreeModelColumn< Glib::RefPtr< Gdk::Pixbuf > >     icon;
                 Gtk::TreeModelColumn< Glib::ustring >                   name;
+                Gtk::TreeModelColumn< Glib::RefPtr< Gdk::Pixbuf > >     filter;
                 Gtk::TreeModelColumn< DiaryElement* >                   ptr;
         };
-        static Colrec               *colrec;
+        static Colrec*              colrec;
 
                                     PanelExtra( BaseObjectType*,
                                                 const Glib::RefPtr<Gtk::Builder>& );
 
-        void                        handle_login( void );
-        void                        handle_logout( void );
+        void                        handle_login();
+        void                        handle_logout();
 
-        void                        populate( void );
+        void                        populate();
         Gtk::TreeIter               add_elem_to_list( DiaryElement*,
                                                       const Gtk::TreeNodeChildren* = NULL );
 
         Gtk::TreeRow                get_row( const Gtk::TreePath& );
 
+        void                        set_filtered_tag( const Tag* );
+
+        void                        refresh_elem_icon( DiaryElement* );
+
     protected:
         void                        handle_treeview_drag_begin(
                                             const Glib::RefPtr< Gdk::DragContext >& );
-        void                        handle_drag_data_get( const Glib::RefPtr<Gdk::DragContext>&,
-                                                          Gtk::SelectionData&,
-                                                          guint, guint );
         bool                        on_drag_motion( const Glib::RefPtr< Gdk::DragContext >&,
                                                     int, int, guint );
         bool                        on_drag_drop( const Glib::RefPtr< Gdk::DragContext >&,
@@ -79,14 +82,32 @@ class PanelExtra : public Gtk::TreeView
                                                          const Gtk::TreeModel::iterator& );
         void                        cell_data_func_text( Gtk::CellRenderer*,
                                                          const Gtk::TreeModel::iterator& );
+        void                        cell_data_func_filter( Gtk::CellRenderer*,
+                                                           const Gtk::TreeModel::iterator& );
+
+        void                        handle_search_string_changed();
+        void                        replace_match();
+        void                        replace_all_matches();
 
         Glib::RefPtr< Gtk::TreeStore >
                                     m_treestore_all_tags;
 
-        Entry                       *m_ptr2entry;
-        DiaryElement                *m_elem_drop_target;
+        Entry*                      m_ptr2entry;
+        DiaryElement*               m_elem_drop_target;
 
-        bool                        m_flag_themes_expanded;
+        Gtk::Button*                m_button_filter;
+
+        EntryClear*                 m_entry_search;
+        EntryClear*                 m_entry_replace;
+        Gtk::Button*                m_button_match_prev;
+        Gtk::Button*                m_button_match_next;
+        Gtk::Grid*                  m_grid_replace;
+        Gtk::Button*                m_button_replace;
+        Gtk::Button*                m_button_replace_all;
+
+        Glib::RefPtr< Gtk::Action > m_action_focusfilter;
+        Glib::RefPtr< Gtk::Action > m_action_previous_match;
+        Glib::RefPtr< Gtk::Action > m_action_next_match;
 
     friend class Lifeograph;
 };
