@@ -41,24 +41,24 @@ class PanelMain
         typedef DiaryElement* PtrDiaryElement;
 
     public:
-                                PanelMain( void );
+                                PanelMain();
 
         bool                    is_cur_elem( DiaryElement *elem )
         { return( elem == get_cur_elem() ); }
 
         void                    show( ElementShowerProto* );
 
-        void                    handle_logout( void );
+        void                    handle_logout();
 
-        void                    go_back( void );
-        //void                  go_forward( void );
+        void                    go_back();
+        //void                  go_forward();
 
         void                    remove_element_from_history( DiaryElement* );
-        void                    clear_history( void );
+        void                    clear_history();
 
-        PtrDiaryElement         get_cur_elem( void )
+        PtrDiaryElement         get_cur_elem()
         { return( m_browsing_history[ m_bhist_index ] ); }
-        DiaryElement::Type      get_cur_elem_type( void )
+        DiaryElement::Type      get_cur_elem_type()
         {
             return( m_browsing_history[ m_bhist_index ] == NULL ?
                     DiaryElement::ET_NONE : m_browsing_history[ m_bhist_index ]->get_type() );
@@ -68,22 +68,28 @@ class PanelMain
         {
             m_image_elem->set( icon );
         }
+        void                    update_overlay_icon()
+        {
+            m_image_overlay->set_visible(
+                    ( m_cur_shower->get_element()->get_type() == DiaryElement::ET_ENTRY) &&
+                    ( m_cur_shower->get_element()->get_status() & ES::FAVORED ) );
+        }
 
-        void                    start_title_edit( void );
-        void                    cancel_title_edit( void );
-        void                    apply_title_edit( void );
+        void                    start_title_edit();
+        void                    cancel_title_edit();
+        void                    apply_title_edit();
         // for entries whose title is partly defined by contents of entry text editor:
-        void                    refresh_title( void )
+        void                    refresh_title()
         {
             m_label_elem_title->set_text( m_cur_shower->get_title_str() );
         }
-        void                    refresh_extra_info( void )
+        void                    refresh_extra_info()
         {
             m_label_elem_extra->set_text( m_cur_shower->get_info_str() );
         }
 
         bool                    handle_entry_title_focus_out( GdkEventFocus* );
-        void                    handle_entry_title_changed( void );
+        void                    handle_entry_title_changed();
         bool                    handle_entry_title_key_press( GdkEventKey* );
         void                    handle_entry_icon_release( Gtk::EntryIconPosition,
                                                            const GdkEventButton* );
@@ -102,20 +108,21 @@ class PanelMain
         bool                    m_flag_title_editable;
         bool                    m_flag_title_applicable;
 
-        ElementShowerProto      *m_cur_shower;
+        ElementShowerProto*     m_cur_shower;
 
-        Gtk::Widget             *m_ptr2widget;
-        Gtk::Box                *m_vbox_content;
+        Gtk::Widget*            m_ptr2widget;
+        Gtk::Box*               m_vbox_content;
 
-        Gtk::Alignment          *m_align_elem_title;
-        Gtk::EventBox           *m_eventbox_elem_title;
-        Gtk::Label              *m_label_elem_title;
-        Gtk::Entry              *m_entry_elem_title;
-        Gtk::Label              *m_label_elem_extra;
-        Gtk::Button             *m_button_back;
-        Gtk::Image              *m_image_elem;
-        Menubutton              *m_button_menu;
-        Gtk::Alignment          *m_alignment_extra_tools;
+        Gtk::Alignment*         m_align_elem_title;
+        Gtk::EventBox*          m_eventbox_elem_title;
+        Gtk::Label*             m_label_elem_title;
+        Gtk::Entry*             m_entry_elem_title;
+        Gtk::Label*             m_label_elem_extra;
+        Gtk::Button*            m_button_back;
+        Gtk::Image*             m_image_elem;
+        Gtk::Image*             m_image_overlay;
+        Gtk::MenuButton*        m_button_menu;
+        Gtk::Alignment*         m_alignment_extra_tools;
 
         Glib::RefPtr< Gtk::Action > m_action_previous_browsing;
 };
