@@ -93,7 +93,7 @@ PrintableImage::render( const Glib::RefPtr< Gtk::PrintContext > &print_context )
 }
 
 // PRINT OPERATION =================================================================================
-PrintOpr::PrintOpr( void )
+PrintOpr::PrintOpr()
 :   m_opt_justify( false )
 {
     m_refSettings = Gtk::PrintSettings::create();
@@ -109,7 +109,7 @@ PrintOpr::~PrintOpr()
 }
 
 void
-PrintOpr::clear_content( void )
+PrintOpr::clear_content()
 {
     for( Printables::iterator iter = m_content.begin(); iter != m_content.end(); ++iter )
         delete *iter;
@@ -155,7 +155,7 @@ PrintOpr::set_hide_comments( bool flag_hide )
 }
 
 Gtk::Widget*
-PrintOpr::on_create_custom_widget( void )
+PrintOpr::on_create_custom_widget()
 {
     Gtk::Grid *grid_main( new Gtk::Grid );
     Gtk::Box *vbox_extent( Gtk::manage( new Gtk::Box( Gtk::ORIENTATION_VERTICAL, 5 ) ) );
@@ -249,7 +249,7 @@ PrintOpr::on_done( Gtk::PrintOperationResult result )
 }
 
 void
-PrintOpr::on_status_changed( void )
+PrintOpr::on_status_changed()
 {
     if( is_finished() )
     {
@@ -262,7 +262,7 @@ PrintOpr::on_status_changed( void )
 }
 
 void
-PrintOpr::show_page_setup( void )
+PrintOpr::show_page_setup()
 {
     // Show the page setup dialog, asking it to start with the existing settings:
     Glib::RefPtr< Gtk::PageSetup > new_page_setup =
@@ -274,7 +274,7 @@ PrintOpr::show_page_setup( void )
 }
 
 inline void
-PrintOpr::add_page( void )
+PrintOpr::add_page()
 {
     m_content.push_back( new PrintablePageBreak );
     m_n_pages++;
@@ -373,7 +373,7 @@ PrintOpr::handle_image( const Glib::RefPtr< Gtk::PrintContext > &print_context )
 }
 
 Printable::Type
-PrintOpr::get_more( void )
+PrintOpr::get_more()
 {
     Chapter *chapter( NULL );
     Entry   *entry( NULL );
@@ -533,7 +533,7 @@ EntryParserPango::set( const Entry *entry )
 }
 
 Printable::Type
-EntryParserPango::parse( void )
+EntryParserPango::parse()
 {
     m_pango_return = Printable::PT_ENTRY_BREAK;
     m_pango_text.clear();
@@ -561,7 +561,7 @@ EntryParserPango::parse( void )
 }
 
 void
-EntryParserPango::apply_regular( void )
+EntryParserPango::apply_regular()
 {
     if( pos_regular < m_pos_start )
     {
@@ -587,7 +587,7 @@ EntryParserPango::apply_markup( const Glib::ustring &tag_o, const Glib::ustring
 }
 
 void
-EntryParserPango::apply_heading_end( void )
+EntryParserPango::apply_heading_end()
 {
     const Glib::ustring esc_text( m_ptr2entry->get_text()->substr( 0, pos_current ) );
     m_pango_text += "<big><b>";
@@ -597,7 +597,7 @@ EntryParserPango::apply_heading_end( void )
 }
 
 void
-EntryParserPango::apply_subheading( void )
+EntryParserPango::apply_subheading()
 {
     // before adding any marked up text, last regular text chunk must be handled:
     begin_apply();  // in turn calls apply_regular()
@@ -607,7 +607,7 @@ EntryParserPango::apply_subheading( void )
 }
 
 void
-EntryParserPango::apply_subheading_end( void )
+EntryParserPango::apply_subheading_end()
 {
     if( pos_regular < pos_current )
     {
@@ -620,31 +620,31 @@ EntryParserPango::apply_subheading_end( void )
 }
 
 void
-EntryParserPango::apply_bold( void )
+EntryParserPango::apply_bold()
 {
     apply_markup( "<b>", "</b>", 1, -1 );
 }
 
 void
-EntryParserPango::apply_italic( void )
+EntryParserPango::apply_italic()
 {
     apply_markup( "<i>", "</i>", 1, -1 );
 }
 
 void
-EntryParserPango::apply_strikethrough( void )
+EntryParserPango::apply_strikethrough()
 {
     apply_markup( "<s>", "</s>", 1, -1 );
 }
 
 void
-EntryParserPango::apply_highlight( void )
+EntryParserPango::apply_highlight()
 {
     apply_markup( "<span bgcolor='yellow'>", "</span>", 1, -1 );
 }
 
 void
-EntryParserPango::apply_comment( void )
+EntryParserPango::apply_comment()
 {
     if( option_hide_comments )
         begin_apply();  // ignores comment
@@ -653,7 +653,7 @@ EntryParserPango::apply_comment( void )
 }
 
 void
-EntryParserPango::apply_check_ccl( void )
+EntryParserPango::apply_check_ccl()
 {
     const Glib::ustring esc_text(
             m_ptr2entry->get_text()->substr( pos_regular, pos_current - pos_regular ) );
@@ -664,7 +664,7 @@ EntryParserPango::apply_check_ccl( void )
 }
 
 void
-EntryParserPango::apply_check_ccl_end( void )
+EntryParserPango::apply_check_ccl_end()
 {
     if( pos_regular < pos_current )
     {
@@ -677,7 +677,7 @@ EntryParserPango::apply_check_ccl_end( void )
 }
 
 void
-EntryParserPango::apply_link( void )
+EntryParserPango::apply_link()
 {
     int offset1( 0 ), offset2( 1 );
     bool flag_img( false );
