@@ -29,17 +29,22 @@
 using namespace LIFEO;
 
 
-Settings::Settings( void )
+const std::string Settings::s_date_format_orders[3]    = { "%1%2%3", "%3%2%1", "%2%3%1" };
+const std::string Settings::s_date_format_separators   = "./-";
+
+Settings::Settings()
 :   autologout( true ), idletime( IDLETIME_DEFAULT ), show_formatting_toolbar( true ),
+    date_format_order( 0 ), date_format_separator( 0 ),
     diary_extension( EXTENSION_DEFAULT ), flag_maiden_voyage( false ),
     width( WIDTH_DEFAULT ), height( HEIGHT_DEFAULT ),
     state_maximized( false ), position_x( POSITION_NOTSET ), position_y( POSITION_NOTSET ),
-    position_pane( PANEPOS_DEFAULT ), position_pane_tags( PANEPOS_TAGS_DEFAULT )
+    position_pane( PANEPOS_DEFAULT ), position_pane_tags( PANEPOS_TAGS_DEFAULT ),
+    small_lists( true )
 {
 }
 
 bool
-Settings::read( void )
+Settings::read()
 {
     m_path = Glib::getenv( "LIFEOGRAPH_CONFIG_FILE" );
     if( m_path.empty() )
@@ -69,25 +74,37 @@ Settings::read( void )
 
         switch( line[ 0 ] )
         {
-            case 'R':
-                recentfiles.insert( line.substr( 2 ) );
+            case 'D':
+                if( line[1] == 'o' )
+                    date_format_order = convert_string( line.substr( 2 ) );
+                else
+                    date_format_separator = convert_string( line.substr( 2 ) );
+                break;
+            case 'E':
+                // if only a dot (.) no extension will be added automatically
+                diary_extension = line.substr( 2 );
+                if( diary_extension[ 0 ] != '.' )
+                    diary_extension.insert( 0, "." );
+                break;
+            case 'F':
+                show_formatting_toolbar = ( line[ 2 ] == 'y' || line[ 2 ] == 'Y' );
                 break;
             // TODO: position & size settings may go to the diary
             // TODO: check if these are within screen boundaries
             case 'H':
                 height = convert_string( line.substr( 2 ) );
                 break;
-            case 'W':
-                width = convert_string( line.substr( 2 ) );
+            case 'I':
+                idletime = convert_string( line.substr( 2 ) );
+                if( idletime < IDLETIME_MIN || idletime > IDLETIME_MAX )
+                    idletime = IDLETIME_DEFAULT;
                 break;
-            case 'S':
-                state_maximized = ( line[ 2 ] == 'm' || line[ 2 ] == 'M' );
+            case 'L':
+                autologout = ( line[ 2 ] == 'y' || line[ 2 ] == 'Y' );
                 break;
-            case 'X':
-                position_x = convert_string( line.substr( 2 ) );
-                break;
-            case 'Y':
-                position_y = convert_string( line.substr( 2 ) );
+            case 'O': // special options
+                if( line.find( "big lists" ) != std::string::npos )
+                    small_lists = false;
                 break;
             case 'P':   // uppercase
                 position_pane = convert_string( line.substr( 2 ) );
@@ -98,22 +115,20 @@ Settings::read( void )
                 if( position_pane_tags == 0 )
                     position_pane_tags = 1;
                 break;
-            case 'L':
-                autologout = ( line[ 2 ] == 'y' || line[ 2 ] == 'Y' );
+            case 'R':
+                recentfiles.insert( line.substr( 2 ) );
                 break;
-            case 'I':
-                idletime = convert_string( line.substr( 2 ) );
-                if( idletime < IDLETIME_MIN || idletime > IDLETIME_MAX )
-                    idletime = IDLETIME_DEFAULT;
+            case 'S':
+                state_maximized = ( line[ 2 ] == 'm' || line[ 2 ] == 'M' );
                 break;
-            case 'F':
-                show_formatting_toolbar = ( line[ 2 ] == 'y' || line[ 2 ] == 'Y' );
+            case 'W':
+                width = convert_string( line.substr( 2 ) );
                 break;
-            case 'E':
-                // if only a dot (.) no extension will be added automatically
-                diary_extension = line.substr( 2 );
-                if( diary_extension[ 0 ] != '.' )
-                    diary_extension.insert( 0, "." );
+            case 'X':
+                position_x = convert_string( line.substr( 2 ) );
+                break;
+            case 'Y':
+                position_y = convert_string( line.substr( 2 ) );
                 break;
 
             case 0:     // empty line
@@ -125,12 +140,14 @@ Settings::read( void )
         }
     }
 
+    update_date_format();
+
     file.close();
     return true;
 }
 
 bool
-Settings::write( void )
+Settings::write()
 {
     if( ! Glib::file_test( m_path, Glib::FILE_TEST_EXISTS ) )
     {
@@ -163,23 +180,39 @@ Settings::write( void )
     file << "\nI " << idletime;
     file << "\nF " << ( show_formatting_toolbar ? 'y' : 'n' );
 
+    file << "\nDo" << date_format_order;
+    file << "\nDs" << date_format_separator;
+
     if( diary_extension != EXTENSION_DEFAULT )
         file << "\nE " << diary_extension;
 
+    if( small_lists == false )
+        file << "\nO big lists";
+
     file.close();
     return true;
 }
 
 void
-Settings::reset( void )
+Settings::reset()
 {
     recentfiles.clear();
     autologout = true;
     idletime = IDLETIME_DEFAULT;
     show_formatting_toolbar = true;
+    date_format_order = 0;
+    date_format_separator = 0;
     diary_extension = EXTENSION_DEFAULT;
 }
 
+void
+Settings::update_date_format()
+{
+    Date::s_date_format_template = s_date_format_orders[ date_format_order ];
+    Date::s_date_format_template.insert( 2, 1, s_date_format_separators[ date_format_separator ] );
+    Date::s_date_format_template.insert( 5, 1, s_date_format_separators[ date_format_separator ] );
+}
+
 // maybe later:
 //bool
 //Settings::get_bool_opt( int i )
