@@ -33,7 +33,7 @@
 using namespace LIFEO;
 
 
-EntryView::EntryView( void )
+EntryView::EntryView()
 :   m_tag_operation_cur( TO_NONE ), m_entry_sync( NULL ),
     m_flag_entrychanged( false )
 {
@@ -47,16 +47,19 @@ EntryView::EntryView( void )
 
     try
     {
-        Lifeograph::builder->get_widget( "vbox_entry", m_vbox );
-        Lifeograph::builder->get_widget_derived( "menu_entry_elem", m_menu );
+        Lifeograph::builder->get_widget( "Bx_entry", m_vbox );
+        Lifeograph::builder->get_widget( "M_entry_elem", m_menu );
+        Lifeograph::builder->get_widget( "menuitem_entry_todo", m_menuitem_todo );
+        Lifeograph::builder->get_widget( "menuitem_entry_done", m_menuitem_done );
+        Lifeograph::builder->get_widget( "menuitem_entry_canceled", m_menuitem_canceled );
+        Lifeograph::builder->get_widget( "menuseparator_entry_4", m_menuseparator_4 );
         Lifeograph::builder->get_widget( "menuitem_entry_favorite", m_menuitem_toggle_favorite );
         Lifeograph::builder->get_widget( "menuseparator_entry_1", m_menuseparator_1 );
         Lifeograph::builder->get_widget( "menuitem_entry_print", menuitem_print );
         Lifeograph::builder->get_widget( "menuitem_entry_filter", menuitem_hide );
         Lifeograph::builder->get_widget( "menuitem_entry_filter_before", menuitem_hide_before );
         Lifeograph::builder->get_widget( "menuitem_entry_filter_after", menuitem_hide_after );
-        Lifeograph::builder->get_widget( "menuitem_entry_reset_theme", m_menuitem_reset_theme );
-        Lifeograph::builder->get_widget( "menuseparator_entry_3", m_menuseparator_2 );
+        Lifeograph::builder->get_widget( "menuseparator_entry_2", m_menuseparator_2 );
         Lifeograph::builder->get_widget( "menuitem_entry_trash", m_menuitem_trash );
         Lifeograph::builder->get_widget( "menuitem_entry_restore", m_menuitem_restore );
         Lifeograph::builder->get_widget( "menuitem_entry_dismiss", m_menuitem_dismiss );
@@ -71,7 +74,8 @@ EntryView::EntryView( void )
         Lifeograph::builder->get_widget( "tgglbutton_entry_comments", m_button_toggle_comments );
         Lifeograph::builder->get_widget_derived( "textview_entry", m_textview );
         Lifeograph::builder->get_widget_derived( "entry_tag_filter", m_tag_widget );
-        Lifeograph::builder->get_widget( "button_tag_operation", m_button_tag_operation );
+        Lifeograph::builder->get_widget( "button_entry_tag", m_button_tag_operation );
+        Lifeograph::builder->get_widget( "button_entry_tag_theme", m_button_set_theme );
         Lifeograph::builder->get_widget_derived( "drawingarea_entry_tags", m_widgettaglist );
         Lifeograph::builder->get_widget( "hbox_entry_toolbar_text", m_hbox_editing_toolbar );
         Lifeograph::builder->get_widget( "box_entry_tag_edit", m_box_tag_edit );
@@ -92,10 +96,15 @@ EntryView::EntryView( void )
     m_textview->m_buffer->signal_changed().connect(
             sigc::mem_fun( this, &LIFEO::EntryView::handle_textview_changed ) );
 
+    m_menuitem_todo->signal_activate().connect(
+            sigc::bind( sigc::mem_fun( this, &EntryView::set_todo_status ), ES::TODO ) );
+    m_menuitem_done->signal_activate().connect(
+            sigc::bind( sigc::mem_fun( this, &EntryView::set_todo_status ), ES::DONE ) );
+    m_menuitem_canceled->signal_activate().connect(
+            sigc::bind( sigc::mem_fun( this, &EntryView::set_todo_status ), ES::CANCELED ) );
+
     m_menuitem_toggle_favorite->signal_activate().connect(
             sigc::mem_fun( this, &LIFEO::EntryView::toggle_favoredness ) );
-    m_menuitem_reset_theme->signal_activate().connect(
-            sigc::mem_fun( this, &LIFEO::EntryView::reset_theme ) );
     m_menuitem_trash->signal_activate().connect(
             sigc::mem_fun( this, &LIFEO::EntryView::trash_entry ) );
     m_menuitem_restore->signal_activate().connect(
@@ -126,6 +135,8 @@ EntryView::EntryView( void )
             sigc::mem_fun( this, &EntryView::handle_button_tag_clicked ) );
     m_button_tag_operation->signal_clicked().connect(
             sigc::mem_fun( this, &EntryView::handle_button_tag_clicked ) );
+    m_button_set_theme->signal_clicked().connect(
+            sigc::mem_fun( this, &EntryView::handle_set_theme ) );
     m_widgettaglist->signal_drag_data_received().connect(
             sigc::mem_fun( this, &EntryView::handle_drag_data_received ) );
     m_widgettaglist->signal_add_tag().connect(
@@ -200,7 +211,7 @@ EntryView::EntryView( void )
 }
 
 void
-EntryView::sync( void )
+EntryView::sync()
 {
     if( m_flag_entrychanged )
     {
@@ -212,7 +223,7 @@ EntryView::sync( void )
 }
 
 void
-EntryView::remove_selected_tags( void )
+EntryView::remove_selected_tags()
 {
     /*std::vector< Gtk::TreeModel::Path > selected_items =
             m_iconview_tags->get_selected_items();
@@ -230,7 +241,7 @@ EntryView::remove_selected_tags( void )
 }
 
 void
-EntryView::handle_login( void )
+EntryView::handle_login()
 {
     m_textview->m_buffer->handle_login();
 
@@ -238,9 +249,12 @@ EntryView::handle_login( void )
     bool editable( ! Diary::d->is_read_only() );
     m_textview->set_editable( editable );
     m_widgettaglist->set_editable( editable );
+    m_menuitem_todo->set_visible( editable );
+    m_menuitem_done->set_visible( editable );
+    m_menuitem_canceled->set_visible( editable );
+    m_menuseparator_4->set_visible( editable );
     m_menuitem_toggle_favorite->set_visible( editable );
     m_menuseparator_1->set_visible( editable );
-    m_menuitem_reset_theme->set_visible( editable );
     m_menuseparator_2->set_visible( editable );
     m_menuitem_trash->set_visible( editable );
     m_menuitem_restore->set_visible( editable );
@@ -250,7 +264,7 @@ EntryView::handle_login( void )
 }
 
 void
-EntryView::handle_textview_changed( void )
+EntryView::handle_textview_changed()
 {
     if( Lifeograph::m_internaloperation ) return;
 
@@ -276,51 +290,66 @@ EntryView::handle_drag_data_received(
 
     context->drag_finish( true, false, time );
 
-    Glib::ustring name = selection_data.get_data_as_string();
-
-    if( name.empty() )  // should never happen
+    if( Lifeograph::s_elem_dragged == NULL )
         return;
 
-    switch( info )
+    switch( Lifeograph::s_elem_dragged->get_type() )
     {
-        case DiaryElement::ET_TAG: // both tags and themes come from this source
+        case DiaryElement::ET_ENTRY:
+            m_textview->m_buffer->insert_link( Lifeograph::s_elem_dragged );
+            break;
+        case DiaryElement::ET_TAG:
         {
-            if( selection_data.get_data_type() == TARGET_ENTRY_TAG )
+            Tag *tag = dynamic_cast< Tag* >( Lifeograph::s_elem_dragged );
+            if( m_ptr2elem->add_tag( tag ) ) // if does not already have the tag
             {
-                Tag *tag = Diary::d->m_tags.find( name )->second;
-                if( m_ptr2elem->add_tag( tag ) ) // if does not already have the tag
-                    m_widgettaglist->update();
-            }
-            else
-            {
-                Theme *theme = Diary::d->m_themes.find( name )->second;
-                m_ptr2elem->set_theme( theme );
-                update_theme();
+                m_widgettaglist->update();
+                if( tag->get_has_own_theme() )
+                    update_theme();
+                // note: even if tag has its own theme it is not applied if entry has already
+                // a theme tag before
             }
             break;
         }
-        case DiaryElement::ET_ENTRY:
-            if( Lifeograph::s_elem_dragged != NULL )
-                if( Lifeograph::s_elem_dragged->get_type() == DiaryElement::ET_ENTRY )
-                    m_textview->m_buffer->insert_link( Lifeograph::s_elem_dragged );
+        case DiaryElement::ET_UNTAGGED:
+            if( m_ptr2elem->clear_tags() )
+            {
+                m_widgettaglist->update();
+                update_theme();
+            }
+            break;
+        default:
             break;
     }
 }
 
 void
-EntryView::toggle_favoredness( void )
+EntryView::toggle_favoredness()
 {
     if( Lifeograph::m_internaloperation )
         return;
 
-    m_ptr2elem->m_option_favored = !m_ptr2elem->m_option_favored;
-    AppWindow::p->panel_main->set_icon( m_ptr2elem->get_icon32() );
+    m_ptr2elem->toggle_favored();
+    AppWindow::p->panel_main->update_overlay_icon();
     Gtk::TreeRow row = AppWindow::p->get_element_row( m_ptr2elem );
     row[ ListData::colrec->icon ] = m_ptr2elem->get_icon();
 }
 
 void
-EntryView::print( void )
+EntryView::set_todo_status( ElemStatus status )
+{
+    if( Lifeograph::m_internaloperation )
+        return;
+
+    m_ptr2elem->set_todo_status( status );
+    AppWindow::p->panel_main->set_icon( m_ptr2elem->get_icon32() );
+    Gtk::TreeRow row = AppWindow::p->get_element_row( m_ptr2elem );
+    row[ ListData::colrec->icon ] = m_ptr2elem->get_icon();
+    row[ ListData::colrec->info ] = m_ptr2elem->get_list_str();
+}
+
+void
+EntryView::print()
 {
     AppWindow::p->m_entry_view->sync();
 
@@ -342,53 +371,38 @@ EntryView::print( void )
 }
 
 void
-EntryView::hide( void )
+EntryView::hide()
 {
-    m_ptr2elem->m_flag_filteredout = true;
-    Diary::d->activate_individual_filter();
-    AppWindow::p->panel_diary->update_button_remove_filters();
+    Diary::d->get_filter()->add_entry( m_ptr2elem );
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 }
 
 void
-EntryView::hide_before( void )
+EntryView::hide_before()
 {
     Diary::d->set_filter_date_begin( m_ptr2elem->get_date().m_date );
-    AppWindow::p->panel_diary->update_button_remove_filters();
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 }
 
 void
-EntryView::hide_after( void )
+EntryView::hide_after()
 {
     Diary::d->set_filter_date_end( m_ptr2elem->get_date().m_date );
-    AppWindow::p->panel_diary->update_button_remove_filters();
     AppWindow::p->panel_diary->update_calendar();
     AppWindow::p->panel_diary->update_entry_list();
 }
 
 void
-EntryView::reset_theme( void )
-{
-    m_ptr2elem->unset_theme();
-    m_textview->m_buffer->set_theme( Diary::d->get_default_theme() );
-    m_menuitem_reset_theme->set_visible( false );
-    update_highlight_button();
-}
-
-void
-EntryView::update_theme( void )
+EntryView::update_theme()
 {
     m_textview->m_buffer->set_theme( m_ptr2elem->get_theme() );
-    m_menuitem_reset_theme->set_visible( m_ptr2elem->get_theme_is_set() );
     update_highlight_button();
-    m_widgettaglist->set_entry( m_ptr2elem );   // to update the theme
 }
 
 void
-EntryView::trash_entry( void )
+EntryView::trash_entry()
 {
     Diary::d->show();
 
@@ -399,7 +413,7 @@ EntryView::trash_entry( void )
         Diary::d->set_startup_elem( Diary::d->get_id() );
         AppWindow::p->m_diary_view->update_startup_elem();
     }
-    Diary::d->set_filtering_status_new();
+    Diary::d->get_filter()->set_status_outstanding();
 
     Lifeograph::m_internaloperation++;
 
@@ -410,12 +424,12 @@ EntryView::trash_entry( void )
 }
 
 void
-EntryView::restore_entry( void )
+EntryView::restore_entry()
 {
     Diary::d->show();
 
     m_ptr2elem->set_trashed( false );
-    Diary::d->set_filtering_status_new();
+    Diary::d->get_filter()->set_status_outstanding();
 
     Lifeograph::m_internaloperation++;
 
@@ -426,7 +440,7 @@ EntryView::restore_entry( void )
 }
 
 void
-EntryView::dismiss_entry( void )
+EntryView::dismiss_entry()
 {
     if( ! AppWindow::p->confirm_dismiss_element( m_ptr2elem ) )
         return;
@@ -449,7 +463,7 @@ EntryView::dismiss_entry( void )
 }
 
 void
-EntryView::toggle_comments( void )
+EntryView::toggle_comments()
 {
     if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
         m_textview->m_buffer->set_comment_visibility(
@@ -457,7 +471,7 @@ EntryView::toggle_comments( void )
 }
 
 bool
-EntryView::check_title_applicable( const Glib::ustring &str ) const
+EntryView::check_title_applicable( const Glib::ustring& str ) const
 {
     try
     {
@@ -472,7 +486,7 @@ EntryView::check_title_applicable( const Glib::ustring &str ) const
 }
 
 bool
-EntryView::apply_title( const Glib::ustring &str )
+EntryView::apply_title( const Glib::ustring& str )
 {
     try
     {
@@ -491,10 +505,12 @@ EntryView::apply_title( const Glib::ustring &str )
 }
 
 void
-EntryView::handle_entry_tag_changed( void )
+EntryView::handle_entry_tag_changed()
 {
     Glib::ustring filter = m_tag_widget->get_text();
 
+    m_button_set_theme->hide();
+
     if( filter.empty() )
     {
         m_button_tag_operation->hide();
@@ -515,6 +531,9 @@ EntryView::handle_entry_tag_changed( void )
             {
                 m_button_tag_operation->set_label( _( "Remove Tag" ) );
                 m_tag_operation_cur = TO_REMOVE;
+
+                if( tag->get_has_own_theme() && m_ptr2elem->get_theme_tag() != tag )
+                    m_button_set_theme->show();
             }
             else
             {
@@ -526,9 +545,9 @@ EntryView::handle_entry_tag_changed( void )
 }
 
 void
-EntryView::handle_button_tag_clicked( void )
+EntryView::handle_button_tag_clicked()
 {
-    Tag *tag;
+    Tag* tag;
     Glib::ustring filter = m_tag_widget->get_text();
 
     switch( m_tag_operation_cur )
@@ -551,12 +570,31 @@ EntryView::handle_button_tag_clicked( void )
             break;
     }
 
+
+    if( tag->get_has_own_theme() )
+        update_theme();
     m_widgettaglist->update();
     m_tag_widget->set_text( "" );
 }
 
 void
-EntryView::focus_tag_entry( void )
+EntryView::handle_set_theme()
+{
+    if( m_tag_operation_cur == TO_REMOVE ) // only tags in entry can be set as the theme
+    {
+        Tag* tag = Diary::d->get_tags()->get_tag( m_tag_widget->get_text() );
+
+        if( tag->get_has_own_theme() )
+        {
+            m_ptr2elem->set_theme_tag( tag );
+            update_theme();
+            m_button_set_theme->set_visible( false );
+        }
+    }
+}
+
+void
+EntryView::focus_tag_entry()
 {
     if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
     {
@@ -573,7 +611,7 @@ EntryView::handle_tag_entry_focus_out( GdkEventFocus* )
 }
 
 void
-EntryView::edit_tag_in_entry( const Tag *tag )
+EntryView::edit_tag_in_entry( const Tag* tag )
 {
     if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY &&
         !Diary::d->is_read_only() )
@@ -585,7 +623,7 @@ EntryView::edit_tag_in_entry( const Tag *tag )
 }
 
 void
-EntryView::show( Entry &entry )
+EntryView::show( Entry& entry )
 {
     // do nothing if entry is already the current element:
     if( AppWindow::p->panel_main->is_cur_elem( &entry ) )
@@ -596,15 +634,34 @@ EntryView::show( Entry &entry )
     m_box_tag_edit->set_visible( false );
     AppWindow::p->panel_main->show( this );
 
+    Lifeograph::m_internaloperation++;
+
     if( ! Diary::d->is_read_only() )
     {
+        m_menuitem_todo->set_visible( entry.is_todo() );
+        m_menuitem_done->set_visible( entry.is_todo() );
+        m_menuitem_canceled->set_visible( entry.is_todo() );
+        m_menuseparator_4->set_visible( entry.is_todo() );
         m_menuitem_trash->set_visible( !entry.is_trashed() );
         m_menuitem_restore->set_visible( entry.is_trashed() );
         m_menuitem_dismiss->set_visible( entry.is_trashed() );
-        m_menuitem_reset_theme->set_visible( entry.get_theme_is_set() );
-    }
 
-    Lifeograph::m_internaloperation++;
+        if( entry.is_todo() )
+        {
+            switch( entry.get_todo_status() )
+            {
+                case ES::TODO:
+                    m_menuitem_todo->set_active();
+                    break;
+                case ES::DONE:
+                    m_menuitem_done->set_active();
+                    break;
+                case ES::CANCELED:
+                    m_menuitem_canceled->set_active();
+                    break;
+            }
+        }
+    }
 
     // TOOLBAR
     update_highlight_button();
@@ -623,24 +680,23 @@ EntryView::show( Entry &entry )
 }
 
 void
-EntryView::prepare_for_hiding( Entry &entry )
+EntryView::prepare_for_hiding( Entry& entry )
 {
     sync();
     m_tag_widget->set_text( "" );
 }
 
 void
-EntryView::update_formatting_toolbar( void )
+EntryView::update_formatting_toolbar()
 {
     m_hbox_editing_toolbar->set_visible( Lifeograph::settings.show_formatting_toolbar &&
                                          Diary::d->is_read_only() == false );
 }
 
 void
-EntryView::update_highlight_button( void )
+EntryView::update_highlight_button()
 {
-    const Theme *theme = m_ptr2elem->get_theme_is_set() ?
-            m_ptr2elem->get_theme() : Diary::d->get_default_theme();
+    const Theme* theme = m_ptr2elem->get_theme();
     m_label_highlight->override_color( theme->color_text, Gtk::STATE_FLAG_NORMAL );
     m_label_highlight->override_color( theme->color_text, Gtk::STATE_FLAG_PRELIGHT );
     m_label_highlight->override_color( theme->color_text, Gtk::STATE_FLAG_ACTIVE );
