@@ -34,11 +34,11 @@ using namespace LIFEO;
 using namespace HELPERS;
 
 
-ViewLogin::Colrec   *ViewLogin::colrec;
+ViewLogin::Colrec*  ViewLogin::colrec;
 std::string         ViewLogin::m_path_cur;
 
 
-ViewLogin::ViewLogin( void )
+ViewLogin::ViewLogin()
 :   m_flag_info_is_visible( false ), m_sort_date_type( SDT_SAVE )
 {
     Gtk::Button *button_new_diary, *button_browse_diary;
@@ -48,16 +48,16 @@ ViewLogin::ViewLogin( void )
     {
         colrec = new Colrec;
 
-        Lifeograph::builder->get_widget( "grid_login", m_grid_login );
-        Lifeograph::builder->get_widget( "treeview_diaries", m_treeview_diaries );
-        Lifeograph::builder->get_widget( "button_new_diary", button_new_diary );
-        Lifeograph::builder->get_widget( "button_open_diary", button_browse_diary );
-        Lifeograph::builder->get_widget( "button_login_edit", m_button_edit_diary );
-        Lifeograph::builder->get_widget( "button_login_read", m_button_read_diary );
-        Lifeograph::builder->get_widget( "button_login_remove_diary", m_button_remove_diary );
-        Lifeograph::builder->get_widget( "infobar_login", m_infobar );
-        Lifeograph::builder->get_widget( "label_login_infobar", m_label_info );
-        Lifeograph::builder->get_widget( "button_login_infobar", m_button_info );
+        Lifeograph::builder->get_widget( "G_login", m_grid_login );
+        Lifeograph::builder->get_widget( "TV_diaries", m_treeview_diaries );
+        Lifeograph::builder->get_widget( "B_new_diary", button_new_diary );
+        Lifeograph::builder->get_widget( "B_open_diary", button_browse_diary );
+        Lifeograph::builder->get_widget( "B_login_edit", m_button_edit_diary );
+        Lifeograph::builder->get_widget( "B_login_read", m_button_read_diary );
+        Lifeograph::builder->get_widget( "B_login_remove_diary", m_button_remove_diary );
+        Lifeograph::builder->get_widget( "IB_login", m_infobar );
+        Lifeograph::builder->get_widget( "L_login_infobar", m_label_info );
+        Lifeograph::builder->get_widget( "B_login_infobar", m_button_info );
 
         col_diary = Gtk::manage( new Gtk::TreeView::Column( _( "Name" ), colrec->name ) );
         col_date = Gtk::manage( new Gtk::TreeView::Column( _( STRING::COLHEAD_BY_LAST_SAVE ),
@@ -78,7 +78,10 @@ ViewLogin::ViewLogin( void )
     col_date->set_clickable( true );
     m_treeview_diaries->append_column( *col_diary );
     m_treeview_diaries->append_column( *col_date );
-    m_treestore_diaries->set_sort_column( 1, Gtk::SORT_DESCENDING );
+    m_treestore_diaries->set_default_sort_func(
+            sigc::mem_fun( this, &ViewLogin::sort_by_date_func ) );
+    m_treestore_diaries->set_sort_column( Gtk::ListStore::DEFAULT_SORT_COLUMN_ID,
+                                          Gtk::SORT_DESCENDING );
     m_treeview_diaries->set_has_tooltip( true );
     m_treeview_diaries->drag_dest_set( Gtk::DEST_DEFAULT_ALL, Gdk::ACTION_COPY );
     m_treeview_diaries->drag_dest_add_uri_targets();
@@ -149,7 +152,7 @@ ViewLogin::ViewLogin( void )
 }
 
 void
-ViewLogin::handle_start( void )
+ViewLogin::handle_start()
 {
     AppWindow::p->remove();
     AppWindow::p->add( *m_grid_login );
@@ -161,7 +164,7 @@ ViewLogin::handle_start( void )
 }
 
 void
-ViewLogin::handle_logout( void )
+ViewLogin::handle_logout()
 {
     handle_start();
     if( Lifeograph::loginstatus == Lifeograph::LOGGED_TIME_OUT )
@@ -171,7 +174,7 @@ ViewLogin::handle_logout( void )
 }
 
 void
-ViewLogin::populate_diaries( void )
+ViewLogin::populate_diaries()
 {
     Gtk::TreeModel::Row row;
 
@@ -187,10 +190,16 @@ ViewLogin::populate_diaries( void )
         row[ colrec->path ] = *iter;
 
         if( stat( iter->c_str(), &fst ) == 0 )
-            row[ colrec->date ] = Date::format_string(
-                    time_t( m_sort_date_type == SDT_SAVE ? fst.st_mtime : fst.st_atime ) );
+        {
+            time_t file_time( m_sort_date_type == SDT_SAVE ? fst.st_mtime : fst.st_atime );
+            row[ colrec->date ] = Date::format_string_dt( file_time );
+            row[ colrec->date_sort ] = file_time;
+        }
         else
+        {
             row[ colrec->date ] = "XXXXX";
+            row[ colrec->date_sort ] = 0;
+        }
     }
 
     // STOCK DIARIES
@@ -204,8 +213,9 @@ ViewLogin::populate_diaries( void )
         row[ colrec->path ] = path;
 
         stat( path.c_str(), &fst );
-        row[ colrec->date ] = Date::format_string(
-                time_t( m_sort_date_type == SDT_SAVE ? fst.st_mtime : fst.st_atime ) );
+        time_t file_time( m_sort_date_type == SDT_SAVE ? fst.st_mtime : fst.st_atime );
+        row[ colrec->date ] = Date::format_string_dt( file_time );
+        row[ colrec->date_sort ] = file_time;
     }
 
     if( m_treestore_diaries->children().size() > 0 )
@@ -213,12 +223,17 @@ ViewLogin::populate_diaries( void )
 }
 
 void
-ViewLogin::sort_by_date( void )
+ViewLogin::sort_by_date()
 {
-    int col_id;
-    Gtk::SortType st;
-    m_treestore_diaries->get_sort_column_id( col_id, st );
-    if( col_id == 1 )
+    if( m_sort_date_type == SDT_NAME )
+    {
+        m_sort_date_type = SDT_SAVE;
+        m_treeview_diaries->get_column( 1 )->set_title( _( STRING::COLHEAD_BY_LAST_SAVE ) );
+        m_treestore_diaries->set_default_sort_func(
+                sigc::mem_fun( this, &ViewLogin::sort_by_date_func ) );
+        PRINT_DEBUG( "sort by date" );
+    }
+    else
     {
         if( m_sort_date_type == SDT_SAVE )
         {
@@ -229,18 +244,58 @@ ViewLogin::sort_by_date( void )
         {
             m_sort_date_type = SDT_SAVE;
             m_treeview_diaries->get_column( 1 )->set_title( _( STRING::COLHEAD_BY_LAST_SAVE ) );
-
         }
-        populate_diaries();
     }
-    else
-        m_treestore_diaries->set_sort_column( 1, Gtk::SORT_DESCENDING );
+    populate_diaries();
 }
 
 void
-ViewLogin::sort_by_name( void )
+ViewLogin::sort_by_name()
 {
-    m_treestore_diaries->set_sort_column( 0, Gtk::SORT_ASCENDING );
+    m_sort_date_type = SDT_NAME;
+    //m_treestore_diaries->set_sort_column( 0, Gtk::SORT_ASCENDING );
+    m_treestore_diaries->set_default_sort_func(
+            sigc::mem_fun( this, &ViewLogin::sort_by_name_func ) );
+    PRINT_DEBUG( "sort by name" );
+    populate_diaries();
+}
+
+int
+ViewLogin::sort_by_date_func( const Gtk::TreeModel::iterator &itr1,
+                              const Gtk::TreeModel::iterator &itr2 )
+{
+    // SORT BY DATE (ONLY DESCENDINGLY FOR NOW)
+    time_t item1 = ( *itr1 )[ colrec->date_sort ];
+    time_t item2 = ( *itr2 )[ colrec->date_sort ];
+
+    int direction( -1 );
+
+    if( item1 > item2 )
+        return( -1 * direction );
+    else
+    if( item1 < item2 )
+        return( 1 * direction );
+    else
+        return 0;
+}
+
+int
+ViewLogin::sort_by_name_func( const Gtk::TreeModel::iterator &itr1,
+                              const Gtk::TreeModel::iterator &itr2 )
+{
+    // SORT BY DATE (ONLY DESCENDINGLY FOR NOW)
+    Glib::ustring item1 = ( *itr1 )[ colrec->name ];
+    Glib::ustring item2 = ( *itr2 )[ colrec->name ];
+
+    int direction( 1 );
+
+    if( item1 > item2 )
+        return( -1 * direction );
+    else
+    if( item1 < item2 )
+        return( 1 * direction );
+    else
+        return 0;
 }
 
 LIFEO::Result
@@ -298,8 +353,11 @@ ViewLogin::open_selected_diary( bool read_only )
     {
         case LIFEO::SUCCESS:
             break;
-        case INCOMPATIBLE_FILE:
-            show_info( Gtk::MESSAGE_ERROR, _( STRING::INCOMPATIBLE_DIARY ) );
+        case INCOMPATIBLE_FILE_OLD:
+            show_info( Gtk::MESSAGE_ERROR, _( STRING::INCOMPATIBLE_DIARY_OLD ) );
+            break;
+        case INCOMPATIBLE_FILE_NEW:
+            show_info( Gtk::MESSAGE_ERROR, _( STRING::INCOMPATIBLE_DIARY_NEW ) );
             break;
         case CORRUPT_FILE:
             show_info( Gtk::MESSAGE_ERROR, _( STRING::CORRUPT_DIARY ) );
@@ -372,7 +430,7 @@ ViewLogin::open_selected_diary( bool read_only )
 }
 
 void
-ViewLogin::remove_selected_diary( void )
+ViewLogin::remove_selected_diary()
 {
     m_path_removed = m_path_cur;
     Lifeograph::settings.recentfiles.erase( m_path_removed );
@@ -383,7 +441,7 @@ ViewLogin::remove_selected_diary( void )
 }
 
 void
-ViewLogin::create_new_diary( void )
+ViewLogin::create_new_diary()
 {
     /*DialogSaveDiary *dialogsavediary = new DialogSaveDiary;
     dialogsavediary->set_current_folder( Glib::get_home_dir() );
@@ -409,7 +467,7 @@ ViewLogin::create_new_diary( void )
 }
 
 void
-ViewLogin::add_existing_diary( void )
+ViewLogin::add_existing_diary()
 {
     DialogOpenDiary *filechooserdialog = new DialogOpenDiary;
 
@@ -420,7 +478,7 @@ ViewLogin::add_existing_diary( void )
 
     int result( filechooserdialog->run() );
 
-    if( result != DialogOpenDiary::RESPONSE_CANCEL )
+    if( result == DialogOpenDiary::RESPONSE_READ || result == DialogOpenDiary::RESPONSE_EDIT )
     {
         m_path_cur = filechooserdialog->get_filename();
         delete filechooserdialog;
@@ -456,7 +514,7 @@ ViewLogin::handle_infobar_response( int )
 }
 
 inline void
-ViewLogin::hide_infobar( void )
+ViewLogin::hide_infobar()
 {
     //m_label_info->set_text( "" );
     m_infobar->hide();
@@ -464,7 +522,7 @@ ViewLogin::hide_infobar( void )
 }
 
 void
-ViewLogin::handle_diary_selection_changed( void )
+ViewLogin::handle_diary_selection_changed()
 {
     m_password_attempt_no = 0;
 
@@ -509,7 +567,7 @@ ViewLogin::handle_key_release( GdkEventKey *event )
 }
 
 void
-ViewLogin::open_activated_diary( void )
+ViewLogin::open_activated_diary()
 {
     open_selected_diary( Lifeograph::stock_diaries.find( m_path_cur ) !=
             Lifeograph::stock_diaries.end() ); // read only if stock diary
