@@ -24,12 +24,13 @@
 #include <cairomm/context.h>
 
 #include "widget_chart.hpp"
+#include "strings.hpp"
 
 
 using namespace LIFEO;
 
 
-ChartPoints::ChartPoints( void )
+ChartPoints::ChartPoints()
 :   value_min( -1 ), value_max( -1 ), flag_use_current( false )
 {
 }
@@ -67,7 +68,7 @@ ChartPoints::get_value_at( Date::date_t date )
 }
 
 unsigned int
-ChartPoints::get_span( void )
+ChartPoints::get_span()
 {
     if( value_max < 0 )
         return 0;
