@@ -38,17 +38,17 @@ using namespace HELPERS;
 class ChartPoints : public std::map< Date::date_t, int >
 {
     public:
-                                    ChartPoints( void );
+                                    ChartPoints();
         void                        add( Date::date_t, int );
         void                        increase( Date::date_t, unsigned int = 1 );
-        void                        finish( void )
+        void                        finish()
         {
             if( get_span() != size() )
                 value_min = 0;
         }
 
         int                         get_value_at( Date::date_t );
-        unsigned int                get_span( void );
+        unsigned int                get_span();
 
         int                         value_min;
         int                         value_max;
