@@ -35,51 +35,87 @@ WidgetEntryList::WidgetEntryList( BaseObjectType* cobject,
 :   Gtk::TreeView( cobject )
 {
     // CELL RENDERERS
-    Gtk::CellRendererPixbuf *cellrenderer_pixbuf = Gtk::manage( new Gtk::CellRendererPixbuf );
-    Gtk::CellRendererText *cellrenderer_text = Gtk::manage( new Gtk::CellRendererText );
-    Gtk::TreeViewColumn *column = Gtk::manage( new Gtk::TreeViewColumn );
+    Gtk::CellRendererPixbuf* cellr_pb_icon = Gtk::manage( new Gtk::CellRendererPixbuf );
+    Gtk::CellRendererText* cellr_text = Gtk::manage( new Gtk::CellRendererText );
+    Gtk::TreeViewColumn* column = Gtk::manage( new Gtk::TreeViewColumn );
 
-    column->pack_start( *cellrenderer_pixbuf, false );
-    column->pack_start( *cellrenderer_text );
-    column->add_attribute( cellrenderer_pixbuf->property_pixbuf(),
-                                ListData::colrec->icon );
-    column->add_attribute( cellrenderer_text->property_markup(),
-                                ListData::colrec->info );
-    column->set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED );
+    Gtk::CellRendererPixbuf* cellr_pb_icon2 = Gtk::manage( new Gtk::CellRendererPixbuf );
 
-    cellrenderer_text->property_ellipsize() = Pango::ELLIPSIZE_END;
-    cellrenderer_text->property_scale() = .90;
-    cellrenderer_text->set_fixed_height_from_font( 1 );
+    cellr_text->property_ellipsize() = Pango::ELLIPSIZE_END;
+    if( Lifeograph::settings.small_lists )
+        cellr_text->property_scale() = .90;
+    cellr_text->set_fixed_height_from_font( 1 );
+
+    column->pack_start( *cellr_pb_icon, false );
+    column->pack_start( *cellr_text );
+    column->pack_start( *cellr_pb_icon2, false );
+
+    column->add_attribute( cellr_pb_icon->property_pixbuf(), ListData::colrec->icon );
+    column->add_attribute( cellr_text->property_markup(), ListData::colrec->info );
+    column->add_attribute( cellr_pb_icon2->property_pixbuf(), ListData::colrec->icon2 );
+
+    column->set_cell_data_func( *cellr_pb_icon2,
+                                sigc::mem_fun( this, &WidgetEntryList::cell_data_func_icon ) );
+
+    // TODO we failed to accomplish fixed height mode with the second icon renderer
+    //column->set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED );
 
     m_treestore = Gtk::TreeStore::create( *ListData::colrec );
 
+    if( Lifeograph::s_color_insensitive.empty() )
+    {
+        Lifeograph::s_color_insensitive = convert_gdkcolor_to_html(
+                get_style_context()->get_color( Gtk::STATE_FLAG_INSENSITIVE ) );
+    }
+
     append_column( *column );
 }
 
-WidgetEntryList::~WidgetEntryList( void )
+void
+WidgetEntryList::cell_data_func_icon( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter )
+{
+    DiaryElement* elem( ( * iter )[ ListData::colrec->ptr ] );
+    if( elem != NULL )
+    {
+        bool favored( elem->get_status() & ES::FAVORED );
+        cell->set_property( "visible", favored );
+        if( favored )
+            cell->set_property( "pixbuf", Lifeograph::icons->entry_favorite_16 );
+    }
+}
+
+WidgetEntryList::~WidgetEntryList()
 {
 }
 
 void
-WidgetEntryList::clear( void )
+WidgetEntryList::clear()
 {
     m_treestore->clear();
     Lifeograph::s_elem_dragged = NULL;
 }
 
 void
-WidgetEntryList::present_element( const DiaryElement *element )
+WidgetEntryList::present_element( const DiaryElement* element )
 {
     Gtk::TreePath path( element->m_list_data->treepath );
 
     expand_to_path( path );
     if( ! get_selection()->is_selected( path ) )
         get_selection()->select( path );
-    scroll_to_row( path);   // does nothing if already visible
+
+    Gtk::TreePath path_b, path_e;
+    get_visible_range( path_b, path_e );
+
+    if( treepath_is_less( path, path_b ) || treepath_is_more( path, path_e ) )
+    {
+        PRINT_DEBUG( "path is not visible" );
+        scroll_to_row( path, 0.0 );   // does nothing if already visible
+    }
 }
 
 void
-WidgetEntryList::expand_element( const DiaryElement *element ) // this function does not do much
+WidgetEntryList::expand_element( const DiaryElement* element ) // this function does not do much
 {
     expand_to_path( element->m_list_data->treepath );
 }
@@ -87,7 +123,7 @@ WidgetEntryList::expand_element( const DiaryElement *element ) // this function
 void
 WidgetEntryList::go_up( bool flag_entry_operation )
 {
-    DiaryElement *elem( AppWindow::p->panel_main->get_cur_elem() );
+    DiaryElement* elem( AppWindow::p->panel_main->get_cur_elem() );
 
     if( elem == NULL )
         return;
@@ -119,14 +155,14 @@ WidgetEntryList::go_up( bool flag_entry_operation )
     PRINT_DEBUG( "previous path: " + path.to_string() );
 
     Gtk::TreeRow row( * m_treestore->get_iter( path ) );
-    DiaryElement *element( row[ ListData::colrec->ptr ] );
+    DiaryElement* element( row[ ListData::colrec->ptr ] );
     element->show();
 }
 
 void
 WidgetEntryList::go_down( bool flag_entry_operation )
 {
-    DiaryElement *elem( AppWindow::p->panel_main->get_cur_elem() );
+    DiaryElement* elem( AppWindow::p->panel_main->get_cur_elem() );
 
     if( elem == NULL )
         return;
@@ -193,7 +229,7 @@ WidgetEntryList::handle_sorting_criteria_changed( SortingCriteria sc )
 }
 
 void
-WidgetEntryList::reset_sorting_criteria( void )
+WidgetEntryList::reset_sorting_criteria()
 {
     switch( Diary::d->get_sorting_criteria() )
     {
@@ -215,7 +251,7 @@ WidgetEntryList::reset_sorting_criteria( void )
 
 // not used now but may be used in the future
 Gtk::TreePath
-WidgetEntryList::find_element( const DiaryElement *element ) const
+WidgetEntryList::find_element( const DiaryElement* element ) const
 {
     Gtk::TreeIter iter_diary( m_treestore->children().begin() );
     if( element == ( *iter_diary )[ ListData::colrec->ptr ] )
@@ -249,7 +285,7 @@ WidgetEntryList::find_element( const DiaryElement *element ) const
 }
 
 bool
-WidgetEntryList::on_button_press_event( GdkEventButton *event )
+WidgetEntryList::on_button_press_event( GdkEventButton* event )
 {
     Lifeograph::s_flag_dragging = false;
 
@@ -304,7 +340,7 @@ WidgetEntryList::on_button_press_event( GdkEventButton *event )
 
     if( item->get_type() == DiaryElement::IT_ENTRY )
     {
-        Entry *entry = dynamic_cast< Entry* >( item );
+        Entry* entry = dynamic_cast< Entry* >( item );
 
 
         m_menu->items().push_back(
@@ -312,7 +348,7 @@ WidgetEntryList::on_button_press_event( GdkEventButton *event )
                 entry->is_favored() ?
                         _( "Remove from _Favorites" ) : _( "Add to _Favorites" ),
                 *image_favored,
-                sigc::mem_fun( *entry, &Entry::toggle_favoredness ) ) );
+                sigc::mem_fun( * entry, &Entry::toggle_favoredness ) ) );
     }
     m_menu->accelerate( *this );
     m_menu->popup( event->button, event->time );
@@ -321,7 +357,7 @@ WidgetEntryList::on_button_press_event( GdkEventButton *event )
 }
 
 bool
-WidgetEntryList::on_button_release_event( GdkEventButton *event )
+WidgetEntryList::on_button_release_event( GdkEventButton* event )
 {
     if( ! Lifeograph::s_flag_dragging /*&& event->button != 1*/ )
     {
@@ -335,7 +371,7 @@ WidgetEntryList::on_button_release_event( GdkEventButton *event )
 }
 
 bool
-WidgetEntryList::on_key_press_event( GdkEventKey *event )
+WidgetEntryList::on_key_press_event( GdkEventKey* event )
 {
     if( event->state == 0 )
     {
@@ -363,38 +399,8 @@ WidgetEntryList::on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& )
     Lifeograph::s_flag_dragging = ! Diary::d->is_read_only();
 }
 
-void
-WidgetEntryList::on_drag_data_get( const Glib::RefPtr< Gdk::DragContext > &context,
-                                   Gtk::SelectionData &data,
-                                   guint info, guint time )
-{
-    if( Lifeograph::s_elem_dragged )
-    {
-        switch( Lifeograph::s_elem_dragged->get_type() )
-        {
-            case DiaryElement::ET_DIARY:
-                data.set( TARGET_ENTRY_DIARY, "element" );
-                break;
-            case DiaryElement::ET_ENTRY:
-                data.set( TARGET_ENTRY_ENTRY, "element" );
-                break;
-            case DiaryElement::ET_CHAPTER:
-                data.set( TARGET_ENTRY_CHAPTER, "element" );
-                break;
-            default:
-                data.set( "N/A", "" );
-                break;
-        }
-    }
-    else    // should never be the case
-    {
-        data.set( "N/A", "" );
-        PRINT_DEBUG( "Nothing is selected at the drag source" );
-    }
-}
-
 bool
-WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext > &context,
+WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext >& context,
                                  int x, int y, guint time )
 {
     if( ! Lifeograph::s_flag_dragging )
@@ -405,7 +411,7 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext > &context
 
     bool retval( false );
     Gtk::TreePath path;
-    DiaryElement *element( NULL );
+    DiaryElement* element( NULL );
 
     // AUTOSCROLL
     Gdk::Rectangle rect;
@@ -445,29 +451,32 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext > &context
                         retval = true;
                     break;
                 case DiaryElement::ET_CHAPTER:
+                    // chapters can only be dropped onto temporal entries
+                    if( element->get_type() == DiaryElement::ET_ENTRY &&
+                        element->get_date().is_ordinal() == false &&
+                        element->get_date().get_pure() !=
+                                Lifeograph::s_elem_dragged->get_date().get_pure() )
+                        retval = true;
+                    break;
+                case DiaryElement::ET_TOPIC:
                     // topics can only be dropped onto other topics
-                    if( Lifeograph::s_elem_dragged->get_date().is_ordinal() )
-                    {
-                        if( element->get_type() == DiaryElement::ET_CHAPTER  &&
-                            element->get_date().is_ordinal() )
-                            retval = true;
-                    }
-                    // chapters cannot be dropped onto anything but ordinal entries
-                    else if( element->get_type() == DiaryElement::ET_ENTRY &&
-                             element->get_date().is_ordinal() &&
-                             element->get_date().get_pure() !=
-                                    Lifeograph::s_elem_dragged->get_date().get_pure() )
+                    if( element->get_type() == DiaryElement::ET_TOPIC )
+                        retval = true;
+                    break;
+                case DiaryElement::ET_TODO_GRP:
+                    // to-do groups can only be dropped onto other to-do groups
+                    if( element->get_type() == DiaryElement::ET_TODO_GRP )
                         retval = true;
                     break;
                 case DiaryElement::ET_TAG:
-                case DiaryElement::ET_THEME:
+                case DiaryElement::ET_UNTAGGED:
                     if( element->get_type() == DiaryElement::ET_ENTRY )
                         retval = true;
                     break;
                 default: // the rest is not accepted
                     break;
             }
-         }
+        }
     }
 
     if( retval )
@@ -484,7 +493,7 @@ WidgetEntryList::on_drag_motion( const Glib::RefPtr< Gdk::DragContext > &context
 }
 
 bool
-WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext > &context,
+WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext >& context,
                                int x, int y, guint time )
 {
     bool retval( false );
@@ -497,67 +506,81 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext > &context,
             {
                 case DiaryElement::ET_ENTRY:
                 {
-                    Entry *entry( dynamic_cast< Entry* >( Lifeograph::s_elem_dragged ) );
-                    if( m_elem_drop_target->get_type() == DiaryElement::ET_CHAPTER )
+                    Entry* entry( dynamic_cast< Entry* >( Lifeograph::s_elem_dragged ) );
+                    switch(m_elem_drop_target->get_type() )
                     {
-                        Chapter *chapter( dynamic_cast< Chapter* >( m_elem_drop_target ) );
-                        Diary::d->set_entry_date( entry, chapter->get_free_order() );
-                        AppWindow::p->panel_main->refresh_title();
-                        AppWindow::p->panel_diary->update_entry_list();
-                        retval = true;
-                    }
-                    else if( m_elem_drop_target->get_type() == DiaryElement::ET_ENTRY )
-                    {
-                        Diary::d->set_entry_date( entry, m_elem_drop_target->get_date() );
-                        AppWindow::p->panel_main->refresh_title();
-                        AppWindow::p->panel_diary->update_entry_list();
-                        retval = true;
+                        case DiaryElement::ET_CHAPTER:
+                        case DiaryElement::ET_TOPIC:
+                        case DiaryElement::ET_TODO_GRP:
+                        {
+                            Chapter *chapter( dynamic_cast< Chapter* >( m_elem_drop_target ) );
+                            Diary::d->set_entry_date( entry, chapter->get_free_order() );
+                            AppWindow::p->panel_main->refresh_title();
+                            AppWindow::p->panel_diary->update_entry_list();
+                            retval = true;
+                            break;
+                        }
+                        case DiaryElement::ET_ENTRY:
+                            Diary::d->set_entry_date( entry, m_elem_drop_target->get_date() );
+                            AppWindow::p->panel_main->refresh_title();
+                            AppWindow::p->panel_diary->update_entry_list();
+                            retval = true;
+                            break;
+                        default:
+                            break;
                     }
                     break;
                 }
                 case DiaryElement::ET_CHAPTER:
                 {
-                    Chapter *chapter( dynamic_cast< Chapter* >( Lifeograph::s_elem_dragged ) );
-                    if( chapter->is_ordinal() )
-                    {
-                        Diary::d->set_topic_order(
-                                chapter, m_elem_drop_target->get_date().m_date );
-                        AppWindow::p->panel_main->refresh_title();
-                        AppWindow::p->panel_diary->update_entry_list();
-                        retval = true;
-                    }
-                    else
-                    {
-                        Diary::d->get_current_chapter_ctg()->set_chapter_date(
-                                chapter, m_elem_drop_target->get_date().m_date );
-                        AppWindow::p->panel_main->refresh_title();
-                        AppWindow::p->panel_diary->update_entry_list();
-                        retval = true;
-                    }
+                    Chapter* chapter( dynamic_cast< Chapter* >( Lifeograph::s_elem_dragged ) );
+                    Diary::d->get_current_chapter_ctg()->set_chapter_date(
+                            chapter, m_elem_drop_target->get_date().m_date );
+                    AppWindow::p->panel_main->refresh_title();
+                    AppWindow::p->panel_diary->update_entry_list();
+                    retval = true;
+                    break;
+                }
+                case DiaryElement::ET_TOPIC:
+                {
+                    Chapter* chapter( dynamic_cast< Chapter* >( Lifeograph::s_elem_dragged ) );
+                    Diary::d->set_topic_order( chapter, m_elem_drop_target->get_date().m_date );
+                    AppWindow::p->panel_main->refresh_title();
+                    AppWindow::p->panel_diary->update_entry_list();
+                    retval = true;
                     break;
                 }
                 case DiaryElement::ET_TAG:
                     if( m_elem_drop_target->get_type() == DiaryElement::ET_ENTRY )
                     {
                         Tag *tag( dynamic_cast< Tag* >( Lifeograph::s_elem_dragged ) );
-                        Entry *entry( dynamic_cast< Entry* >( m_elem_drop_target ) );
+                        Entry* entry( dynamic_cast< Entry* >( m_elem_drop_target ) );
                         if( entry->add_tag( tag ) ) // if does not already have the tag
                         {
                             if( AppWindow::p->panel_main->is_cur_elem( m_elem_drop_target ) )
+                            {
                                 AppWindow::p->m_entry_view->update_tag_widget();
+                                AppWindow::p->m_entry_view->update_theme();
+                            }
+
                             retval = true;
                         }
                     }
                     break;
-                case DiaryElement::ET_THEME:
+                case DiaryElement::ET_UNTAGGED:
                     if( m_elem_drop_target->get_type() == DiaryElement::ET_ENTRY )
                     {
-                        Theme *theme( dynamic_cast< Theme* >( Lifeograph::s_elem_dragged ) );
-                        Entry *entry( dynamic_cast< Entry* >( m_elem_drop_target ) );
-                        entry->set_theme( theme );
-                        if( AppWindow::p->panel_main->is_cur_elem( m_elem_drop_target ) )
-                            AppWindow::p->m_entry_view->update_theme();
-                        retval = true;
+                        Entry* entry( dynamic_cast< Entry* >( m_elem_drop_target ) );
+                        if( entry->clear_tags() )
+                        {
+                            if( AppWindow::p->panel_main->is_cur_elem( m_elem_drop_target ) )
+                            {
+                                AppWindow::p->m_entry_view->update_tag_widget();
+                                AppWindow::p->m_entry_view->update_theme();
+                            }
+
+                            retval = true;
+                        }
                     }
                     break;
                 default:
@@ -569,49 +592,14 @@ WidgetEntryList::on_drag_drop( const Glib::RefPtr< Gdk::DragContext > &context,
     context->drag_finish( retval, false, time );
     return retval;
 }
-/*
-void
-WidgetEntryList::on_drag_data_received(
-                const Glib::RefPtr< Gdk::DragContext > &context,
-                int x, int y,
-                const Gtk::SelectionData &selection_data,
-                uint info, guint time )
-{
-    //Glib::ustring name = selection_data.get_data_as_string();
-                PRINT_DEBUG( "Entry moved1" );
 
-    //if( name.empty() )    // should never happen
-        //return;
-                PRINT_DEBUG( "Entry moved2" );
-
-    switch( info )
-    {
-        case DRAG_TARGET_ENTRY_INFO:
-        {
-            DiaryElement *element = Lifeograph::p->get_dragged_elem();
-            if( element != NULL || m_ptr2target_chapter != NULL )
-            {
-                Entry *entry( dynamic_cast< Entry* >( element ) );
-                entry->set_date( m_ptr2target_chapter->get_free_order() );
-                PRINT_DEBUG( "Entry moved3" );
-
-            }
-            break;
-        }
-        default:
-            break;
-    }
-
-    context->drag_finish( true, false, time );
-}
-*/
 int
-WidgetEntryList::sort_by_date( const Gtk::TreeModel::iterator &itr1,
-                               const Gtk::TreeModel::iterator &itr2 )
+WidgetEntryList::sort_by_date( const Gtk::TreeModel::iterator& itr1,
+                               const Gtk::TreeModel::iterator& itr2 )
 {
     // SORT BY DATE (ONLY DESCENDINGLY FOR NOW)
-    DiaryElement *item1 = ( *itr1 )[ ListData::colrec->ptr ];
-    DiaryElement *item2 = ( *itr2 )[ ListData::colrec->ptr ];
+    DiaryElement* item1 = ( *itr1 )[ ListData::colrec->ptr ];
+    DiaryElement* item2 = ( *itr2 )[ ListData::colrec->ptr ];
     if( !( item1 && item2 ) )
         return 0;
     else
@@ -620,21 +608,21 @@ WidgetEntryList::sort_by_date( const Gtk::TreeModel::iterator &itr1,
 
     int direction( ( item1->get_date().is_ordinal() && item2->get_date().is_ordinal() ) ? -1 : 1 );
 
-    if( item1->get_date() > item2->get_date() )
+    if( item1->get_date().get_sort() > item2->get_date().get_sort() )
         return( -1 * direction );
     else
-    if( item1->get_date() < item2->get_date() )
+    if( item1->get_date().get_sort() < item2->get_date().get_sort() )
         return( 1 * direction );
     else
         return 0;
 }
 
 int
-WidgetEntryList::sort_by_size( const Gtk::TreeModel::iterator &itr1,
-                               const Gtk::TreeModel::iterator &itr2 )
+WidgetEntryList::sort_by_size( const Gtk::TreeModel::iterator& itr1,
+                               const Gtk::TreeModel::iterator& itr2 )
 {
-    DiaryElement *item1 = ( *itr1 )[ ListData::colrec->ptr ];
-    DiaryElement *item2 = ( *itr2 )[ ListData::colrec->ptr ];
+    DiaryElement* item1 = ( *itr1 )[ ListData::colrec->ptr ];
+    DiaryElement* item2 = ( *itr2 )[ ListData::colrec->ptr ];
     if( !( item1 && item2 ) )
         return 0;
 
@@ -652,11 +640,11 @@ WidgetEntryList::sort_by_size( const Gtk::TreeModel::iterator &itr1,
 }
 
 int
-WidgetEntryList::sort_by_change( const Gtk::TreeModel::iterator &itr1,
-                                 const Gtk::TreeModel::iterator &itr2 )
+WidgetEntryList::sort_by_change( const Gtk::TreeModel::iterator& itr1,
+                                 const Gtk::TreeModel::iterator& itr2 )
 {
-    DiaryElement *item1 = ( *itr1 )[ ListData::colrec->ptr ];
-    DiaryElement *item2 = ( *itr2 )[ ListData::colrec->ptr ];
+    DiaryElement* item1 = ( *itr1 )[ ListData::colrec->ptr ];
+    DiaryElement* item2 = ( *itr2 )[ ListData::colrec->ptr ];
     if( !( item1 && item2 ) )
         return 0;
 
@@ -675,7 +663,7 @@ WidgetEntryList::sort_by_change( const Gtk::TreeModel::iterator &itr1,
 }
 
 inline bool
-WidgetEntryList::move_path_next( Gtk::TreePath &path )
+WidgetEntryList::move_path_next( Gtk::TreePath& path )
 {
     if( unsigned( path.back() ) < ( m_treestore->
                 get_iter( path )->parent()->children().size() - 1 ) )
@@ -688,7 +676,7 @@ WidgetEntryList::move_path_next( Gtk::TreePath &path )
 }
 
 inline bool
-WidgetEntryList::make_path_deeper_last( Gtk::TreePath &path )
+WidgetEntryList::make_path_deeper_last( Gtk::TreePath& path )
 {
     if( ! m_treestore->get_iter( path )->children().empty() )
     {
