@@ -49,8 +49,8 @@ Gtk::TextBuffer             *UndoEdit::m_ptr2buffer;
 PredicateNL                 TextbufferDiary::s_predicate_nl;
 
 // LINK
-Link::Link( const Glib::RefPtr< Gtk::TextMark > &start,
-            const Glib::RefPtr< Gtk::TextMark > &end,
+Link::Link( const Glib::RefPtr< Gtk::TextMark >& start,
+            const Glib::RefPtr< Gtk::TextMark >& end,
             LinkType t )
 :   m_mark_start( start ), m_mark_end( end ), type( t )
 {
@@ -69,30 +69,30 @@ Link::~Link()
 }
 
 // LINK TO ID
-LinkID::LinkID( const Glib::RefPtr< Gtk::TextMark > &start,
-                const Glib::RefPtr< Gtk::TextMark > &end,
+LinkID::LinkID( const Glib::RefPtr< Gtk::TextMark >& start,
+                const Glib::RefPtr< Gtk::TextMark >& end,
                 DEID id )
 :   Link( start, end, LT_ID ), m_id( id )
 {
 }
 
 void
-LinkID::go( void )
+LinkID::go()
 {
     Diary::d->get_element( m_id )->show();
 }
 
 // LINK TO ENTRY
 Gtk::Menu *LinkEntry::menu_link = NULL;
-LinkEntry::LinkEntry( const Glib::RefPtr< Gtk::TextMark > &start,
-                      const Glib::RefPtr< Gtk::TextMark > &end,
+LinkEntry::LinkEntry( const Glib::RefPtr< Gtk::TextMark >& start,
+                      const Glib::RefPtr< Gtk::TextMark >& end,
                       Date date )
 :   Link( start, end, LT_ENTRY ), m_date( date )
 {
 }
 
 void
-LinkEntry::go( void )
+LinkEntry::go()
 {
     EntryVector *entries = Diary::d->get_entries( m_date.get_pure() );
 
@@ -138,15 +138,15 @@ LinkEntry::go( void )
 // LINK TO URI
 Gtk::TextBuffer *LinkUri::m_ptr2buffer;
 
-LinkUri::LinkUri( const Glib::RefPtr< Gtk::TextMark > &start,
-                  const Glib::RefPtr< Gtk::TextMark > &end,
+LinkUri::LinkUri( const Glib::RefPtr< Gtk::TextMark >& start,
+                  const Glib::RefPtr< Gtk::TextMark >& end,
                   const std::string& url )
 :   Link( start, end, LT_URI ), m_url( url )
 {
 }
 
 void
-LinkUri::go( void )
+LinkUri::go()
 {
     GError *err = NULL;
     gtk_show_uri (NULL, m_url.c_str(), GDK_CURRENT_TIME, &err);
@@ -155,15 +155,15 @@ LinkUri::go( void )
 // LINK CHECKBOX
 const Glib::ustring     LinkCheck::boxes = "☐☑☒";
 
-LinkCheck::LinkCheck( const Glib::RefPtr< Gtk::TextMark > &start,
-                      const Glib::RefPtr< Gtk::TextMark > &end,
+LinkCheck::LinkCheck( const Glib::RefPtr< Gtk::TextMark >& start,
+                      const Glib::RefPtr< Gtk::TextMark >& end,
                       unsigned int state_index )
 : Link( start, end, LT_CHECK ), m_state_index( state_index )
 {
 }
 
 void
-LinkCheck::go( void )
+LinkCheck::go()
 {
     PRINT_DEBUG( "LinkCheck::go()" );
     m_state_index = ( m_state_index + 1 ) % 3;
@@ -221,7 +221,7 @@ InlineImage::~InlineImage()
 }
 
 // TEXTBUFFERDIARY =================================================================================
-TextbufferDiary::TextbufferDiary( void )
+TextbufferDiary::TextbufferDiary()
 :   Gtk::TextBuffer(),
     m_flag_settextoperation( false ), m_flag_ongoing_operation( 0 ), m_flag_parsing( false ),
     m_ptr2textview( NULL ), m_max_thumbnail_width( 0 ), m_enchant_dict( NULL )
@@ -310,7 +310,7 @@ TextbufferDiary::TextbufferDiary( void )
 }
 
 void
-TextbufferDiary::handle_login( void )
+TextbufferDiary::handle_login()
 {
     // SPELL CHECKING
     if( Diary::d->is_read_only() )
@@ -318,7 +318,7 @@ TextbufferDiary::handle_login( void )
 }
 
 void
-TextbufferDiary::handle_logout( void )
+TextbufferDiary::handle_logout()
 {
     EntryParser::set_search_str( "" );
 
@@ -330,7 +330,7 @@ TextbufferDiary::handle_logout( void )
 }
 
 void
-TextbufferDiary::set_search_str( const Glib::ustring &str )
+TextbufferDiary::set_search_str( const Glib::ustring& str )
 {
     EntryParser::set_search_str( str );
     place_cursor( begin() );
@@ -338,7 +338,7 @@ TextbufferDiary::set_search_str( const Glib::ustring &str )
 }
 
 bool
-TextbufferDiary::select_searchstr_previous( void )
+TextbufferDiary::select_searchstr_previous()
 {
     if( m_search_str.size() <= 0 )
         return false;
@@ -369,7 +369,7 @@ TextbufferDiary::select_searchstr_previous( void )
 }
 
 bool
-TextbufferDiary::select_searchstr_next( void )
+TextbufferDiary::select_searchstr_next()
 {
     if( m_search_str.size() <= 0 )
         return false;
@@ -401,7 +401,7 @@ TextbufferDiary::select_searchstr_next( void )
 }
 
 void
-TextbufferDiary::parse( const Gtk::TextIter &start, const Gtk::TextIter &end )
+TextbufferDiary::parse( const Gtk::TextIter& start, const Gtk::TextIter& end )
 {
     m_flag_parsing = true;
 
@@ -419,7 +419,7 @@ TextbufferDiary::parse( const Gtk::TextIter &start, const Gtk::TextIter &end )
 }
 
 void
-TextbufferDiary::reparse( void )
+TextbufferDiary::reparse()
 {
     m_flag_settextoperation = true;
     parse( begin(), end() );
@@ -434,7 +434,7 @@ TextbufferDiary::get_char_at( int i )
 
 // PARSING APPLIERS
 void
-TextbufferDiary::apply_heading( void )
+TextbufferDiary::apply_heading()
 {
     Gtk::TextIter iter_start( get_iter_at_offset( 0 ) );
     Gtk::TextIter iter_end( iter_start );
@@ -454,7 +454,7 @@ TextbufferDiary::apply_heading( void )
 }
 
 void
-TextbufferDiary::apply_subheading( void )
+TextbufferDiary::apply_subheading()
 {
     Gtk::TextIter iter_start( get_iter_at_offset( m_pos_start ) );
     Gtk::TextIter iter_current( iter_start );
@@ -463,31 +463,31 @@ TextbufferDiary::apply_subheading( void )
 }
 
 void
-TextbufferDiary::apply_bold( void )
+TextbufferDiary::apply_bold()
 {
     apply_markup( m_tag_bold );
 }
 
 void
-TextbufferDiary::apply_italic( void )
+TextbufferDiary::apply_italic()
 {
     apply_markup( m_tag_italic );
 }
 
 void
-TextbufferDiary::apply_strikethrough( void )
+TextbufferDiary::apply_strikethrough()
 {
     apply_markup( m_tag_strikethrough );
 }
 
 void
-TextbufferDiary::apply_highlight( void )
+TextbufferDiary::apply_highlight()
 {
     apply_markup( m_tag_highlight );
 }
 
 void
-TextbufferDiary::apply_comment( void )
+TextbufferDiary::apply_comment()
 {
     Gtk::TextIter iter_start( get_iter_at_offset( m_pos_start ) );
     Gtk::TextIter iter_end( get_iter_at_offset( pos_current ) );
@@ -496,7 +496,7 @@ TextbufferDiary::apply_comment( void )
 }
 
 void
-TextbufferDiary::apply_ignore( void )
+TextbufferDiary::apply_ignore()
 {
     Gtk::TextIter iter_start( get_iter_at_offset( m_pos_start ) );
     Gtk::TextIter iter_end( iter_start );
@@ -505,8 +505,8 @@ TextbufferDiary::apply_ignore( void )
 }
 
 void
-TextbufferDiary::apply_hidden_link_tags( Gtk::TextIter &iter_end,
-                                         const Glib::RefPtr< Tag > &tag_link )
+TextbufferDiary::apply_hidden_link_tags( Gtk::TextIter& iter_end,
+                                         const Glib::RefPtr< Tag >& tag_link )
 {
     Gtk::TextIter iter_start( get_iter_at_offset( m_pos_start ) );
     Gtk::TextIter iter_current( get_iter_at_offset( pos_current ) );
@@ -538,7 +538,7 @@ TextbufferDiary::apply_hidden_link_tags( Gtk::TextIter &iter_end,
 }
 
 void
-TextbufferDiary::apply_link( void )
+TextbufferDiary::apply_link()
 {
     // HANDLE RELATIVE PATHS
     if( word_last.find( "rel://" ) == 0 )
@@ -614,7 +614,7 @@ TextbufferDiary::apply_link( void )
 }
 
 void
-TextbufferDiary::apply_link_id( void )
+TextbufferDiary::apply_link_id()
 {
     DiaryElement *element( Diary::d->get_element( id_last ) );
 
@@ -641,7 +641,7 @@ TextbufferDiary::apply_link_id( void )
 }
 
 void
-TextbufferDiary::apply_link_date( void )
+TextbufferDiary::apply_link_date()
 {
     LinkStatus status( LS_OK );
     Entry *ptr2entry( Diary::d->get_entry( date_last.m_date + 1 ) ); // + 1 fixes order
@@ -682,7 +682,7 @@ TextbufferDiary::apply_link_date( void )
 }
 
 void
-TextbufferDiary::apply_check_unf( void )
+TextbufferDiary::apply_check_unf()
 {
     Gtk::TextIter iter_start( get_iter_at_offset( pos_current - 1 ) );
     Gtk::TextIter iter_end( get_iter_at_offset( pos_current ) );
@@ -694,7 +694,7 @@ TextbufferDiary::apply_check_unf( void )
 }
 
 void
-TextbufferDiary::apply_check_fin( void )
+TextbufferDiary::apply_check_fin()
 {
     Gtk::TextIter iter_start( get_iter_at_offset( pos_current -1 ) );
     Gtk::TextIter iter_box( get_iter_at_offset( pos_current ) );
@@ -709,7 +709,7 @@ TextbufferDiary::apply_check_fin( void )
 }
 
 void
-TextbufferDiary::apply_check_ccl( void )
+TextbufferDiary::apply_check_ccl()
 {
     Gtk::TextIter iter_start( get_iter_at_offset( pos_current - 1 ) );
     Gtk::TextIter iter_box( get_iter_at_offset( pos_current ) );
@@ -724,7 +724,7 @@ TextbufferDiary::apply_check_ccl( void )
 }
 
 void
-TextbufferDiary::apply_match( void )
+TextbufferDiary::apply_match()
 {
     Gtk::TextIter iter_start( get_iter_at_offset( pos_search ) );
     Gtk::TextIter iter_end( get_iter_at_offset( pos_current+1 ) );
@@ -734,7 +734,7 @@ TextbufferDiary::apply_match( void )
 //#define CALL_MEMBER_FN(object,ptrToMember)  ((object).*(ptrToMember))
 
 inline void
-TextbufferDiary::apply_markup( const Glib::RefPtr< Tag > &tag)
+TextbufferDiary::apply_markup( const Glib::RefPtr< Tag >& tag)
 {
     Gtk::TextIter iter_start( get_iter_at_offset( m_pos_start ) );
     Gtk::TextIter iter_current( get_iter_at_offset( pos_current ) );
@@ -789,7 +789,7 @@ TextbufferDiary::on_insert( const Gtk::TextIter& iterator,
 }
 
 void
-TextbufferDiary::process_space( void )
+TextbufferDiary::process_space()
 {
     Gtk::TextIter iter_end = get_iter_at_mark( get_insert() );
     Gtk::TextIter iter_start( iter_end );
@@ -850,7 +850,7 @@ TextbufferDiary::process_space( void )
 }
 
 bool
-TextbufferDiary::process_new_line( void )
+TextbufferDiary::process_new_line()
 {
     Gtk::TextIter iter_end = get_iter_at_mark( get_insert() );
     Gtk::TextIter iter_start( iter_end );
@@ -985,8 +985,8 @@ TextbufferDiary::on_apply_tag( const Glib::RefPtr< TextBuffer::Tag >& tag,
 }*/
 
 void
-TextbufferDiary::on_mark_set( const TextBuffer::iterator &iter,
-                              const Glib::RefPtr< TextBuffer::Mark > &mark )
+TextbufferDiary::on_mark_set( const TextBuffer::iterator& iter,
+                              const Glib::RefPtr< TextBuffer::Mark >& mark )
 {
     Gtk::TextBuffer::on_mark_set( iter, mark );
 
@@ -1100,7 +1100,7 @@ TextbufferDiary::get_link( int offset ) const
 }
 
 Link*
-TextbufferDiary::get_link( const Gtk::TextIter &iter ) const
+TextbufferDiary::get_link( const Gtk::TextIter& iter ) const
 {
     for( ListLinks::const_iterator link = m_list_links.begin();
           link != m_list_links.end();
@@ -1131,7 +1131,7 @@ TextbufferDiary::clear_links( int start, int end )
 }
 
 void
-TextbufferDiary::clear_links( void )
+TextbufferDiary::clear_links()
 {
     for( ListLinks::iterator iter = m_list_links.begin();
          iter != m_list_links.end();
@@ -1172,7 +1172,7 @@ TextbufferDiary::clear_images( int start, int &end )
 }
 
 void
-TextbufferDiary::clear_images( void ) // note that this version does not alter the buffer
+TextbufferDiary::clear_images() // note that this version does not alter the buffer
 {
     for( ListImages::iterator iter = m_list_images.begin();
          iter != m_list_images.end();
@@ -1409,25 +1409,25 @@ TextbufferDiary::toggle_format( Glib::RefPtr< Tag > tag, const Glib::ustring &ma
 }
 
 void
-TextbufferDiary::toggle_bold( void )
+TextbufferDiary::toggle_bold()
 {
     toggle_format( m_tag_bold, "*" );
 }
 
 void
-TextbufferDiary::toggle_italic( void )
+TextbufferDiary::toggle_italic()
 {
     toggle_format( m_tag_italic, "_" );
 }
 
 void
-TextbufferDiary::toggle_strikethrough( void )
+TextbufferDiary::toggle_strikethrough()
 {
     toggle_format( m_tag_strikethrough, "=" );
 }
 
 void
-TextbufferDiary::toggle_highlight( void )
+TextbufferDiary::toggle_highlight()
 {
     toggle_format( m_tag_highlight, "#" );
 }
@@ -1439,7 +1439,7 @@ TextbufferDiary::set_comment_visibility( bool visible )
 }
 
 void
-TextbufferDiary::calculate_para_bounds( Gtk::TextIter &iter_begin, Gtk::TextIter &iter_end )
+TextbufferDiary::calculate_para_bounds( Gtk::TextIter& iter_begin, Gtk::TextIter& iter_end )
 {
     if( ! iter_begin.backward_find_char( s_predicate_nl ) )
         iter_begin.set_offset( 0 );
@@ -1453,8 +1453,8 @@ TextbufferDiary::calculate_para_bounds( Gtk::TextIter &iter_begin, Gtk::TextIter
 }
 
 bool
-TextbufferDiary::calculate_multiline_selection_bounds( Gtk::TextIter &iter_begin,
-                                                       Gtk::TextIter &iter_end )
+TextbufferDiary::calculate_multiline_selection_bounds( Gtk::TextIter& iter_begin,
+                                                       Gtk::TextIter& iter_end )
 {
     bool flag_starts_first_para( false );
 
@@ -1487,7 +1487,7 @@ TextbufferDiary::calculate_multiline_selection_bounds( Gtk::TextIter &iter_begin
 }
 
 void
-TextbufferDiary::handle_indent( void )
+TextbufferDiary::handle_indent()
 {
     if( ! m_ptr2textview->has_focus() )
         return;
@@ -1520,7 +1520,7 @@ TextbufferDiary::handle_indent( void )
 }
 
 void
-TextbufferDiary::handle_unindent( void )
+TextbufferDiary::handle_unindent()
 {
     if( ! m_ptr2textview->has_focus() )
         return;
@@ -1561,7 +1561,7 @@ TextbufferDiary::handle_unindent( void )
 }
 
 void
-TextbufferDiary::add_bullet( void )
+TextbufferDiary::add_bullet()
 {
     Gtk::TextIter iter, iter_end;
     if( ! calculate_multiline_selection_bounds( iter, iter_end ) )
@@ -1627,7 +1627,7 @@ TextbufferDiary::add_bullet( void )
 }
 
 void
-TextbufferDiary::add_checkbox( void )
+TextbufferDiary::add_checkbox()
 {
     Gtk::TextIter iter, iter_end;
     if( ! calculate_multiline_selection_bounds( iter, iter_end ) )
@@ -1693,7 +1693,7 @@ TextbufferDiary::add_checkbox( void )
 }
 
 void
-TextbufferDiary::add_empty_line_above( void )
+TextbufferDiary::add_empty_line_above()
 {
     if( ! m_ptr2textview->has_focus() )
         return;
@@ -1705,7 +1705,7 @@ TextbufferDiary::add_empty_line_above( void )
 }
 
 void
-TextbufferDiary::remove_empty_line_above( void )
+TextbufferDiary::remove_empty_line_above()
 {
     if( ! m_ptr2textview->has_focus() )
         return;
@@ -1724,7 +1724,7 @@ TextbufferDiary::remove_empty_line_above( void )
 }
 
 void
-TextbufferDiary::move_line_up( void )
+TextbufferDiary::move_line_up()
 {
     if( ! m_ptr2textview->has_focus() )
         return;
@@ -1761,7 +1761,7 @@ TextbufferDiary::move_line_up( void )
 }
 
 void
-TextbufferDiary::move_line_down( void )
+TextbufferDiary::move_line_down()
 {
     if( ! m_ptr2textview->has_focus() )
         return;
@@ -1800,7 +1800,7 @@ TextbufferDiary::move_line_down( void )
 }
 
 void
-TextbufferDiary::insert_link( DiaryElement *element )
+TextbufferDiary::insert_link( DiaryElement* element )
 {
     // TODO: implement a custom insert function that adds spaces where necessary
     Gtk::TextIter iter( get_iter_at_mark( get_insert() ) );
@@ -1816,7 +1816,7 @@ TextbufferDiary::insert_link( DiaryElement *element )
 }
 
 void
-TextbufferDiary::insert_time_stamp( void )
+TextbufferDiary::insert_time_stamp()
 {
     if( ! m_ptr2textview->has_focus() )
         return;
@@ -1831,12 +1831,11 @@ TextbufferDiary::insert_time_stamp( void )
     if( c != ' ' && c != '\n' && c != '\t' )
         insert( get_iter_at_mark( get_insert() ), " ");
 
-    time_t date( time( NULL ) );
-    insert( get_iter_at_mark( get_insert() ), Date::format_string( date ) );
+    insert( get_iter_at_mark( get_insert() ), Date::format_string_dt( time( NULL ) ) );
 }
 
 void
-TextbufferDiary::set_richtext( Entry *entry )
+TextbufferDiary::set_richtext( Entry* entry )
 {
     m_flag_settextoperation = true;
     clear_links();
@@ -1848,8 +1847,7 @@ TextbufferDiary::set_richtext( Entry *entry )
     UndoManager::m->freeze();
     m_ptr2entry = entry;
     set_language( Diary::d->is_read_only() ? "" : entry->get_lang_final() );
-    set_theme( entry->get_theme_is_set() ?
-            entry->get_theme() : Diary::d->get_default_theme() );
+    set_theme( entry->get_theme() );
     Gtk::TextBuffer::set_text( entry->get_text() );
     place_cursor( begin() );
     UndoManager::m->thaw();
@@ -1889,7 +1887,7 @@ TextbufferDiary::set_theme( const Theme *theme )
 
 // SPELL CHECKING BY DIRECT UTILIZATION OF ENCHANT (code partly copied from GtkSpell library)
 void
-TextbufferDiary::handle_word( void )
+TextbufferDiary::handle_word()
 {
     PRINT_DEBUG( "ALPHA_LAST=[" + alpha_last + "]" );
 
@@ -1904,8 +1902,8 @@ TextbufferDiary::handle_word( void )
 }
 
 static void
-set_lang_from_dict_cb( const char * const lang_tag, const char * const provider_name,
-                       const char * const provider_desc, const char * const provider_file,
+set_lang_from_dict_cb( const char* const lang_tag, const char* const provider_name,
+                       const char* const provider_desc, const char* const provider_file,
                        void * user_data )
 {
     std::string *language = ( std::string* ) user_data;
@@ -1941,7 +1939,7 @@ TextbufferDiary::set_language( std::string lang )
 }
 
 Gtk::Menu*
-TextbufferDiary::build_languages_menu( void )
+TextbufferDiary::build_languages_menu()
 {
     Gtk::Menu *menu = Gtk::manage( new Gtk::Menu );
     Gtk::RadioButtonGroup group;
@@ -1991,17 +1989,17 @@ TextbufferDiary::build_languages_menu( void )
 }
 
 void
-TextbufferDiary::add_suggestion_menus( const Glib::ustring &word, Gtk::Menu *topmenu )
+TextbufferDiary::add_suggestion_menus( const Glib::ustring& word, Gtk::Menu* topmenu )
 {
-    Gtk::MenuItem *mi;
-    char **suggestions;
+    Gtk::MenuItem* mi;
+    char** suggestions;
     size_t n_suggs;
     int menu_position( 0 );
 
 //    if (!spell->speller)
 //        return;
 
-    suggestions = enchant_dict_suggest( m_enchant_dict, word.c_str(), word.size(), &n_suggs );
+    suggestions = enchant_dict_suggest( m_enchant_dict, word.c_str(), word.size(), & n_suggs );
 
     if ( suggestions == NULL || !n_suggs )
     {
@@ -2015,7 +2013,7 @@ TextbufferDiary::add_suggestion_menus( const Glib::ustring &word, Gtk::Menu *top
     }
     else
     {
-        Gtk::Menu *menu_more( NULL );
+        Gtk::Menu* menu_more( NULL );
 
         for( size_t i = 0; i < n_suggs && i < 20; i++ )
         {
@@ -2050,7 +2048,7 @@ TextbufferDiary::add_suggestion_menus( const Glib::ustring &word, Gtk::Menu *top
     mi = Gtk::manage( new Gtk::MenuItem(
             Glib::ustring::compose( _("Add \"%1\" to Dictionary" ), word ) ) );
     mi->show();
-    topmenu->insert( *mi, menu_position++ );
+    topmenu->insert( * mi, menu_position++ );
     mi->signal_activate().connect( sigc::bind(
             sigc::mem_fun( this, &TextbufferDiary::add_word_to_dictionary ), word ) );
 
@@ -2091,14 +2089,14 @@ TextbufferDiary::handle_language_changed( const std::string& lang,
 }
 
 void
-TextbufferDiary::ignore_misspelled_word( const Glib::ustring &word )
+TextbufferDiary::ignore_misspelled_word( const Glib::ustring& word )
 {
     enchant_dict_add_to_session( m_enchant_dict, word.c_str(), word.size() );
     parse( begin(), end() );   // check entire buffer again
 }
 
 void
-TextbufferDiary::replace_misspelled_word( const Glib::ustring &new_word )
+TextbufferDiary::replace_misspelled_word( const Glib::ustring& new_word )
 {
 //    if (!spell->speller)
 //        return;
@@ -2134,7 +2132,7 @@ TextbufferDiary::replace_misspelled_word( const Glib::ustring &new_word )
 }
 
 void
-TextbufferDiary::add_word_to_dictionary( const Glib::ustring &word )
+TextbufferDiary::add_word_to_dictionary( const Glib::ustring& word )
 {
     enchant_dict_add_to_pwl( m_enchant_dict, word.c_str(), word.size() );
     parse( begin(), end() );   // check entire buffer again
@@ -2142,7 +2140,7 @@ TextbufferDiary::add_word_to_dictionary( const Glib::ustring &word )
 
 // TEXTVIEW ========================================================================================
 // STATIC MEMBERS
-TextviewDiary::TextviewDiary( BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>& )
+TextviewDiary::TextviewDiary( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
 :   Gtk::TextView( cobject ),
     m_cursor_hand( Gdk::Cursor::create( Gdk::HAND2 ) ),
     m_cursor_xterm( Gdk::Cursor::create( Gdk::XTERM ) ),
@@ -2162,7 +2160,7 @@ TextviewDiary::TextviewDiary( BaseObjectType *cobject, const Glib::RefPtr<Gtk::B
 }
 
 inline void
-TextviewDiary::update_link( void )
+TextviewDiary::update_link()
 {
     Gtk::TextIter       iter;
     const Glib::RefPtr< Gdk::Cursor >
@@ -2210,7 +2208,7 @@ TextviewDiary::update_link( void )
 }
 
 void
-TextviewDiary::set_richtext( Entry *entry )
+TextviewDiary::set_richtext( Entry* entry )
 {
     m_link_hovered = NULL;
 
@@ -2225,14 +2223,14 @@ TextviewDiary::set_richtext( Entry *entry )
 }
 
 bool
-TextviewDiary::on_motion_notify_event( GdkEventMotion *event )
+TextviewDiary::on_motion_notify_event( GdkEventMotion* event )
 {
     update_link();
     return Gtk::TextView::on_motion_notify_event( event );
 }
 
 bool
-TextviewDiary::on_button_press_event( GdkEventButton *event )
+TextviewDiary::on_button_press_event( GdkEventButton* event )
 {
     if( event->button == 1 )
     {
@@ -2265,7 +2263,7 @@ TextviewDiary::on_button_press_event( GdkEventButton *event )
 }
 
 bool
-TextviewDiary::on_button_release_event( GdkEventButton *event )
+TextviewDiary::on_button_release_event( GdkEventButton* event )
 {
     if( m_link_hovered != NULL && event->button == 1 )
     {
@@ -2291,7 +2289,7 @@ TextviewDiary::on_button_release_event( GdkEventButton *event )
 }
 
 bool
-TextviewDiary::on_key_press_event( GdkEventKey *event )
+TextviewDiary::on_key_press_event( GdkEventKey* event )
 {
     if( ! Diary::d->is_read_only() )
     {
@@ -2319,7 +2317,7 @@ TextviewDiary::on_key_press_event( GdkEventKey *event )
 }
 
 bool
-TextviewDiary::on_key_release_event( GdkEventKey *event )
+TextviewDiary::on_key_release_event( GdkEventKey* event )
 {
     if( event->keyval == GDK_KEY_Control_L || event->keyval == GDK_KEY_Control_R )
         if( m_link_hovered )
@@ -2329,9 +2327,10 @@ TextviewDiary::on_key_release_event( GdkEventKey *event )
 }
 
 void
-TextviewDiary::on_size_allocate( Gtk::Allocation &allocation )
+TextviewDiary::on_size_allocate( Gtk::Allocation& allocation )
 {
     Gtk::TextView::on_size_allocate( allocation );
+
     m_flag_size_allocated = true;
 
     if( m_buffer->update_thumbnail_width( allocation.get_width() ) )
@@ -2349,6 +2348,14 @@ TextviewDiary::on_size_allocate( Gtk::Allocation &allocation )
     }
 }
 
+//void
+//TextviewDiary::on_style_changed( const Glib::RefPtr< Gtk::Style > &style_prev )
+//{
+//  Gtk::TextView::on_style_changed( style_prev );
+////    TextbufferDiary = get_pango_context()->get_font_description();
+//  TextbufferDiary::m_theme_font = get_style()->get_font();
+//}
+
 bool
 TextviewDiary::handle_query_tooltip( int x, int y, bool keyboard_mode,
                                      const Glib::RefPtr< Gtk::Tooltip > &tooltip )
@@ -2390,11 +2397,3 @@ TextviewDiary::handle_query_tooltip( int x, int y, bool keyboard_mode,
 
     return true;
 }
-
-//void
-//TextviewDiary::on_style_changed( const Glib::RefPtr< Gtk::Style > &style_prev )
-//{
-//  Gtk::TextView::on_style_changed( style_prev );
-////    TextbufferDiary = get_pango_context()->get_font_description();
-//  TextbufferDiary::m_theme_font = get_style()->get_font();
-//}
